(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1897131,      32954]
NotebookOptionsPosition[   1892057,      32878]
NotebookOutlinePosition[   1892478,      32895]
CellTagsIndexPosition[   1892435,      32892]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c234eda6-470d-4ce4-a2a7-7f58a6df059d"],

Cell["Chapter 2, Section 2.8, Animation of Figure 2.14", "Section",
 CellChangeTimes->{{3.8814780367287827`*^9, 
  3.881478039196784*^9}},ExpressionUUID->"8d36d243-d1b2-4dc1-b6c6-\
24fb93c12288"],

Cell[TextData[{
 "We start by a function ",
 StyleBox["r", "Input"],
 " using Eq.(2.20) to give us the radial distance for given values of \
semi-major axis, ",
 StyleBox["a", "Input"],
 ", eccentricity, ",
 StyleBox["e", "Input"],
 ", and true anomaly, ",
 StyleBox["f", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d5ed9320-f05a-4b94-8a25-ee3a9e0eae98"],

Cell["r[a_,e_,f_]:=a(1-e^2)/(1+e Cos[f]);", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"672bc8cb-0992-40af-9edd-19e6c582074e"],

Cell[TextData[{
 "Now define a fixed viewpoint, ",
 StyleBox["vp", "Input"],
 ", from which to view the 3D plots."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a0007e51-09cc-412e-b873-7e1d980429ba"],

Cell["vp = {1.300, -2.400, 2.000};", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"9de712f4-ffc4-4c90-a61a-23de1e8c4c9d"],

Cell["Set up the points defining an ellipse in the X-Y plane.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.852535506345207*^9, 3.852535547776589*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"34bfc68c-99b8-4d2c-b94b-cd8ab878feb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xyz0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"1.0", ",", "0.5", ",", "t"}], "]"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"1.0", ",", "0.5", ",", "t"}], "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", "\n", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "Pi"}], ",", 
       RowBox[{"Pi", "/", "60"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8524550323689423`*^9, 3.852455032372922*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"0e376915-8fd5-499c-8b61-f5a9c5e9b62d"],

Cell["Define the RGB colour to be used for the 3D arrowheads.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525355602484217`*^9, 3.85253558792832*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1bc6f51f-3786-4763-aba6-8599670a2d28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ccolour", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.852533343123155*^9, 3.852533350115405*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"857e11d4-9e67-4184-abb4-7e1dd13a9671"],

Cell["\<\
Define a function to draw a circle, with arrow, at the end of the X axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535629487727*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c77888b8-1de3-4b8c-90ef-f6ae58a47bc9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circleX", "[", 
   RowBox[{"rad_", ",", "offset_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ParametricPlot3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"offset", ",", 
        RowBox[{"rad", "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"rad", "*", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", 
        RowBox[{"2", "Pi"}]}], "}"}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"ccolour", ",", 
       RowBox[{"Arrowheads", "[", "0.03", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"Tube", "[", 
         RowBox[{"BSplineCurve", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"offset", ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "20"}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "20"}], "]"}]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"offset", ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "10"}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "10"}], "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"offset", ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", "0", "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", "0", "]"}]}]}], "}"}]}], "}"}], "]"}], 
         "]"}], "]"}]}], "}"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.852530333257227*^9, 3.8525304086068172`*^9}, {
   3.852530558154735*^9, 3.852530648536417*^9}, {3.8525307533107567`*^9, 
   3.8525307774217033`*^9}, 3.8525308423951693`*^9, 3.8525308864100122`*^9, {
   3.8525321033795357`*^9, 3.852532317715383*^9}, {3.852532351892086*^9, 
   3.852532362185829*^9}, {3.852532396866641*^9, 3.85253241656883*^9}, {
   3.852532524575098*^9, 3.852532525021137*^9}, {3.852532618043804*^9, 
   3.852532664681788*^9}, {3.852532696585359*^9, 3.852532697240665*^9}, {
   3.852532746071652*^9, 3.852532751615067*^9}, {3.852533374804676*^9, 
   3.852533400778474*^9}, {3.852533640296274*^9, 3.8525336470232763`*^9}, {
   3.852533791060368*^9, 3.852533860715954*^9}, {3.8525340922576227`*^9, 
   3.85253409260006*^9}, {3.852572124974773*^9, 3.8525721329911537`*^9}, {
   3.85257217039001*^9, 3.852572172180476*^9}, {3.852572378233522*^9, 
   3.852572393641234*^9}, 3.85257242393714*^9, {3.85257246398421*^9, 
   3.852572464951795*^9}, 3.852572529823399*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"3652ce30-f56d-4e52-852d-b4fe08c65066"],

Cell["\<\
Define a function to draw a circle, with arrow, at the end of the Z axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.85253564256765*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9e30f975-d9be-4ece-95d5-877d0e85514d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circleZ", "[", 
   RowBox[{"rad_", ",", "offset_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ParametricPlot3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"rad", "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"rad", "*", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", "offset"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", 
        RowBox[{"2", "Pi"}]}], "}"}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"ccolour", ",", 
       RowBox[{"Arrowheads", "[", "0.03", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"Tube", "[", 
         RowBox[{"BSplineCurve", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "20"}]}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "20"}]}], "]"}]}], ",", "offset"}], "}"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "10"}]}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "10"}]}], "]"}]}], ",", "offset"}], "}"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", 
                 RowBox[{"Pi", "/", "4"}]}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{"3", 
                 RowBox[{"Pi", "/", "4"}]}], "]"}]}], ",", "offset"}], 
             "}"}]}], "}"}], "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.852530333257227*^9, 3.8525304086068172`*^9}, {
   3.852530558154735*^9, 3.852530648536417*^9}, {3.8525307533107567`*^9, 
   3.8525307774217033`*^9}, 3.8525308423951693`*^9, {3.8525308864100122`*^9, 
   3.85253092293753*^9}, 3.852532737103771*^9, {3.8525328278286257`*^9, 
   3.852532855603735*^9}, {3.8525329272113457`*^9, 3.852532947840917*^9}, {
   3.852533005801093*^9, 3.852533008885957*^9}, {3.8525330565753*^9, 
   3.852533059692666*^9}, {3.852533180122869*^9, 3.852533190833643*^9}, {
   3.85253322865856*^9, 3.85253325183976*^9}, {3.852533370780944*^9, 
   3.852533371554509*^9}, {3.852533404861548*^9, 3.852533407354621*^9}, {
   3.852533874651873*^9, 3.8525339583782463`*^9}, 3.852534001203566*^9, {
   3.8525340876666117`*^9, 3.852534088112321*^9}, 3.852572185442327*^9, {
   3.8525722869554663`*^9, 3.852572296891017*^9}, {3.8525724406005983`*^9, 
   3.852572472159524*^9}, 3.8525725348627243`*^9},
 CellLabel->"In[6]:=",ExpressionUUID->"1398d984-0426-4b5a-a072-c893e20cdcad"],

Cell["\<\
Draw the two circles for use in the plots to denote rotation axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535691910995*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e5a24ef9-2e36-42fa-b1ad-7178d38ca7cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"circleX", "[", 
    RowBox[{"0.2", ",", "1.8"}], "]"}]}], ";", " ", 
  RowBox[{"cZ", "=", 
   RowBox[{"circleZ", "[", 
    RowBox[{"0.2", ",", "1.8"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.852530930762123*^9, 3.852530969441333*^9}, {
   3.852531307355262*^9, 3.852531309138297*^9}, 3.852532334956168*^9, 
   3.852533421050256*^9, {3.852535651777452*^9, 3.852535652481008*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"252528e2-40aa-4756-b12f-b27bc2a3cac5"],

Cell["\<\
Define a function to draw a set of red axes of unit vectors for x-y-z.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535762668989*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b8a8eb27-75de-4e3c-8f55-30f58984bbe9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"axesred", "[", "vec_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Arrowheads", "[", "0.04", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"orig", ",", "vec"}], "}"}], ",", "0.02"}], "]"}], "]"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.852529070144017*^9, 3.852529072480816*^9}, {
  3.852530247114521*^9, 3.852530256682539*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"f1e1377c-633c-4f70-854a-860223c37998"],

Cell["\<\
Define a function to draw a set of blue axes of unit vectors for X-Y-Z.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.8525357716208477`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06c35ab9-b0b8-40b6-b090-c02afe2d208d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"axesblue", "[", "vec_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Arrowheads", "[", "0.04", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"orig", ",", "vec"}], "}"}], ",", "0.02"}], "]"}], "]"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.85245513621462*^9, 3.852455151342005*^9}, {
  3.852530260627121*^9, 3.852530262969915*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"51024ddd-924d-498c-ad34-6d51ff7c2881"],

Cell["\<\
Set up the basic axes, labels and a plane to denote the ecliptic.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.85253589933282*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"67043386-4d59-4e57-a499-e40e376b532f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ax", "=", 
   RowBox[{"{", 
    RowBox[{"1.8", ",", "0", ",", "0"}], "}"}]}], ";", " ", 
  RowBox[{"ay", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.8", ",", "0"}], "}"}]}], ";", " ", 
  RowBox[{"az", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.8"}], "}"}]}], ";", " ", 
  RowBox[{"orig", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xlab", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<X\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.65", ",", "0", ",", 
        RowBox[{"-", "0.2"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylab", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<Y\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"0.1", ",", "1.7", ",", "0.1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zlab", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<Z\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"0.2", ",", "0", ",", "1.65"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aX", ",", "aY", ",", "aZ"}], "}"}], "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"axesblue", "[", "#", "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"ax", ",", "ay", ",", "az"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"OaX", ",", "OaY", ",", "OaZ"}], "}"}], "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"axesred", "[", "#", "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"ax", ",", "ay", ",", "az"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"originalaxes", "=", 
   RowBox[{"{", 
    RowBox[{"aX", ",", "aY", ",", "aZ"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ecliptic", "=", "\n", 
   RowBox[{"Graphics3D", "[", "\n", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "1", "]"}], ",", 
      RowBox[{"Opacity", "[", "0.5", "]"}], ",", 
      RowBox[{"Polygon", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1.6", ",", "1.6", ",", 
           RowBox[{"-", "0.001"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.6"}], ",", "1.6", ",", 
           RowBox[{"-", "0.001"}]}], "}"}], ",", "\n", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.6"}], ",", 
           RowBox[{"-", "1.6"}], ",", 
           RowBox[{"-", "0.001"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1.6", ",", 
           RowBox[{"-", "1.6"}], ",", 
           RowBox[{"-", "0.001"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.852455072151498*^9, 3.852455072154038*^9}, {
   3.852455174334524*^9, 3.852455278076873*^9}, {3.852455643806073*^9, 
   3.852455740260494*^9}, {3.852455940820121*^9, 3.85245597107213*^9}, {
   3.852456236888843*^9, 3.8524562676779823`*^9}, {3.8524665494557056`*^9, 
   3.852466693659786*^9}, {3.8524667310279827`*^9, 3.85246676886753*^9}, {
   3.852466840470213*^9, 3.852466894506056*^9}, 3.852467043482765*^9, {
   3.8525302689863653`*^9, 3.8525303104249287`*^9}, 3.852531018505537*^9, {
   3.8525313901218224`*^9, 3.8525314089366903`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"f877f1cb-57e9-409f-aef3-d7ceea1b068c"],

Cell[TextData[{
 "Define the ",
 StyleBox["OrbitPlots",
  FontWeight->"Bold"],
 " function.  This will plot the reference and transformed axes for given \
values of the inclination, ",
 StyleBox["i",
  FontWeight->"Bold"],
 ", argument of pericentre, ",
 StyleBox["\[Omega]",
  FontWeight->"Bold"],
 ", and longitude of ascending node, ",
 StyleBox["\[CapitalOmega]",
  FontWeight->"Bold"],
 ".  The value of ",
 StyleBox["rotc",
  FontWeight->"Bold"],
 " determines whether or not a rotation circle and directional arrow are \
plotted around either the X (",
 StyleBox["rotc",
  FontWeight->"Bold"],
 "=2) or Z (",
 StyleBox["rotc",
  FontWeight->"Bold"],
 "=1) axes.  The various 3x3 transformation matrices are defined in Sect.2.8 \
of the book."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ef8f25f0-a856-4688-a767-eed688aacf14"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OrbitPlots", "[", 
   RowBox[{"i_", ",", "\[Omega]_", ",", "\[CapitalOmega]_", ",", "rotc_"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Omega]", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "\[Omega]", "]"}]}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Omega]", "]"}], ",", 
          RowBox[{"Cos", "[", "\[Omega]", "]"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"P2", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"Cos", "[", "i", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "i", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"Sin", "[", "i", "]"}], ",", 
          RowBox[{"Cos", "[", "i", "]"}]}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"P3", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "\[CapitalOmega]", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "\[CapitalOmega]", "]"}]}], ",", "0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", "\[CapitalOmega]", "]"}], ",", 
          RowBox[{"Cos", "[", "\[CapitalOmega]", "]"}], ",", "0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"P", "=", 
      RowBox[{"P3", ".", "P2", ".", "P1"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"X", ",", "Y", ",", "Z"}], "}"}], "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"P", ".", "#"}], ")"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{"ax", ",", "ay", ",", "az"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"OX", ",", "OY", ",", "OZ"}], "}"}], "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"axesred", "[", "#", "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "Y", ",", "Z"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"finalaxes", "=", 
      RowBox[{"{", 
       RowBox[{"OX", ",", "OY", ",", "OZ"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xyz", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"P", ".", "#"}], ")"}], "&"}], ",", "xyz0"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ell3D", "=", 
      RowBox[{"Graphics3D", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
         RowBox[{"Polygon", "[", "xyz", "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
      "ell3D", ",", "finalaxes", ",", "originalaxes", ",", "ecliptic", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"rotc", "==", "1"}], ",", "cZ", ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"rotc", "==", "2"}], ",", "cX", ",", 
           RowBox[{"Graphics3D", "[", 
            RowBox[{"Point", "[", "orig", "]"}], "]"}]}], "]"}]}], "]"}], ",",
        "xlab", ",", "ylab", ",", "zlab", ",", "\[IndentingNewLine]", 
       RowBox[{"Boxed", "->", "False"}], ",", 
       RowBox[{"SphericalRegion", "->", "True"}], ",", 
       RowBox[{"Lighting", "->", "False"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.6"}], ",", "1.82"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.6"}], ",", "1.82"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.6"}], ",", "1.82"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ViewPoint", "->", "vp"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8523663694230433`*^9, 3.8523664862422733`*^9}, {
   3.852366611635578*^9, 3.8523666473612747`*^9}, {3.852366682905582*^9, 
   3.852366755284726*^9}, {3.852367646994536*^9, 3.852367651522007*^9}, {
   3.852367738971428*^9, 3.85236775670152*^9}, {3.8523677897918873`*^9, 
   3.852367790855768*^9}, {3.852373058776144*^9, 3.8523730641314793`*^9}, 
   3.852373132482732*^9, {3.852373209829453*^9, 3.852373241075569*^9}, {
   3.852373296718609*^9, 3.8523734011141043`*^9}, {3.8523734750656757`*^9, 
   3.852373512462964*^9}, {3.852373558889861*^9, 3.852373571626051*^9}, {
   3.852373623916692*^9, 3.852373659417144*^9}, 3.8523737289492073`*^9, {
   3.8523741733943453`*^9, 3.852374187854589*^9}, {3.8523780182420473`*^9, 
   3.85237803666327*^9}, 3.852378355217454*^9, {3.852378427937359*^9, 
   3.852378456391492*^9}, {3.852378521972739*^9, 3.85237854111128*^9}, {
   3.852378626405312*^9, 3.852378724845235*^9}, {3.852380825929387*^9, 
   3.852380844131444*^9}, {3.8524493444945803`*^9, 3.85244941914929*^9}, {
   3.8524499495037317`*^9, 3.852450031958137*^9}, {3.852450726669446*^9, 
   3.85245073727488*^9}, 3.852454500790194*^9, {3.852454746401718*^9, 
   3.852454944547532*^9}, {3.85245558340059*^9, 3.852455588319963*^9}, 
   3.852456138679851*^9, 3.852456241646624*^9, {3.8524562768765697`*^9, 
   3.85245629824328*^9}, {3.852456368106683*^9, 3.8524563942500677`*^9}, {
   3.8524565611273737`*^9, 3.852456628517189*^9}, {3.8524582954311132`*^9, 
   3.852458296085181*^9}, {3.852460567306382*^9, 3.8524605750319347`*^9}, 
   3.852460789506646*^9, {3.852464882303657*^9, 3.852464929394867*^9}, {
   3.8524650082639017`*^9, 3.852465024818969*^9}, {3.852465108818759*^9, 
   3.852465189542272*^9}, {3.8524667860231447`*^9, 3.8524667961633883`*^9}, {
   3.852529206930707*^9, 3.852529209185336*^9}, {3.852531035168294*^9, 
   3.8525310373111362`*^9}, {3.852531112988882*^9, 3.852531117108981*^9}, 
   3.852532553327829*^9, {3.8525328079278393`*^9, 3.852532809997335*^9}, {
   3.85253415101926*^9, 3.852534241836462*^9}, {3.852534593115531*^9, 
   3.852534633273737*^9}, {3.852534725297579*^9, 3.852534734550969*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"833cd61d-07b2-413f-b484-11b9829ef206"],

Cell["\<\
Display the final configuration for specific values of the three rotation \
angles.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.88147777434899*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1466ea03-023b-4327-9ae2-52e45c36a7e4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrbitPlots", "[", 
  RowBox[{
   RowBox[{"60", "\[Degree]"}], ",", 
   RowBox[{"70", "\[Degree]"}], ",", 
   RowBox[{"40", "\[Degree]"}], ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.852373814300861*^9, 3.852373831041306*^9}, {
  3.852378405930765*^9, 3.8523784064840717`*^9}, {3.852444574374269*^9, 
  3.852444577013468*^9}, {3.852444706682804*^9, 3.852444710857604*^9}, {
  3.852534280606179*^9, 3.852534282908753*^9}, {3.852534350628705*^9, 
  3.8525343561637363`*^9}, {3.852534642161298*^9, 3.8525346432311363`*^9}, {
  3.852536133481573*^9, 3.8525361345214453`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"b60ad620-4b8e-4c0b-a3d0-430ab0675dee"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-0.07201576178665542, 1.0435850380609761`, 
      1.4648358264288728`}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.4935850380609763`, -0.8514386251926501, 
      0.5331566389068428}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {1.0020067186075547`, -1.1941451067040891`, 0.9}}, 
     0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, 
   Point3DBox[{0, 0, 0}], Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{{3.852378399310581*^9, 3.852378407828208*^9}, 
   3.852378547541182*^9, 3.852380154045643*^9, 3.852380326681987*^9, 
   3.8523808503566732`*^9, 3.852444475401033*^9, {3.852444577906727*^9, 
   3.852444582735711*^9}, 3.8524447115812263`*^9, 3.852446084958755*^9, 
   3.852456433502329*^9, 3.852456603917859*^9, 3.8524566447758083`*^9, 
   3.8524605839977617`*^9, 3.8524609869455233`*^9, 3.852464935821768*^9, 
   3.8524650394836607`*^9, 3.852465141567812*^9, 3.8524651953961554`*^9, 
   3.852465290031794*^9, 3.852466811900235*^9, {3.852466874874168*^9, 
   3.852466900924855*^9}, 3.852467054204668*^9, 3.8525290811178217`*^9, 
   3.8525292146481647`*^9, 3.852530312581037*^9, 3.852531122739458*^9, 
   3.852531339882201*^9, 3.8525314203468933`*^9, 3.852532483658257*^9, {
   3.852532538058654*^9, 3.852532557269662*^9}, {3.852532649420203*^9, 
   3.852532706457687*^9}, 3.8525327733290577`*^9, 3.852532890259429*^9, {
   3.852532957035873*^9, 3.8525329780395403`*^9}, 3.852533031033733*^9, 
   3.8525330732532387`*^9, 3.852533204256501*^9, 3.85253326409923*^9, 
   3.85253343818744*^9, 3.852533975625881*^9, 3.8525340157966757`*^9, 
   3.8525340615950003`*^9, 3.852534107527691*^9, {3.852534265124349*^9, 
   3.852534284798882*^9}, {3.852534351685446*^9, 3.8525343570388403`*^9}, {
   3.852534638914278*^9, 3.8525346434858513`*^9}, 3.852534740384254*^9, 
   3.852536261458724*^9, 3.8525367491478777`*^9, 3.852572138832901*^9, 
   3.852572254910359*^9, 3.852572398723446*^9, {3.8525724446437683`*^9, 
   3.852572474587914*^9}, 3.85257260605926*^9, 3.85257265067542*^9, 
   3.881478279960526*^9, 3.89090057901742*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"416d576c-bb6c-4a31-9e6e-1a4786492f85"]
}, Open  ]],

Cell["Display the initial configuration.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.88147779716459*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b7a09cb3-557c-4d78-a2bf-c8fb0069582a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"0", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8523810615551033`*^9, 3.8523810656207123`*^9}, {
  3.8524592490107183`*^9, 3.8524592500415373`*^9}, {3.8525347624941*^9, 
  3.852534762725068*^9}, {3.8525349550594883`*^9, 3.852534955666621*^9}, {
  3.8525361400892982`*^9, 3.8525361408086147`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"594a663c-15fe-40ed-8e2d-2b9900170700"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, 
   Point3DBox[{0, 0, 0}], Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{
  3.852444549377204*^9, 3.8524445827446203`*^9, 3.852456733470018*^9, 
   3.85245925296642*^9, 3.852460588116181*^9, 3.852460986956438*^9, 
   3.852464943770381*^9, 3.852465044575453*^9, 3.8524652022577543`*^9, 
   3.8524652900672083`*^9, 3.852466911816861*^9, 3.8524670597192307`*^9, 
   3.8525290811407433`*^9, 3.8525292146577044`*^9, 3.852530312595257*^9, 
   3.8525314500708447`*^9, 3.852534763998212*^9, 3.852534956950941*^9, 
   3.852536261517921*^9, 3.852536749169718*^9, 3.852572138846715*^9, 
   3.8525722549616613`*^9, 3.852572398734063*^9, {3.852572444657372*^9, 
   3.852572474600338*^9}, 3.852572606120566*^9, 3.8525726508162937`*^9, 
   3.881478279982415*^9, 3.890900579031953*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"a88cbfa1-8297-44e5-bcc4-e04e8975d0e4"]
}, Open  ]],

Cell["Rotate through the angle \[Omega] = 70\[Degree] about the Z-axis.", \
"Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477853758255*^9}, {
  3.88147788756236*^9, 3.8814778882668543`*^9}, {3.881477923532687*^9, 
  3.881477927882909*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a8640360-e1d7-44a9-9f7d-681bf0595b39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"0", "\[Degree]"}], ",", 
    RowBox[{"70", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.852380420509632*^9, 3.852380420944628*^9}, {
   3.8523809246358633`*^9, 3.852380951097877*^9}, {3.8523809939685793`*^9, 
   3.852381002080772*^9}, 3.852381225505616*^9, {3.852444456386067*^9, 
   3.852444490521521*^9}, {3.8524567435512953`*^9, 3.852456765261394*^9}, {
   3.852459257641944*^9, 3.852459258577326*^9}, {3.8525347731740513`*^9, 
   3.852534773637135*^9}, {3.85253496096316*^9, 3.8525349613784847`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"0f9b85c3-b35f-4be3-a072-a517b5fb9a1f"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.6914467174146353`, 0.}}, 
     0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.6156362579862037, 0.}}, 
     0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
       Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
        "]]},
      Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
    Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
     0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736, 
     1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
   Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{
  3.852380421408445*^9, {3.852380933453915*^9, 3.852380951868314*^9}, {
   3.8523810030641212`*^9, 3.852381009466127*^9}, 3.852381226681816*^9, {
   3.8524444754568777`*^9, 3.852444490926265*^9}, {3.852444553169175*^9, 
   3.852444582795414*^9}, {3.8524567444158363`*^9, 3.852456766218759*^9}, 
   3.852459260356385*^9, 3.852460593584777*^9, 3.852460986969067*^9, 
   3.8524649473269587`*^9, 3.852465047447159*^9, 3.852465205656651*^9, 
   3.85246529007983*^9, 3.8524669165406237`*^9, 3.852467063503601*^9, 
   3.8525290811509666`*^9, 3.8525292147154284`*^9, 3.852530312608665*^9, 
   3.8525314545184803`*^9, 3.8525347743897963`*^9, 3.852534961668293*^9, 
   3.8525362615376883`*^9, 3.852536749184833*^9, 3.852572138859*^9, 
   3.852572255009947*^9, 3.852572398744689*^9, {3.852572444670288*^9, 
   3.852572474614695*^9}, 3.852572606134432*^9, 3.8525726508342667`*^9, 
   3.881478280087286*^9, 3.890900579044248*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"621736f9-05fd-41bd-a5cf-8b0cb2b3f041"]
}, Open  ]],

Cell[TextData[{
 "Rotate through the angle ",
 StyleBox["I",
  FontSlant->"Italic"],
 " = 60\[Degree] about the X-axis."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
  3.881477936314797*^9, 3.88147794091721*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"39ed6fe5-ade0-446f-b09e-9b5a1681b068"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"60", "\[Degree]"}], ",", 
    RowBox[{"70", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.852380420509632*^9, 3.852380420944628*^9}, {
   3.8523809246358633`*^9, 3.852380951097877*^9}, {3.8523809939685793`*^9, 
   3.852381002080772*^9}, 3.852381225505616*^9, {3.852444456386067*^9, 
   3.852444490521521*^9}, 3.852444559910759*^9, {3.852444611157506*^9, 
   3.852444619573037*^9}, {3.852444654381534*^9, 3.852444659371697*^9}, {
   3.852456782558415*^9, 3.8524567892688417`*^9}, {3.8524592640501127`*^9, 
   3.852459265008973*^9}, {3.852534781682221*^9, 3.852534782132825*^9}, {
   3.852534968971693*^9, 3.852534969674604*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"74132f98-8cb1-45bd-8f90-c0ab6a619887"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {0.6156362579862037, 0.8457233587073176, 
      1.4648358264288728`}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.30781812899310185`, 
      0.5331566389068428}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
     0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
       Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
        "]]},
      Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
    Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
     0.19753766811902757`, -0.03128689300804618}, {1.8, 
     0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 0.}}]]}, 
   Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{{3.852444582807111*^9, 3.852444621405051*^9}, 
   3.852444660407256*^9, 3.852456790124343*^9, 3.852459267042406*^9, 
   3.852460598326964*^9, 3.852460986979949*^9, 3.852464950240081*^9, 
   3.852465051815103*^9, 3.85246520980832*^9, 3.852465290114893*^9, 
   3.8524669221210938`*^9, 3.8524670672617397`*^9, 3.8525290811616507`*^9, 
   3.8525292147260313`*^9, 3.852530312618573*^9, 3.852531460082572*^9, 
   3.8525347826877413`*^9, 3.852534970687194*^9, 3.852536261551614*^9, 
   3.852536749199881*^9, 3.852572138870838*^9, 3.852572255058742*^9, 
   3.852572398755088*^9, {3.852572444682293*^9, 3.8525724746270437`*^9}, 
   3.852572606147358*^9, 3.852572650852107*^9, 3.881478280266638*^9, 
   3.890900579056566*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"6239c3b3-73b5-4604-84d5-f99bc78c4af6"]
}, Open  ]],

Cell["Rotate through the angle \[CapitalOmega] = 40\[Degree] about the \
Z-axis.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
  3.881477948281983*^9, 3.881477976797102*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f196d2f0-08bc-483a-9bcc-4bf1a8e01320"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"60", "\[Degree]"}], ",", 
    RowBox[{"70", "\[Degree]"}], ",", 
    RowBox[{"40", "\[Degree]"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.852380420509632*^9, 3.852380420944628*^9}, {
   3.8523809246358633`*^9, 3.852380951097877*^9}, {3.8523809939685793`*^9, 
   3.852381002080772*^9}, 3.852381225505616*^9, {3.852444456386067*^9, 
   3.852444490521521*^9}, 3.852444559910759*^9, {3.852444611157506*^9, 
   3.852444619573037*^9}, {3.852444654381534*^9, 3.8524446713411913`*^9}, {
   3.852456812775723*^9, 3.8524568180126047`*^9}, {3.85245927190593*^9, 
   3.852459272865191*^9}, {3.8525347903337183`*^9, 3.852534792740693*^9}, {
   3.852534981811583*^9, 3.852534982097989*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"7bda418d-e005-45e6-95fd-0290eb895615"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-0.07201576178665542, 1.0435850380609761`, 
      1.4648358264288728`}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.4935850380609763`, -0.8514386251926501, 
      0.5331566389068428}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {1.0020067186075547`, -1.1941451067040891`, 0.9}}, 
     0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
       Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
        "]]},
      Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
    Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
     0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736, 
     1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
   Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  ImageSize->{360., 360.},
  ImageSizeRaw->Automatic,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.},
  ViewVertical->{-0.017549883726549975`, 0.009971094716962628, 
   0.9997962686724381}]], "Output",
 CellChangeTimes->{
  3.85245681879396*^9, 3.852459274082631*^9, 3.852460603530384*^9, 
   3.8524609869914427`*^9, 3.852464954361578*^9, 3.8524650561718817`*^9, 
   3.852465216333837*^9, 3.85246529018519*^9, 3.852466928423379*^9, 
   3.8524670722973547`*^9, 3.8525290811767893`*^9, 3.852529214738916*^9, 
   3.852530312629949*^9, 3.8525314645675707`*^9, 3.85253479339153*^9, 
   3.852534982838595*^9, 3.85253626156723*^9, 3.8525367492165823`*^9, 
   3.8525721388841743`*^9, 3.85257225515536*^9, 3.8525723987686*^9, {
   3.852572444732267*^9, 3.852572474640718*^9}, 3.852572606160508*^9, 
   3.852572650871436*^9, 3.88147828033291*^9, 3.890900579076642*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"c89a4775-3949-4a41-a098-e221182224c3"]
}, Open  ]],

Cell["Display all for configurations. This is Fig.2.14.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
  3.881477948281983*^9, 3.881478020268004*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"96787028-9abc-4f81-ac55-2383ad25ed4f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"GraphicsGrid", "[", "\n", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p3", ",", "p4"}], "}"}]}], "}"}], "]"}], ",", "\n", "  ", 
   RowBox[{"GraphicsSpacing", "->", "0.001"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.85245930229953*^9, 3.8524593023021097`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"0aa0cfc5-2e05-439e-b313-c47398647101"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, 
        Point3DBox[{0, 0, 0}], Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {192., -192.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True], InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.6914467174146353`, 0.}}, 
          0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.6156362579862037, 0.}},
           0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {
          1.6, -1.6, -0.001}}]}, {{{}, {}, 
          TagBox[
           {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
            Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
             "]]},
           Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
        {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
         Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
          0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736,
           1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
        Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {576., -192.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True]}, {InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {0.6156362579862037, 0.8457233587073176, 
           1.4648358264288728`}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.30781812899310185`, 
           0.5331566389068428}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
          0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {
          1.6, -1.6, -0.001}}]}, {{{}, {}, 
          TagBox[
           {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
            Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
             "]]},
           Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
        {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
         Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
          0.19753766811902757`, -0.03128689300804618}, {1.8, 
          0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 0.}}]]}, 
        Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {192., -576.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True], InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-0.07201576178665542, 1.0435850380609761`, 
           1.4648358264288728`}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-1.4935850380609763`, -0.8514386251926501, 
           0.5331566389068428}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {1.0020067186075547`, -1.1941451067040891`, 
           0.9}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {
          1.6, -1.6, -0.001}}]}, {{{}, {}, 
          TagBox[
           {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
            Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
             "]]},
           Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
        {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
         Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
          0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736,
           1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
        Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {576., -576.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True]}}, {}},
  GraphicsSpacing -> 0.001,
  ImageSize->Automatic,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.852459305110222*^9, 3.85246061134135*^9, 3.852460987328471*^9, 
   3.852464960290338*^9, 3.8524650597093973`*^9, 3.852465222203807*^9, 
   3.852465290761191*^9, 3.852466952800222*^9, 3.852467078078985*^9, 
   3.8525290815867233`*^9, 3.852529215083949*^9, 3.8525303131319103`*^9, 
   3.85253149381744*^9, 3.852534801702043*^9, 3.8525349897261753`*^9, 
   3.852536261903882*^9, 3.852536749615987*^9, 3.8525721392109547`*^9, 
   3.85257225571778*^9, 3.852572399085998*^9, {3.852572445058536*^9, 
   3.8525724749605637`*^9}, 3.8525726064869347`*^9, 3.852572651388859*^9, 
   3.881478281025601*^9, 3.890900579503729*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"4527f351-5805-494c-aa6b-6acd2afe4621"]
}, Open  ]],

Cell["\<\
Now define a routine to show the three rotations as an animation.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
  3.881477948281983*^9, 3.881478020268004*^9}, {3.8814781699079733`*^9, 
  3.881478193547615*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ef016f41-6678-421f-b622-b72abbe6859f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"OrbitRotates", "[", 
    RowBox[{"imax_", ",", "ommax_", ",", "Ommax_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pause0", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"OrbitPlots", "[", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "]"}], ",", 
         RowBox[{"{", "50", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"plots1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"OrbitPlots", "[", 
          RowBox[{"0", ",", "om", ",", "0", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"om", ",", "0", ",", "ommax", ",", 
           RowBox[{"1", "\[Degree]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"pause1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"OrbitPlots", "[", 
          RowBox[{"0", ",", "ommax", ",", "0", ",", "0"}], "]"}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}]}], ";", 
      RowBox[{"plots2", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"OrbitPlots", "[", 
          RowBox[{"i", ",", "ommax", ",", "0", ",", "2"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "imax", ",", 
           RowBox[{"1", "\[Degree]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"pause2", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"OrbitPlots", "[", 
          RowBox[{"imax", ",", "ommax", ",", "0", ",", "0"}], "]"}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"plots3", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"OrbitPlots", "[", 
          RowBox[{"imax", ",", "ommax", ",", "Om", ",", "1"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"Om", ",", "0", ",", "Ommax", ",", 
           RowBox[{"1", "\[Degree]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"pause3", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"OrbitPlots", "[", 
          RowBox[{"imax", ",", "ommax", ",", "Ommax", ",", "0"}], "]"}], ",", 
         
         RowBox[{"{", "50", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Join", "[", 
       RowBox[{
       "pause0", ",", "plots1", ",", "pause1", ",", "plots2", ",", "pause2", 
        ",", "plots3", ",", "pause3"}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.852458350392355*^9, 3.852458356923439*^9}, {
   3.852458434703906*^9, 3.852458870996469*^9}, 3.852458918981189*^9, {
   3.852459003903736*^9, 3.852459010371798*^9}, {3.852459055277108*^9, 
   3.852459057275091*^9}, {3.852459128029894*^9, 3.852459145418795*^9}, {
   3.8524606454653893`*^9, 3.852460646031179*^9}, {3.8524606810011673`*^9, 
   3.852460704734807*^9}, {3.852460737852726*^9, 3.852460738555214*^9}, {
   3.852535012589731*^9, 3.852535102096813*^9}, {3.85253615369055*^9, 
   3.85253616390444*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"9dc7945e-0af2-4963-b81b-a46b1e048422"],

Cell["Display the animation.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
  3.881477948281983*^9, 3.881478020268004*^9}, {3.881478204362555*^9, 
  3.881478207954124*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"241143ac-ac99-48b3-b7ee-7f7c40389e78"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"orbrot", "=", 
  RowBox[{"ListAnimate", "[", 
   RowBox[{"OrbitRotates", "[", 
    RowBox[{
     RowBox[{"60", "\[Degree]"}], ",", 
     RowBox[{"70", "\[Degree]"}], ",", 
     RowBox[{"40", "\[Degree]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.852458947708552*^9, 3.852458964300393*^9}, {
  3.8525363698999767`*^9, 3.852536372769567*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"a848fe40-6adb-4e9e-90d4-ad4283ef6ee3"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i11$$ = 25, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i11$$ = 1}, 
     "\"max\"" :> {$CellContext`i11$$ = 293}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i11$$], 1, ""}, 1, 293, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i11$$], {1, 293, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->15.378368854522705`,
                 AnimationTimeIndex->0.42662116040952824`,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 2->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 3->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 4->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 5->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 6->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 7->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 8->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 9->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 10->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 11->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 12->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 13->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 14->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 15->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 16->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 17->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 18->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 19->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 20->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 21->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 22->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 23->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 24->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 25->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 26->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 27->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 28->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 29->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 30->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 31->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 32->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 33->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 34->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 35->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 36->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 37->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 38->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 39->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 40->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 41->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 42->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 43->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 44->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 45->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 46->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 47->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 48->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 49->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 50->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 51->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 52->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk81FsfB3ChR9rQZnejxnVzSepa0yE3e4qWuapbkZIWcsVEoXEzHro9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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7997258512815044`, 
                    0.03141433158711032, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.03141433158711032, 
                    1.7997258512815044`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 53->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3C5rCjJ2kaxKJSetCRddijHtUQ7ucSPRRvrLrGNUpLcEkK5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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7989034886343724`, 
                    0.06281909406450174, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.06281909406450174, 
                    1.7989034886343724`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 54->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk01ekfB3CSJcaSCCOhxVY/mpCx9WSpiDFIyy9E7k9jG4ZBOf0KmVZZ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.797533162558233, 
                    0.09420472123729891, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.09420472123729891, 
                    1.797533162558233, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 55->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01OkfB3CUrGusa6m1bokVW2RtpSfDMsUiKndam24ol6LR1sYouZwI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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7956152904676836`, 
                    0.12556165273942554`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.12556165273942554`, 
                    1.7956152904676836`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 56->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk01ekfB/A7lbWyFZmfEmZkKbshN90nRRKlMEI1lPlZU7KLmu7gkKih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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.793150456565142, 0.1568803369457847,
                     0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.1568803369457847, 
                    1.793150456565142, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 57->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3CNmIRCK7dKwqz9bSLVtiSnWNftQolupOQn3chsoiSVu9Sy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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.790139411662892, 
                    0.18815123388177626`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.18815123388177626`, 
                    1.790139411662892, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 58->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3CxSq2ISpptK7dQWBstNZPjlkukZCllZdMotdFuUkMpyhZK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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7865830729543797`, 
                    0.21936481812926545`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.21936481812926545`, 
                    1.7865830729543797`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 59->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk01ekfB3BJYcg2fhKlGpRt7DGtj+VkazCWZJ1jHzVpcSOJTBqkuClr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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7824825237348267`, 
                    0.25051158172811777`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.25051158172811777`, 
                    1.7824825237348267`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 60->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3BiXVIuRbm0WtqILqQkpPMbxRpyjy4SuUQq2hqRdalxL5cu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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.777839013071248, 0.2815820370724156,
                     0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.2815820370724156, 
                    1.777839013071248, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 61->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01OkfB/BZtxLbmN/OYmPp4lZIsiqX7XFbW5GIhkUtJSuXVDQWm0hy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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7726539554219745`, 
                    0.3125667198004746, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.3125667198004746, 
                    1.7726539554219745`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 62->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk4ldseB/D9JG43UwlXunTITB1TEt2zrnZnI1IUJZXhmnY3CSkqkmqj
pFscVDbXFGWWeVqG2Mew7W0e9mazDbFNkeFEcnueo7X6577Ps/75/PG+71q/
7+/3LDknTyuXLQQCwf/b4vu2aov0yQFkDjjpdGPA40oJIGw+dgZeVLMdHHCc
PnFtarUKeZ+bPMkxfRCoCAaorVXVIn/kHSGQozUIgvVaRuBqPfI/SkTP7ckc
ALJTJmZFmo3IgyP8ooL/NgDkHya4NTq0IC90HVst8mEDrt9oOusRA3n2YndO
UDULDIuLMp3OtiFvWooupa73g2iq7Sm18Xbk6X57V2vU+kGrenNyilcncj/H
NeUY4z4gEjM7//ZzF/L9bcO0itO9gMXbe0kksAc501RZ9XeLHuAy6SwZ87UX
eeyLMLdj+t1gKW7CjO92P3KZSlvffNEuMLz3sZjAJxbyOrs4rbDODrC0f1iB
5DqAXHKRHHGQ0g60RubCLnQOInc1TWuRVmgDVRtL4WTZIeSNW4ivFe0YgLb8
2vMZA3vGRfdTA8QWIOLcpWIbMIy8u46uMUtoBMaHN96RlbnIx22Zgqz/1APL
twbVDnTsVM8FDemFGuBarxHBuDqCvH9VQEaTVAE4moziw4KjyElWlI++xwrA
FcI57q4k7PkuxEhqcRpQ3OtoV6s9hvxanbDGWZNQQLvqnxxTgT1oantKHSsW
ni1Jm2z/ZRx5u3C9ll5rDlyzUAmIL8F+Q2uGX3t7GTQ/NHZERPUD8vJGKVcr
y1ooFsYTkX2KPfpO5EfDPhokZd/yyJ3Evk1Z3Ps5lQ4jim/veXJoAnnlu4sm
Fxlt0CaJIelwEzubrBRpPdsJvUgtoyVp2BsEeUcvq/fChiUPu+007IFXVI9t
obBg4IOZHRkd2L9E/5K1b30QZhLZSd3N2MtyfjXLMx6GQeHuwrlZ2AsNZ4zd
ZEbguQ/WVr/+8D+dJ/XveX4dhXp/TyyIUsLewa8U+PPkOAz/7SEzshTv9548
53EmawKS43d36x/A/tJT6nBwBw8GZu1WpATjc2YkpCz10afhbGaiX2wBrhfR
jBjjTJuFIemniotrcd09cymn1S99hPTL5daXM3B+bI7JGeqemYdjyR+3PvbA
eUszrrjvQVyAPN+jig7bcG4rOgLJRqqf4NLBi5buK7gvfnoRnDq9ZRGqyrf5
s57i/vrndBLnEX0RHqqyp5izcf/++y/rk0qUJVhtXZPlP9SB58mCYkyr6jJ0
UnvKfUrEc0bIIjr5TeEyZDJYDQkWDTjPfrubxJRXoPiFfVmOH0pxX/RYVubd
XoEE2CfOMHyJvPhGsE9U3grsNHimKnbrLfzuWhu2W0m0FZgwQ5R4lFKNPCWO
bTNcvgIFpgx0STlNyP/M8Qr8M9ftyHekZz6xMVqBiit3J621epC/uC3kQulY
hppvb37az2Mhz9OVJBoZL8Ot+V/NEg8NIf/CfEVIjl+CzM9hJf89z0V+pGdQ
1IC9CCm34p/o2o4i523zn5/5dv5KlUJW9j+PIy9ISng8IvEJKuiIvZLo/4Ac
KmQAR6kF+MCUccDo7CRyITKVXCA8D03kTEJKU3nIR386TdRZmIMNQrG+OvVT
yE+9OedgWT4Dg5VNBdWKppGf/6uZV9idKcjsJu2s859BviSkckvOcBIGjL8w
yNs5i7w2fO45c20cKpqGf5EIwr6ZY/g919/9pq/njEMkF/r5nfEy5mEfKpgL
qrs2BDO95e+HTmHnPWLJxJax4VxGie46/Yfvput7tBb2QklvU5pvFHY2ncDc
090Jmwq+qucaYXdoc5pNkWmDg4fK+Cx68b6y2er7ivc0Q3F+3yv08z/sN/ye
vebJ93Ah9Ijeg2Z8PlWAyqVllkMbJVMpqgZ2zZym8LT32VBam3JfMgifc25+
8cUK3hPoSKosqaXhurznts7BXVQQXhnRYcKPfb/FPxJl0/NAf4x4iJIBru/I
9dF3PtfKwQHR0DP5bhPIN+cz2JzPyH2TN7isxAZAktQJ9c/DuXKeso70ymwC
Hq+KzAsZY8hFfo/bVebTCuRU3M+l8nA+7wwsux9YZ4LD6keK+fiwm6c0Me4k
toMco8cCPrtHkMeT6vh3qnSCKto0M+gAzn+nQLSs2vMu0HW3uTrt6DDypMW2
kLWhbpC+f1e6pQ3uoxi/rpcZEr1A8kZTaX7HIHK6/Y5XVlp9QNS6pldqjY3r
68sntKrbDybqqMdt9+E+jeoLPxEnxwJ3skVWueZ9yKWsmJ4Kf7BAVcOpJDE/
3O8R6de0r5aywcDDtp0HU7twHjbvGZv3DuR3T17gkDcGgNxd8R4jATxPUtae
nAh9OAjsFcxdQgyYyMtCSPxHPw8CgwBhygK3BblpbFyKqh0HSHqdOHPJphG5
rHejzvsMDvhXOO/NdUY9cunoxpCwKQ64JFYjfcKiFvml0gJLb+EhMGXxMWQ6
tRL59sPXt0vLDIFcB9Gdc2VFyOdlnJXHFIaAmG/vy+PFOcgVzezWl785YXlL
vviOJOSGqaPyHt/eU+I0IkAlBCNfH4XP7UWGQIt9h4P2/DM0t8ciNX+rmeOA
Tr3mXNPzr/G9qza/ee0dBzhkqaoEt+ch/3/35/8BkHEbZw==
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7669289302057951`, 
                    0.34345619167778063`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.34345619167778063`, 
                    1.7669289302057951`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 63->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3Bkw7osouRWWqSwSNY1J6arW34k7apcwtRK/KREQmGH1Ba/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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7606656813208503`, 
                    0.37424104347196685`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.37424104347196685`, 
                    1.7606656813208503`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 64->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41NsfB/CxJBWVKXGrX/YWS1LKrcEple2W5Va27FS0oCwRd2QvLbLW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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7538661166134235`, 
                    0.40491189781895703`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.40491189781895703`, 
                    1.7538661166134235`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 65->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01OkfB/ApomZLIlYoq2WVe7qQLg9JwlYrt4rsJGIrph/WZV1+GSLy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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7465323072967938`, 
                    0.4354594120794019, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.4354594120794019, 
                    1.7465323072967938`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 66->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lFsfB3C3ac55o05y63Tj6C0SSakQm5UQ1UFUTsili3qLF5NbKYp6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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7386664873203228`, 
                    0.4658742811845372, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.4658742811845372, 
                    1.7386664873203228`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 67->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41PseB3BbpwhNUTnucVRXri2VGAfpG8eanNyKE6UsTRspS45QSDpI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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.730271052688974, 0.4961472404705985,
                     0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.4961472404705985, 
                    1.730271052688974, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 68->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns4lGkfB3AKqSWjRV6VU0lLOaRNIbfDdkKJiTZsazclOpl1ppp2yKFE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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7213485607334638`, 
                    0.5262690685009263, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.5262690685009263, 
                    1.7213485607334638`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 69->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11gsw1dseB/CN3qQ4RSFODELyqFC5liIixCaHa+RVShQXh7ySFKUo3YjD
dL2Od+MVJ2Qvj2yS985je+1t2872ttke28njNhNr3bl37pr5z5r5/Gf+8///
f9/1W+uosyfxBi+BQAj4fvF9vzas9H8S9BwC5uMqmrPkOkDYHPKtegPOI4Pg
55QyEZV5MvLcs4eDfI0GQZSCK0HxQBNyuQZvmVOpA+BDbAXj6/EW5Leq7ls+
negHKWosXkHJduTcYD22hWw/aLq4xGGndCD/NGZh72zRBz4L22zfkKQgbxMd
efn4LhWolod3H0n4ivxiaopsSHAvEBdQ0Twu0I18R2O0O09QD9iat9yB2RhQ
49YNXj7Xc/Jg9iLPKVXQc7nUBejGvBT1S33IX/8lURgu8hXkzUGb/Zn9yD2N
o6rLKJ3gGsPRuXRtAD//rlB5ZGgHmDyVJ0Y2G0Lu4RXuEHC4HZj9ZqlKTaAh
Z8vYxgtcaAH+MSHnK+/QkR9t/z35glIT0EjbRt3DP4zc1z1w3X2aDNIbKi4K
ZmBX2ne1nRhZB95p3M6/q8XAdel4mOQ+C8GfiQWPmhqwHyp+LBoX+AF0Ckol
v7cYQW6tUer+4F0h2MOO3VnShd2XIlbLz58K4tyV+XQsmci3Bo/JzVrSZ+zv
W8SyrL6kwrmCc+oxWqPItRnklBXlYrhmyC3kvMX+iwtZ0bC/Er70i6iWWcW+
282glLpcC+Xst1foXPkTuUGCYcYTjUbo/ZH+7Mob7NzBhk7X3BYIgU+MMQW7
OTmpYCGnA+ZJVd4X4GUht7AoqUpM/AoNmz8V20pjP/1PpSyejB4oYaCVMqiO
/W19glBrYx8Usx/rVPwPPyRXNGy9cwgesDfxr5TEblRcfc6sgA5XhS6kzy/h
9wmIv34+2ZUBk6P4YyTLsTNtvpEzjzHhrFn5TJAL9iVD16qzC6Nw8ceMvJZ0
MrungQV7+Bnxj9ywZ9v2+GSmjkOWjCPv4xpcl9VjscleoZPQhsmm+PyF69tw
VlYu4do03DZ0qD9VGLur2uPtQtqzUHK0mxu5C+dnRkzf4UQUGwrvYCX29uHc
7naPi/r0jznoZCffJieEc+7nQnRJJM5D++a016el8XpZ7HBJM1DkQN2T8spx
Y3g91pIvq2gtceBcZfjwkRtduL7X/Y3LShZgxEMr04VE3DeczL9c5DgsQv1v
fW0OB78gF67hfJbgLkJSDpE0d68Wf5fAip1XwBLU1/TScu0tRj5vnXCfOLwE
Cf81gOfGnZvKy9Bro4xt6lmC7gt7W0rm2y3D6z9p6oyn1yHP3Egeib69DMHy
wRfReS3IxdWP7NmwWYbhz6ZfNlMpyIt+TS+JkFuGpNZe0V3tvch/5HgJ/sj1
IPLxdZabkOMSnFi/ppOoPIz8RSbfeZ3WRThjUM6Et0eQk49yuHVSi7A1oqP1
c8Qo8njuQLHwLwtw7OyIUnIwC7kRfUaE4M+BZXGBEhuG48glhvVs8x/OQ/m2
xdWi0QnktdvCh26EzMGZpjNOPpZTyJtFyVejb7NhzKSpy9qLaeRECT64/NsM
tNyct1xmx8nlXuIUDPPuaBr2nUXu0fBUlMI7AUsuq1wN2sdGXjP19HVIIQuK
CO3dF2mK/YOF1C2a4yg0lBMQIv2KndjnoXb90Ajk+qkm3XuKfTPHcCvXW/4p
uTuAaj0IfULbz7oFYDf7ucXX7zAVMgmX68ttsH+hKVzJ4umCq86ktncK2Bcm
g51ihDvgzfN/S4ntx9+1YHMhn5rcBEMJgeqrJth9oz+K379TB0OlLR1tc/H/
EdCOlXRWK4dtumGCZ5bw/1Q9qaTBCcqGx7JWGlfUp/8nv+uUB74Nzrgujy7p
/v3NwSyg/dwqOClyErmjEjuPeqMMEEx2Semk4/q+1zhxqta4GpAKVqMu/YHz
4E3iDby9rx5wZM49ka8fw+8T8lwrO/wzEPcVD5Rsxbna7M9gsz8jd68u8rOq
awdL3VMrv3fhfI7V39pTFd0J6M/8FPi7mchnVSLj505/BYyRuB7NLpzzNU5a
mldVF7C3nl5pozCQ6+8XPVMg2wNMZxJDHTvxeokMrVMW8eoFa3tvDDh10JGf
qg45THhLBRMGr0i+aTTk5jb7J/4o7AM1e7VzHmTg9XiXJT7pn9MPPH7MeL0c
0lF1ezoA+PqzzTqLqMifqD0xSbcYBC+y88Tmq3qQKz6LMDjONwT0c/sYcq1d
uI6PWRXct0PgnjGNv5CB+8YAzznpKVkacDhQsxt+68D53DxnbJ47kNP8X118
yKWBE6qTzQv+zchfd88uNkvTQeRCFjmH3Ih87rDcOyddOlAcoA0ek6pHHvC8
MMToKh2Ao0aeIWE1yPONgwManOhAgNgURvy+n2+5skdCu6grHWjItu0ybXiP
nOdfpvu9nOngwZ20N5nRecjF/I46bFjTQW+RrrfozSTkwet6pTN6eL/ZGhwt
QSEnBTrImAm0ixdLwvt7i02Wz046aB01C81YyEWeQBSTCv5IA1knr64rir/H
/Z+f0p1hRwNeamH65jkVyMvP7TgYNDUEGJaxzDuvqpH/v/PzvwFSnAm1
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7119017293312764`, 
                    0.5562305898749055, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.5562305898749055, 
                    1.7119017293312764`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 70->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41GkbB3BJ5BXRshQ5FTYskq3JxuNQsR2GsmXEtquypSK8QgflFL1K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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.7019334360787703`, 
                    0.5860226780228821, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.5860226780228821, 
                    1.7019334360787703`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 71->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk4VeseB3DhEJXscs0nEdUxdZKZ6z12oUE3lJnKRRyFc4+5W6adTSUZ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 72->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk01OsfB3Bku+kSl/ZEliuUn10Lj1EXN5TtJtmlCKUoqZus3Vt+FZJu
juVoKMYSrSZxH5ERZiyNmWzD1zLITsy4N/FzTuZ5/vp9z/me58zrj+9853ne
n898lH1DHE+JCAkJXVm516zcYtRl6cFeDjjAbNoRPUUDQqvX1S1u1jqAA2aT
JVtEpRqQX8lcPH81qRs8UrHLqt/KQN5v9lmqjNkFTgTtXSDWtyAXIgmpMiS7
wNzM6eqgu63Ih37/HJKu0wksJddTLoozkTeZ1l3gW3WA5MRmLW5EG/INb9pS
ih3awcKDau1sLgt/75j1wRjbT6BvdRW4pM+PUrtN2ECmOkDYvbgdefTQ5lJf
eRZQb5rf9VWiE7n4kfsOjQQTJBxKZu1w70JuR9FJlMj8CM5vvBsfTelGPp72
glpi3Qoyfqnc+mGKg3zswy75fFozoJupNNzf04tcn2Y2/U87HVDXNgW+1SOQ
z7+uUXWpqweps6Qn/HrsS8Tz5RdJNLBt1sauzL0Pud7bxL0L+jXAgVQRRRnF
Xv5zjaiwNwRs2+rQsLB+5NXf6vvNJajApGLb7RIe9qUT4NOvbqXAkT8bPB42
gJyuFOLr/iIb5HwrHi8cxb66exUGruWivicGkT/UkLW0DXgE2w17n4ZVY89/
NRO+ofYZNGe1Ug13cpHHu2Y5rzF8C+fWTiSNRWD/q+zPRX5sNSTL3JSl1WKv
vKVl2pxRBxPUPR37JYaQX1tgmleO0KFRTN8tazPsZxW7Nmbrt0LRBiA15o89
mDYpYr2uDX7Jdr/wOA67k0n7Z8slNuz0UpY6kISdTbthefyHTpi03Yzsdhu7
9oeZLL42B14+0VyeFo6dHxyzU9OAgBPSRucv2WF3X17qVub0wQZSxmZXGewb
G9t80pIG4Fpx+lBGOf6961UKChPsuFDu+4o8LUC0qUBuGO4Z26Rwkob3WSNH
wdCnZwRWXrWO91PBnhMqNPn301FIZxykM33xOQ7uWnQLjxmH0sX2EhJxOA9P
suq6mU6TsGLP86LQWJyre1zvZTfZaWjv+vgfqhfO52uWptjh+Wm4yyPS/LJ+
D/IHJlWcl8wZ2JFWIublhetobqfcHf+CWajta6XgZ4Hr8S1h9uxr+BeomDZZ
/3c3rveu9y0ThNEcVBEJsW/VwX3jfSQn1394Dvr9O+dMvob70sKbNq3mG/Pw
IoxIZW2qxnnLrzrnIsODwYdCFEOiniO3nVOj/BbDg98/JR0QeJDE0XibDh68
aXt3mKbxAgr85OmlxGV5PrT1Lg24FlCDXIQYK0vVW3FlUgnZj4Gclf9865P/
8GGg/v6c62VM5FMNLqn20nz4+yO7BfnX7cjFIzOO2DTyoCL5lrRINgf59xzz
4Pdc9yF/OBpnocqdh5UT0dUqUQPId8AiavyheThbbMMwLeIi51DqJtVuzkFm
VNOM5ath5GwnL4+051/gfx0mI/1TP+PndG6bbqbNQuOmeuFX1mPI5/cZ316q
m4G6UcpVB+njyDdsSbgV82Ya0tacKtFSnERu2CbeE2M6BQ1WV4FvKnBd3s0b
hxq5ulMqCtPIKV0RNy/mjMKMKqtXlFDsCWpnMlxsRuBP11OOb6JiN1GaknT+
woXu7zhd0UPYK4pDmEezB+DVPzbH7lnGflkrViz5WB/s8zEvebBmBvlqjqEg
1wLfPvUbo6CjAx6PtNMbZmEnoneSMnJZ0HSzzQuZPOxJVZ7rNjxshUWqg+me
gdiv5WeQW842wr2O91x9lLGHO+X7S4m/h26DOvdV0/H+HP+JbBfLewNHBgb6
KQTez4B48tj+fRSoyitUH1bALrgW7Nu5+00n8HtKT4WL1eaBFp/ti63H8Xlt
gSE/XP+xDBh6b/XICsTnm9IR/C2xugp49ShzfS+OIpd31DpplFcLinaQR0ov
45wETgjvizVuAOWedPPxSyP4PfU0miLCm0DZNCf7yHmct9X+DFb7M/L8+8Ja
f67MAXq1d62eeeDcviycKr/zqg0sCS9ZXHAcRE5Pc7pjY8EGoSH2Nj2WOP+R
QaKMo08/AflTslvu7e9HfoU1927713bw0XycIqOL60heV9ZDU7MTmKWaMGt/
JpDnqkmFdR7oAkGPfT1VzHuQn74t9keMQTdYXZFbXs0X8ZHjAOMguVG13Z3I
9TTtOvI+ccBG78qsCE1c744RuV6hN3qA3r8P1BnabOQlpCuBDdt6weGiRotT
Bm3IuYzl5LysXlC39vLFMNJH5IshtAa+GAF8O7KMtju3IBfMGatzB3JPVb9z
QscIkHmti2qlUI+cITQUoXSeAGNnSClGHrXI6ymjx87GECCPHJxCL32HPPNU
xa+6CQSYHSHJSSlVIDdWeuZQsuLZ0wWeBfMvcV2zrMJV4ggQva4+Ovd9IfLY
dmOpmjACTFe5ljj/lY6fc6l9psJd8H8TXSHwNbbh7L1mK15q4nvbNB3188ka
hzPumwigpJMiIS9biPs8m6Qex+4FKVW8X/K1XuI5kL3+sPC5XmDw+uXrcWo5
8iA3DUkXfg/QfceigIdVeD78lpKdGdoDeMR8CqivQf7/5uf/AVmJB6Y=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.6804447676949632`, 
                    0.6450623091815405, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.6450623091815405, 
                    1.6804447676949632`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 73->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41NsfB3DRxe2xdG1dtCBT6aoky0+LY2t+lxaUirgeRtxSiCgpN6WL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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.6689309382202173`, 
                    0.6742918681486416, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.6742918681486416, 
                    1.6689309382202173`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 74->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk4lWkfB/Ajy5wKb4y17K8iZdAIg9xSdJIWIk16vWVnMtlGlpjINpbk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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.6569087362143926`, 
                    0.7033160312806928, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.7033160312806928, 
                    1.6569087362143926`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 75->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11gs0lOkfB3CNSjJadgtJoXJJtKJNJM+spWIpW4rkFuGIYm0IFYVBibIu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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.6443818237566816`, 
                    0.7321259575364404, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.7321259575364404, 
                    1.6443818237566816`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 76->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41NsfB/BpU0oX1bjIcpUUWlD8VD8Ol+xLxpLtdtODqFu3zZpUFBK/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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.63135401666597, 0.760712871133259, 
                    0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.760712871133259, 1.63135401666597, 
                    0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 77->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk81FsfB/BpRLLEjQppTwiFS1nilBBdt4RIPVomlG1oE6rnsZbE5Lo3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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.6178292833385006`, 
                    0.7890680642203395, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.7890680642203395, 
                    1.6178292833385006`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 78->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nlQk0cfB/CACFQu0SLCWwMICgUBjVaRgCuWVxBBNJWr5RKq4kgRxPfF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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.6038117435390622`, 
                    0.8171828995311843, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.8171828995311843, 
                    1.6038117435390622`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 79->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41NsfB3A3S1Gpbkj52apfKsrWVBfXsTWhXzeppm5kLWtMsqvuFbpI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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.5893056671460686`, 
                    0.8450488130146034, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.8450488130146034, 
                    1.5893056671460686`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 80->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41NsfB3ATkkJEy5Wl3BAiI1HIKZTwu1d3lJTlarGkdNVgLMnN0s2Q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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.5743154728509123`, 
                    0.8726573164434067, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.8726573164434067, 
                    1.5743154728509123`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 81->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1nk41NsfB/ARZYnIo26WSp5UpO1Wsv06li5ZE3LdlJv1cgkXP6WLX64r
S+Hy009q7LtC2S4yTpYZkj3LzNhmGGtkhqFF8XPFOffpfp7n+5xnXjN/fOd7
3p/v5+yz8zBz3EQgEPxWL97VK8/IauJWWR8grFX7+kogmCVqBYbS6OB8dlRf
uUcH8iufv7OLn6WBWFOO0FxvJ3JyjatW4nsqcKSXi6WrdCEfdas6FsztBVJR
xcdIMd3I1br1hxVHesDGuuFyLdpj1+u7gXz9Jf02JSry4xXBPbsfdIH2b0b+
CHGnIVfuPBvDZ/MaxITr6svm0JEnc6I9WDs6gY/nUpEzrQ/fp5l40E3YDmZK
ypZ2bxpAXthb+WiypBXQQ/e6cvcNIj9KvKQj0vIKGLxMC4hTGUJ+h5tNyaU0
grie2YVmOQbySNH894RUMnhfm2Sin4H9XYZ2rr51LWh0P1wbKMtEviXHIcl2
kgSeRAoU7Y/HzgLyjFJqGfC1Ua+e5B9GThwoNorfXAj2G9qKenthF4ik+FjE
J4OVBa046x7sG3Xq5F81gjzjHuONgG0K1AUEdkAY9mvKpa63859CQXYMf3E3
9s5tedN5Nyvg0yMGvBpSLOS0MtZ4m34NdAuYonhfwq7k0MWcXCHDIcZnYuYd
7N9PV0nrDDXBi7vk9YTzsT8mBrpYTbTBc51XJTsasE+QnYVIkZ1w6K6vwtYe
7DZxKhbXNLrhVqpTUvXf/EtR4W1V7aP9jdjHrluoXKHSYUjsUr/mY+wH03g4
m8gD8FjLSfEyf+w8sr5H0u0YUEyzU3ZOHfvDIDMpyWkmZBjuuJYwjp9P8sjy
RxA4AtdX5KIFH9jndo3CwN2qKW7Lf9vHiK1ReyrGoN//HLSITtinXkn/GvLj
BCQwUyX0SnEehu/+lzUtOAWnhHRFxidwrr707xu4vPJX4XzWx8Z8z2M/A6E6
W8d8Duc8Eb488054Ftpd0BE7k4X7gkUwJFdYseF52RYfX0ncX7TC0JW4Axw4
uNSYbWWA+xSkH5I//ZYDhQ3/I0g+8xr5TrKQf0z+HDQQinfpqm3D+Zkv1/Wx
m4ds8GCkJboROUliZvy2EBey9aJLx2gvkFuadXM00rmwPVyMutfkGXL1QsJV
GcUFSPiq/MPecP8gLsDyprQTJ/YWoe/Fa+ZfyrxfgC9yzao5N2uRRxjfVvpJ
bRFW7dFLOqzYjFzn2HZbc9tF+NvIARlV/tfIn1VTJr9xXYQJ3GTD/fxU5OGV
IUsWlotwwF0me5l/AHmB39mwQ3Krv7/fSNy+zEAencWrdbZ1Ab7VrWDBn0eQ
73TLkaRfXoCvo6WlCHWjyL/kmLv+eQK5+5G+n0mSXOj42ye/q9JTyEkf8tm/
X5iHNsTqlMui08gpldY9ZW5zsNjlF0Wh3hnkLSUu3v/y4cBvS5atf3GfRX63
ZrDHxIUNN9YNPzv/bVRK0lu4aeFAWQ+Bg3y6SdXW23wa1vIFDzoGYD+ulOa/
8G4SahoVFIsNYf8077mZEjsOvXhtgM2BOeRqa/s7Cn1teCpVLLArbblZlVs3
DNVLiZL9LtgrNUzVf3dgQImP1aN1ztgvN6fFnZbrh772ZvYJZtiloptM7R72
wpn7wmw5BezrOYYbud7wByucG5nLLVBZMEU6Kx27huEy6ckkGd7LjF/UNsQu
UFpPO+VWBfl0BQsaxvBzC9P/VHk06TH0983jUm+w/5HftfZdwc+/MaTVOnUl
F2gGVQ5c4MEuoRGzx+5EBWjXDNqmuoj3sawx0/KVYS1wVdkhIsHE+y7wIeuZ
w6MG4E9WC1+qe4PcvlI2Qz2iGZwR52e1puD8eI55i5Ii24FUr27wab9J5Lf2
ijw3yO0EVS0D+WkmOIcXLxaTEhK6gF5zfdEPcuPI7dqDZSOu9QCR506KXguj
X/1fKlh/PyP/aBVi3O9HA6X36W4Oibgv0gTs97xro4NH3ZoC5d7DyJuTjI2k
+foBffPmU85GTOSa0SHHeXcNAEOC672Zg7jv8qK361uKDIL1FefzXHBi9ugg
GFL0ih/u6EM+pRtb7ZM2BE69CJAkJNFwDm+kpsSuzvv+wtAuca9e5A+bE4xD
fmKAIF+LSieTbuwNPPJPUxhgbfyexO+TsuMvJbNaGWB/TwFIku1A7hG87cEs
hwG2UNtuBB5pRa6cxkcT2soEe9ozidqHm5CfM6ZoukkxQT5NceddNQrOz/o5
Y/3cgfy8Suh3GbuZ4Mln4S0UKRLynKssUWVxJjA1L1ezTy1FbskaORSyzADs
qp0H98U9Qc4Z7CXRh1c9RME7/SIRv2fWzld4Pm3U6MF8voQ4Bgj795Upx9ZH
eM4mG4t52q369bT4rMjHyNm74jmKCgxgZzydJHWrBLnbn6ZRzI4hkMPvcqdX
5DnylF71e2SdIdDKxzI/XYPnSIDLZa5KziBotvwxfMd0HT7vbePhcV4ZAM7s
Wpki/gY8T9Ukf/XRHwARCk4ERYkm5J5kIxnfO/3gc7mhR9z2lq/m7z/Pz/8H
J7H7GA==
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.5588457268119895`, 0.9, 0.}}, 
                   0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.9, 1.5588457268119895`, 0.}}, 
                   0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 82->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01OkfB/ARuoqkLEkh125HbG6xT0qqn938QqI2UdnBilDsuobkcpT7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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.5429011412638023`, 
                    0.9270685348380975, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.9270685348380975, 
                    1.5429011412638023`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 83->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01OkfB/BBpW3db4USRZRcs11UHo3LKQpZbLclxZSktuQSkUYq87NM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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.5264865730815667`, 
                    0.9538546756197689, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.9538546756197689, 
                    1.5264865730815667`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 84->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns4lNseB3C2y6FQKR2SXMolpiJJRKuRculQHB1R7WzUSdmi7MJhyK0e
W9hJ7coWtorIXS7FinIZtzGYwRhzc7+FYYbOcdk9D9b667zP8z7rmc8/s961
vr/fWuruNx2v/CAiIhL4/RX7/jIP5GZ60BlA5a5vV+7PVCCy9sRQ9kmEDvWA
YHsjj39R25E7RK+USI51A4JAYqCd0Ik8YuMT1iSnCwhjRwnKYTTk8zKabqpN
dCBcG9c99E3ZDlImDZQSqV4Nst3IE+IpeoMBnaDNvN5v3qoHuerwgp6OWQfI
C/A8ERXIQO4xrvnzVj4V1D7NziKm9yKXK3x61Pt5G8jk2VTxq5nI1U5oW/G8
WsHYuIyuU3cf8sGCvODi8CYQFO5ybvsgC3mri618EakBtDkdu983zEY+5kVM
PHypFrSKDAWo+XKQ77r3XPKhSg2I0TGlDQxhDydXSQtDKkGjZnbdgjMX+QPt
6xJB996DxNvWEls+Y3cz/uaz+0EuSHsQ6tOjzcP+WeZ8yOaXQF9U/txcFPa1
1fsYU9FY+42JXYodv9C3NRWeqvSrvkPoR77sCrpsLuRDx3m+98Rt7PRZM1qK
oAzCC0QTSiH2Li3t4oOTn6B1wDGJ6BHssRQ2IzCqFm5+zDLz2jaA3HGnlpqJ
ZSP82jDxrdoI+8ITRtnQXgp0O2BJIJ/GPuN8YL+XcjtM/Lqd+voc9uLsqYqH
JZ1wRXTZws8RO41lMuzo0QUnUhXzCETsOYU6J6L3MODgn+FVjWrYraVDnpMX
mPAjfSBadxrP//3DM9ExbDbkp/Z0K+Zir5MFgYs3uPDwf23/5uCC/faGEivS
NA/6r47IN4zsePY4eABGBx9oM7+FvYmYrOSyaQheWFlmqvfh/VV543In980w
3M9rbio5gF1Xut/GxHIUjnbwQiKu4fy48ea55/vHoO5R02uHZHAOvQnmKmoR
E1CUZam3Xw7neWdWcIm9+lc4p6akdLkT10tCTqPH6Q9T8NHEdv3/XMR1d0zp
dNGmN9OQEaZBTM7A9Tt8nyBpemMG7nPxCnHPxn0A9JJJNjp8yAvuXdLntCLv
FshJGzH58LonbaVosB6vZ0BPNTlyFnr+xl256/UJudVNjfQC1Tl43Dj0ZDs7
H/kZuqxcyNs5uPor9eO6B7RcC8rTEEA3y+SlpbICuO4L5Z16lCgB9IUBSTTF
GuRsobDjLlUA9cvnKoxeNSHXEJ6NuikmhP/QMTW4UtqOfMSetbtSSQgzftI3
5ed1Ia8x/EUHygthS1YOXTufif+3gG9LnBTAXKNL2/1pHOQTp46HxWcK4It9
4mwDm37kajCnLNJSAPnvTreY5wwiVxezWEisnoNx4pJXns4PI1/N8RxczfUY
csp1zcPNHrOw8OXzRSphAvm1Gi1ibSwfnmU6iws2fEXu1hun4JoyAyWeyR62
qphC/vhc1Lu4F9NwfVx3k43h3s6bpuAZe3URHzCD3CBU/dOJ5gkoNDWOXa7H
vpde2s/wH4NXfQzCxY34yN0ZQWnzm0ag8LqPdU009s2KZlk6GYPwssoGhfFK
7CbG3Vkxxv2QdHb61qNe7DU6pY3ZFA50ijHbuIOLPcLEnDjDY8Ij92Rnd7Vh
3+tupeBp0Q3nNOQf/vst9nS1qmbalw7oxSqntPthX8sxXM/1ukvJfhQP+q0O
Do40ZBZQ8Pd6WqfBAutK+HuWQ8SAF3ap0vfqBndy4BN30tPXC3g9V58EszrD
ri3pIdilyFPW9U1vwa4h+cnaObwvTlvT7cKF5WC4v5+XxcH76NgW5bfYUwMM
q3ZORVZPIg/T99wq79AAymwsBrOe4TyUCz88UvVoAa9eFHrr3RhHHic5cuNP
aSpw8zguyzbGuXJ3E38XebAD3DKyWnETHUW+L8UgYNt+GmDxVvwUyTifTke6
R08t0wHjsvpGs4Qh5JaPS14rvuoG+nZmfnRnnPO1/gzW+jNyh7NB/lGkXhAz
Sf3cPc7D85FLJa8UM4HBWxGZtHIu8rTAPbmt5D4wn0JPyozBdSdlMR9aVsUC
ayPy/orz932S2IAoldik7Yvr91jSkY5abQ7YZrDlkq4uA+dTfnurzV0OmFei
7iFM4j7gZVZ56Vs5B1yVdDMkldOQx1r/ukya5oClpcfvXeM7kFsU78kOVOaC
Q1EXw0Z8qMh/TCGphxzlgmdicZbB+a3IlV87m8o7cEE+9bID+UkjchX+abvS
i1zwP07hSlFCHe4/9xnJnB+5YNH2ppJWCu576/eMtXsHcn+xg0Y/WXNBc/zJ
WYmhEjwf34CEW/pc4CSRaPr3kRzkxxsvEEI2c4GOIP0XvZRk3Me+iN8mj6yf
T2Fm664Ki2x//74+itVXi/1kklE/z6JZ3dkdwQGRMuSwjC/ZyF2vq03/cfK7
K5DKtVKKkR+x0waHRDkgQ0GdpmT8Abn41YlflbzZgKyvOUOl43OkPsJeMaGB
BVL6p18piX5BbiQ3JfaDIgtQxj+fTNqBzyPDf44GP3ftA9Splyo3dzciD/xj
0TcogQlSd9ulkJVbkNszOIKy8l4gxz54lC3ahvz/3Z//AqSwEE8=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.5096070223017632`, 
                    0.9803502630270488, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.9803502630270488, 
                    1.5096070223017632`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 85->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0lVsfB3DDxb1XrzFl6JrDLSKrG+La5i6p0KVkyJCZXKeQocnwilSv
FF40kV4yliF1sA0HoTimznFM55iPODjH6Rapt7XS3u8/77PW/uez9trrefb+
/n7PVvIKdfDh4+Hhifo6+L+OAlbhm6gkGpDcEE+Ym+oFPJvPD3ROQkDaEDCd
TPBxsOhHXjh5MXX+BhUYUwpcnXMGkFMphnuXL1FA/xZP/lXmIPJXNltzfU6/
BdDid3kJHQryXTEOUnuMBgGpV0Y6N4SK3Hew0nKn0ABwtdQPJ+QNIX+QXBKh
0NoH7r2SMQrppiEnrdzqZ4b3At3ndQ4uK8PI12MeltrIkEG3WFc3r/AoctVT
PCn87m9As9BRPTm5MeTq95/opoV0glvDyTVOSuPIeUlhyQUe7eC2mM3dYhE6
8pixgle5+0mgbBaaOidh33JuQLWD1QiMDs+KnF/DbtG0QJ0VIwIaRVaV5MdA
Xtvo+rJeoAp8Dl7yXOnGTk0NmNsWXgRSm+3bn2hPICeHJcfzPr8NLgqnt6Ql
Y+cxyfVtEE+EN27kXvh9BPu+PTJ24yEF0Mt3VOyA+iTy/RnreSvilfBq/KdG
oUDs/q9NImqriPBq+spO2UfYQbaAxDG7Zigmx3SgDGCXnLUvj33XBrcTDq1n
rGP/qPh3skdJF1xSCsl+uH0K+f1xl4hKazLctXcqX1sDe+2nl4b+5D6o0WZB
8tfE3sBvq+wUOAgJSppG3irYbUQ4Fr7bqfBupYiXyhbsueuyba4UGvz0zPhk
zjR+H7Hq1FO9RaOQoiMrXVyGvb0+K0byIB0e1zCDir7YZXXnpZqaGDAp8JfL
L37GPkbrDDhlMQm/yOSJquTgffaZadHT7Z6CZmdMxzeksDNryH227jNQ8OIt
Y3oUPl99giPhGmcWzqim3j7ZinPi3by4PzWVCctU7Js/LuIcCnrIihaqv4N7
DYkEoizObae+E/Fd8wJsF2igWYqMIP+X9ZSVuCsLxkdXCUi34Tpa3DD0jl5e
gq6nM003AK7HDMed2zMaluFDPj3Wr9G4ri/fWYvzvbQClWyeKbiexf2Br+Vg
Wp8+G0YEC1t9cXyN/JGFmWfvHBs+2H1CpcisFXm9vILL3uscaOdeXO7qTsS5
NQoVuq+yChWZycEGVx4jTyEcaS8rWoX0nj9jDKUyITpf2J7L3MGFJ2qUTTTv
P0du9lSafzSaC8Uy8yP8ZFqRF0aeztRq4kL5K1EpH8q7kRfZUARLFrnwiqhw
nYTJAHKFJiufoM9cOJquV//JYAj58Z+tGykrXJgp/Et0vMEY8uFt9nFdbVyY
BTSEX2YxkMsctN6aF8uFdzbGEz/+NIVc3+OJlpUkF3L6EipCA2aQM8NMCQeu
rUKdxuQTihVzyL/lmAO/5Xoeuf17+2kZVQ5c8yKGrFMXkLPApd+W/mBDYuvd
gJRyFnK3gfQ3HU4rME96Z7nR7mXk5q+JxGq7ZbjHb0pqxzR2493UBr5zLAjK
/+mvmrCC3IVvzsVUcwFO+JME84TYeL7Wn6VKvUzYHzhV7R+KnbScPhsTMAul
Y2t/7SRiV9P7jx51fQpGMv30ri5iB7zmYdY3JiB7IEaQJMBBXtKtpWmvRocL
TYY57/7H5w/Dpuy0YXhytWLt8RJeR4l+uWeU8xbe3Wf+vpWEvcyhJzE0ug9e
eH8mRDsJ+2aO4fdcf/eRR7YtHyVJsOvJfET2MN6HhMishrrAWriRViV2Ogw7
2fzDwNO1PLib53Ls+3W8n8vhW164B90CUezeyI1Y7Br2gSE3h5+C91/+ChNe
WEJuG9XYq2LZAOTH65q5ZHyO+lpGa4KLJPCFXJh4uHgRr29LbTA+2gkK0x2P
eF/AeQhqcytbP9QD3ONyW6ys3yH/UeSspgmnF8yp2w13iOFccU/Rg38THwDq
HYf6EwZxDr3C4Fon71tQepyQTcuaRd4Z/KbmSxsFpHvuCtlwwXneN5F/echr
CJwtd4nkKEzj+v3Wn8Fmf8bf+2yelqg2Av59MOxiRekEzrPxxUFzh1FAuz2j
3HMe1xfN3K7ynOsYOK+br3D+a//+7uKKQdcnrMbBgyCZCo19uE7HfHe8ffAT
HfjW29YuMYaR60koFWZ60kHXdrPwjixc70l+nYnSJXTgtNEsIudMQe47ct2K
xqQD1R/O79dWGUTOEyQ7kSTHAFVx11UP/N2HfKtydn6jKQOMB1B3uA2SkQd/
LgqXdmMA/oQXosdi3iCXNWAC6TMMwFrKdDzo0YFc+UdvO+NwBpB4tVUixRn3
N79p49efCQxQH2jC/uTbhPdn856xee9APlsHkpeOMYAxXzztr5hK5ANnkjyH
9BjgD12XcB3ZQuTh1xxreyUZgEyTOntSKh35zZuEYsU5OrBjc4+KTMahvu3o
zO4TrKaDqj6nBbOnecjP1WTk10fTAf0fF6w/aFfg+Y+Pd0Ua0IFO6rlc9kQN
8lhXsmjLxDgQkba/t41Qj/+/FadZppbj4I586doyqwl5mVtzS0n2GLiZE9Lh
LYn/O6svDvEYTI4CCUciJUPtFXKCBCtMXGEUpKh1sKs1uvB7qujUOh0ZAT73
LCqmZLqRb/NIKFMIGwbFTkJt8hfIyP/f/fm/UWoYwg==
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.4922676305990752`, 
                    1.0065472262473445`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.0065472262473445`, 
                    1.4922676305990752`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 86->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41NsfB3BluS2WqJGQbENliRZK5ZBdN+JSqDRJQoufJY1fkqVslStL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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.4744736797201852`, 
                    1.032437585431883, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.032437585431883, 
                    1.4744736797201852`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 87->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lFsfB3C514uj3nPcJaeQS0huHbRVR40oTLo4ulDJKbdTblGhNETR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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.4562305898749055`, 
                    1.0580134541264516`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.0580134541264516`, 
                    1.4562305898749055`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 88->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lFsfB/BxSR2vkeuoiUJuFXFKTm/OsVF6S1EhcWpJ5NIhuZ4wqQ6T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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.437543918085127, 1.083267041673687, 
                    0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.083267041673687, 1.437543918085127,
                     0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 89->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41PseB/A5dSqki4SxhbonpO5YkkS+hI4t2g+RaDsSV1mypAhNYy/L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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.4184193564920995`, 
                    1.108190655586185, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.108190655586185, 
                    1.4184193564920995`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 90->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns8lNkfB3ByiRVJP8pSqPxYXYili8thf5psF01EhbRkkWbTCq3LhNCW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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.3988627306225476`, 
                    1.1327767038897074`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.1327767038897074`, 
                    1.3988627306225476`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 91->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11mlUk8caB3BatKAsYQdBq2DcQAQXrLbRoVxkrShRe4GgYlg0itJapHAb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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.3788799976141604`, 
                    1.1570176974357707`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.1570176974357707`, 
                    1.3788799976141604`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 92->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk81FsfB/Ch8BBJXCWumKwtJCWEMxRFpZq0iKv18kzRQtd2lZClsnUt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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.3584772444009896`, 
                    1.1809062521829132`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.1809062521829132`, 
                    1.3584772444009896`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 93->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11gk01GsfB/DhCiVLclFR3ChRcUtdSfeR5cqWSG5vEYO4XqKilDtZblla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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.3376606858593096`, 
                    1.204435091445945, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.204435091445945, 
                    1.3376606858593096`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 94->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01FsbB3BCbh3lEOXQTaZQpKWIxnbk1Nsp5No7cksKvSkdklDIreGl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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.3164366629145068`, 
                    1.2275970481124974`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.2275970481124974`, 
                    1.3164366629145068`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 95->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01FsbB3B1ikgnQqpTkmsdIlIh2e5lxSsqR2gKg6ZTeXMPcTpSDNGR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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.2948116406095722`, 
                    1.250385066826195, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.250385066826195, 
                    1.2948116406095722`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 96->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11glMVFcUBuCRVYUSsRjAVIWIYhtUqBSpSN9ojFJKZcDWpdDK4oIFpQWD
Wor7grKIIyORsmk0sdJANQ60VD0sKgMCAnXEQZZhk02mDDNUsEZq0vnvTUj6
kslLPmB4795zz/kdw6IDtxuJRKIDbz/Gbz81Xod25OQ9EXAXGa6ZOZZDplFK
QXpkTJNb3cTcZdS0u9HlsSA5OSE3G3jKfOriD3NfdTYK3bdCZlW+UTHXa3eU
R6Y2CG/EIqfaqc+Y203XZlktrRcU5l3i1+YtzOvkt6Ymna4VwpUfy5a85l59
PD+kOadaCJf7JLv3tDLXpicvK8muFOqirMWPy9uYZ7XNvvvoxD0hoqlIpUhv
Z35l0C6keGOZYG4jGQlZrObP2bdqpoXDbSFr++1P3c5wX7ij5/DZMLngZDQ/
Pk/N3c/0/Arbvl+Eb77bnxbj2sF8OOVKot36bOHF7gGHbQe441qRPfPx+39w
dx0o3uswN4casxe1Ro9ylywf3zM/sYAuJR7ao3LuZB5os+yuzKOYOh52LhAF
ci91rjCZEkKk9CuPiY3lrjb37bugriCxpfRlcRL35nIPlz2LFSSWbehbm8k9
0tTCTHmhhnRBoxEpOdzneqe3Hkmtp4xnNn8NZnBXFJU6WqgbyTa1Il9+gvsP
sfcrjMRKqvnc29h1J/eESJNa/4Imene79WypF3enc/k76YNm+i133hETI+6h
VnlVE7dayPW6yPLS73x9vug/Gp3p107JdcbqmFDuqqj2mrgxNRnuzH339R6S
SjoppumYcVYCd22e6qldQRfJU/xPnmnndRIwelUaMqOHFvrau8l+4nUV99Wj
kotxz8lFoc156cLrsPQ5xSjae+kz2+N7153jda7qcQkn336qW+05ZPeAnwsr
r8p/7IsGaHPT4ZvTqvj5UrU8verh8IL+Ng/+si5DyVyamTjP7dQQCcHNJatd
/2RuQz7rWvs0lGZ2viwhrZ65Z6B0S6jjMB28lnW5fvdDvl+yknLLqmFqGVhZ
XbjmPvOMnwOOde/Skp/PJbrhc4f5eMKYv7vRCOU5N9aeXlbA3Dtim9YxbYRE
k642q3jnG9Y6+vUdzZwnrwrZzx/sV5VVHddR8LmOiX27SpnHukmWi3t1tGhU
42/tWcW8+V79kNpDT/ONoiUNSxuYX9xU88nB7/VUeCdA7t2vZH60KXnGFJme
bs8ZWG9c2sz8Wv+M7PhcPQnpL22+vd7OfI17dJH3WT3ttlLY31jfyTzolTy1
P0xP9RbXtmx80M287kffylP2etq8tUuf9FEvc+WGrV9fvKmjpABNwk5ZP/OV
750fX7BER2mzzMdb2gaZR5QvXHU/eYQkLZtMRqdrmN8NSre4/EhLmY2h1sem
DTP/r46HCXc4fg9/B8f34v/A8Rx4LjieG+8Bx3viveFYF6wTHOuIdYVj3bEP
cOwT9g2OfcU+w1EHqAs46gZ1BEedoe7gqEvUqWjSNbmuUfc4B3CcE5wbOM4V
zhkc5xDnku2L4dziHLN1M5xznHs4+gL6BNsvQx9BX4Gj76APwdGn0Lfg6Gvo
c3D0QfRFOPom+igcfRZ9F46+jD4NRx9HX4ej72MOwDEnMDfgmCuYM3DMIcwl
OOYW5hgccw5zD465iDkJxxzFXGVumLuYw3DMacxtOOY65jwcOQC5AI7cgBwB
n5wzcCGXIKfAkWOQa+DIPchBcOQk5CY4chVyFhw5DLkMjtyGHAdHzkPuY27I
hciJcORI5Eo4cidyKBw5FbkVjlyLnAtHDkYuhv9ffv4XN14VMg==
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.2727922061357855`, 
                    1.2727922061357855`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.2727922061357855`, 
                    1.2727922061357855`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 97->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns01OkfB3C1LilthFTbRYhaIrdC9AgpJ1ZUVmgKo5q2sqEIqVaKcWul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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.250385066826195, 
                    1.2948116406095722`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.2948116406095722`, 
                    1.250385066826195, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 98->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11n00VOseB3BClI44JDmoyBSKtBTReBycup1CXtIdIUmhm9LxklDIyxgu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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.2275970481124974`, 
                    1.3164366629145068`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.3164366629145068`, 
                    1.2275970481124974`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 99->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11gs0lNseAPDhCCWP5EhFcaJExSl1JJ0tjyNMKcnpFtUgjktUlHImj5NX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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.204435091445945, 
                    1.3376606858593096`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.3376606858593096`, 
                    1.204435091445945, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 100->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk4lGsfB/Ahy0sk5WjhiMnWRlJCuAdRqahJhRxpOXqnKOHYTiWUJYUO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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.1809062521829132`, 
                    1.3584772444009896`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.3584772444009896`, 
                    1.1809062521829132`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 101->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3C7spTLuBO1pYZEoou2dtWxfnLdlKH9YVQakSll18ry2yGX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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.1570176974357707`, 
                    1.3788799976141604`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.3788799976141604`, 
                    1.1570176974357707`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 102->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3ByiRVJS1kKlR/bjVjdXA77k2wXTW4Vk5YsqtmmFVoyIWm7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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.1327767038897074`, 
                    1.3988627306225476`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.3988627306225476`, 
                    1.1327767038897074`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 103->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ms4FNoaB/DZ2RWqQwlDiurskDrjUknKIrQNovsmEt22iqNQLilC0wyh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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.108190655586185, 
                    1.4184193564920995`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.4184193564920995`, 
                    1.108190655586185, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 104->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB/BxSW0/I9dRE4VcSsSWbL/adVzSrxTKrWw9Erm0JNctJlvL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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.083267041673687, 1.437543918085127, 
                    0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.437543918085127, 1.083267041673687,
                     0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 105->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lVkfB3C514vBO+MumULklhIN2skIUXHSxVBRyRQxRYkKpUOIFq/L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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.0580134541264516`, 
                    1.4562305898749055`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.4562305898749055`, 
                    1.0580134541264516`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 106->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk4lOsbB3BZOi2WqJGQsitLlCUqDxHSyXYoVJIktDiWLCfJUrbKkSWi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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.032437585431883, 
                    1.4744736797201852`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.4744736797201852`, 
                    1.032437585431883, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 107->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk41GsbB3DLiXOOXmuydSyRnFLk6oQ4HlscUqFDiWTJ2HNMlixtltch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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {1.0065472262473445`, 
                    1.4922676305990752`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.4922676305990752`, 
                    1.0065472262473445`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 108->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lFsfB3COy0shKQ5JuRQOU0gSjXYj5dKb4tUR3RzU28hxqU7hZcit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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.9803502630270488, 
                    1.5096070223017632`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.5096070223017632`, 
                    0.9803502630270488, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 109->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lFsfB/BBpdNxvxVKFFFyzUE3uyasopCDU+klxZSk3pJ7pJHKvM6Y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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.9538546756197689, 
                    1.5264865730815667`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.5264865730815667`, 
                    0.9538546756197689, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 110->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB/CRdJFIZEkiuaceZXO3h5LqZ5dfkVubqOzETwrFrmtI5FHu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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.9270685348380975, 
                    1.5429011412638023`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.5429011412638023`, 
                    0.9270685348380975, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 111->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1gk01dsaAPAjyhCRpW6GJCsVqXRvyfTahi4ZE3K9lJtjuFzCxVO6eLmu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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.9, 1.5588457268119895`, 0.}}, 
                   0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.5588457268119895`, 0.9, 0.}}, 
                   0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 112->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lFsfB3DjkuQSoToS5YSQy6hIZBdKeM+pM0rK5VDu0VETIyrH9WRc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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.8726573164434067, 
                    1.5743154728509123`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.5743154728509123`, 
                    0.8726573164434067, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 113->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11mdQVFkWB3BGgoCKOgKiDFFHUEBQbGWA4RJbwjoiausIBlCRILRIFHWG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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.8450488130146034, 
                    1.5893056671460686`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.5893056671460686`, 
                    0.8450488130146034, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 114->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11n001FkDB/AhZPOWWolnG++xhJrakqFL64lEylNh10uxpJMV6Xm0VsS0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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.8171828995311843, 
                    1.6038117435390622`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6038117435390622`, 
                    0.8171828995311843, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 115->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns0lFsfB/CJSIM4UUkqJSEUDuUSW2pExympiF5dJim3oZSM9L7GpYsy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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.7890680642203395, 
                    1.6178292833385006`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6178292833385006`, 
                    0.7890680642203395, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 116->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk01OsfB/BJRUoXZVxkuUpKWhD9xI+nrsm+ZEK22y8divrVbbMmFSUV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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.760712871133259, 1.63135401666597, 
                    0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.63135401666597, 0.760712871133259, 
                    0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 117->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkbAHANJRktu4Wk6GJIaYs2kZzZlopVWd0kSYRHFD+/ECoKY0jI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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.7321259575364404, 
                    1.6443818237566816`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6443818237566816`, 
                    0.7321259575364404, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 118->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk81VkfB/BbLnMrPDH2NR5FykSjGOLIepMWIiY9HtmZjHWsMaUsQ5JL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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.7033160312806928, 
                    1.6569087362143926`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6569087362143926`, 
                    0.7033160312806928, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 119->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3DR0vYo1q1FF8pUWhVy+eniIPktXVyiiPUwYiMSUVKW0krj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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6742918681486416, 
                    1.6689309382202173`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6689309382202173`, 
                    0.6742918681486416, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 120->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ns41NkfB3DktmmJpXsukRWVH+XShWOqxYZy2yT36SYUIalNhrRbfhUl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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6450623091815405, 
                    1.6804447676949632`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6804447676949632`, 
                    0.6450623091815405, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 121->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 122->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 123->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 124->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 125->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 126->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 127->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 128->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 129->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 130->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 131->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 132->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6914467174146353`, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6156362579862037, 0.}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 133->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAofxm1xOCVKlhSi1VaRreRPKrKUiCxlrYhIicg+hOy7pijkoBQy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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.691189101886867,
                     0.029519815579329242`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6155424936022112, 0.010744334191903553`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.03141433158711032, 
                    1.7997258512815044`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 134->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIoegBUpEs0hCafSqiJUpHL7l1ISLo49QoiInKwVCtlqyIzkKNmS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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.690416333775747,
                     0.059030639136868145`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6152612290117735, 0.021485395555529554`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.06281909406450174, 
                    1.7989034886343724`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 135->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FIwXxkPZUmhBm2yVUkLZ06GkhU+F7EJJUVq+kJDdELJnT0KIsjS2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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6891286484739283`, 0.08852348138988334}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6147925498908093, 0.03221991225953564}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.09420472123729891, 
                    1.797533162558233}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 136->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmc4FQwfh4XHyizJaAnlESplRI+/URlReBpmSDipZEclq6yQVSjhSCQ5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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6873264382228277`, 0.11798935853292095`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6141365990035195, 0.04294461446614617}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.12556165273942554`, 
                    1.7956152904676836`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 137->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobxi1FdVqQg1KkaJEliRR5C0XRqXQqiXDKEho6KBVlyZpESCS7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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6850102519931467`, 0.14741929497436082`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6132935761588981, 0.053656235327176484`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.1568803369457847, 
                    1.793150456565142}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 138->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FIofhgtHWlAS0kqWDuIkWpBfKqVSIcaaJcpSVFLpHLIVKruQKESG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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.682180795317647,
                     0.17680432607046873`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6122637381498706, 0.06435151197914653}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.18815123388177626`, 
                    1.790139411662892}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 139->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11mk8FIoexnFbRBtlLZK1snRui63c/m1ESZZDsssamepW0m6pIeFQuVIU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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.678838930076243,
                     0.20613550085611362`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6110473986750705, 0.07502718653718063}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.21936481812926545`, 
                    1.7865830729543797`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 140->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobh4VD0YKINlG2U5RUUyKvFjuFbIMW2dqI0FGnUmTJFipFKspO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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6749856742334595`, 0.23540388477131832`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6096449282432852, 0.08568000708739082}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.25051158172811777`, 
                    1.7824825237348267`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 141->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAofxYW4RFFCyLVUFFpkLfpHWYoW2myFVLRQXRUhhdCCooso2bcI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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.670622201528354,
                     0.264600562382813}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6080567540605937, 0.09630672867744133}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.2815820370724156, 
                    1.777839013071248}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 142->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAobhm2RaBFJKZGlTSodiXxe+1KSaKGUrNnScqLlHBGyhWylIlH2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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.665749841116982,
                     0.29371664009976267`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6062833599002373, 0.10690411430499246`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.3125667198004746, 
                    1.7726539554219745`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 143->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwbhgtRylZIUhmKEipFwt+rqChfiQiRFJGkP1tUKku0ICJSllS2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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6603700771675252`, 0.32274324888284106`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6043252859552566, 0.1174689359037229}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.34345619167778063`, 
                    1.7669289302057951`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 144->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11lk4FAwXB3Amb7K0EJIklCVrFGWpYwktVIpUlqhsWVoILZYoqVBRtEi2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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.654484548408197,
                     0.3516715469458256}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.6021831286739434, 0.12799797532662993`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.37424104347196685`, 
                    1.7606656813208503`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 145->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIofxW2lRS6RpdCtW5K0yRp/P0TWWyISEiH+lUklkTVEi2RCKJQl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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6480950476280716`, 0.3804927224488917}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5998575405781571, 0.1384880253263082}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.40491189781895703`, 
                    1.7538661166134235`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 146->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11lk8FAofxnFbKUeylGi1hBIVRVL5qyRFkiJbSmU5KlpsnVAhlZSlTihk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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6412035211309837`, 0.4091979961827841}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5973492300645602, 0.14893589053190848`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.4354594120794019, 
                    1.7465323072967938`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 147->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FIoXxm2XW0omQlIRku3eIqTkRFlColKKxC0RmsrebgkV2bol2Yts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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6338120681426636`, 0.4377786242430491}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5946589611888338, 0.15933838842247833`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.4658742811845372, 
                    1.7386664873203228`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 148->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11lkgFAwXBmBbtH+2LBUl+1JJEVEHEYUiS7aUEFFaSaskkmRr0UIh+062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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6259229401712947`, 0.46622590069351305`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5917875534329387, 0.16969235029638913`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.4961472404705985, 
                    1.730271052688974}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 149->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobhzVJJfly7CVlK0U6CJX0RoRoL3uWspQs+URpI4SEEMo5QpG1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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6175385403216802`, 0.4945311602181941}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5887358814554928, 0.17999462223655294`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.5262690685009263, 
                    1.7213485607334638`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 150->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAofxW1RLpU20uUmkTLppuzxjxKhriWVrZpkubZSSC4Rwg0VhRZC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.6086614225632359`, 0.5226857807608416}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5855048748253433, 0.1902420660711364}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.5562305898749055, 
                    1.7119017293312764`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 151->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAoXx5FSUplyhVAUla1SonIdQnTRnrJGihAtkpKEStKQqFBSlBA1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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.599294290952026,
                     0.5506811861512986}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5820955177384088, 0.20043156032947834`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.5860226780228821, 
                    1.7019334360787703`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 152->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FIr7xYVyU4rIVrKEXJdKocXyRLYk1C17i6hcNN0WS7eULSRkabmi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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.5894399988070804`, 0.5785088487178854}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5785088487178854, 0.21056000119291973`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.6156362579862037, 
                    1.6914467174146353`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 153->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAofxu1bJVpsLZZIIZWyhNNfihaVSZGtcFCqQ6fS4ljCCMnYWmwl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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.5791015478412471`, 0.6061602918850117}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5747459602979014, 0.2206243034402573}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.6450623091815405, 
                    1.6804447676949632`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 154->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobxiWnDpUQWVKytJyiJKR05u1kidLJkhZLpY2PkMqWlC3KviR0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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.568282087246841,
                     0.6336270927552232}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5708079986907215, 0.23062140138753132`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.6742918681486416, 
                    1.6689309382202173`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 155->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAofxi2J5IiSLRUtOEKlbKn+abFFC4eyJEqRCpFSDhVFC7JkiyQJ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.5569849127363702`, 0.6609008846748982}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5666961634375992, 0.24054824982186304`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.7033160312806928, 
                    1.6569087362143926`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 156->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FIofhoVSUignQmQtwikdJeHnWEqFlIjsZYtotZ1EliShlGMpopK1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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.545213465538628,
                     0.6879733597828104}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5624117070433847, 0.2504018249290558}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.7321259575364404, 
                    1.6443818237566816`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 157->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FIzbh1HRRpRlkkiSQlwJIfW8LYpoISIpWyJbi0IkopdsZasoZWmx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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.5329713313504638`, 0.7148362715407851}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5579559345950004, 0.2601791252146782}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.760712871133259, 
                    1.63135401666597}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 158->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwbhiOhUpE+pJItKUsRouRFiSRtkq2kKJStRRSyJRWi+ipljVLZ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.5202622392445437`, 0.7414814372456743}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5533302033638979, 0.26987717241834847`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.7890680642203395, 
                    1.6178292833385006`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 159->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwbhpEoX/2fIiEVUslSKluUlygq/Vm+REhREaESadEmS6FlUmjR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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.5070900605334387`, 0.7679007405218862}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5485359223926207, 0.27949301242094116`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.8171828995311843, 
                    1.6038117435390622`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 160->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llkgFIrfhplk6SC0oCRbFCotlqR+RUmoUEmiSEpIqyUVolDh4PhCm63s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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.4934588075903859`, 0.7940861337937138}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.543574552065596, 0.28902371614444095`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.8450488130146034, 
                    1.5893056671460686`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 161->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobxgvRXpJkaSFpQYt9O96ytaBESpYkkRJRWTuVEIpEKYmElF1k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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.4793726326270806`, 0.8200296407367027}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.538447603664287, 0.2984663804441674}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.8726573164434067, 
                    1.5743154728509123`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 162->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11mk4FIoeBnDh0CJRslaoibK1ylL5l9CiBadEUbmIo1DZO0ImVKQQ6cQh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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.4648358264288728`, 0.8457233587073176}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5331566389068428, 0.30781812899310185`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.9, 1.5588457268119895`}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 163->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAofxYWIFksSkaUoVyiKhPxRWW4UirJkuRVSaEG6JFG4hUT3uoVK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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.4498528170477514`, 0.8711594611501641}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5277032694723834, 0.3170761131580438}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.9270685348380975, 
                    1.5429011412638023`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 164->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxlGhvaQI2QpFKa6klLdsqbQpa5aULUo7UZQlZAvdmyuSyk72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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.4344281684535176`, 0.8963301999820331}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5220891565100664, 0.32623751286733255`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.9538546756197689, 
                    1.5264865730815667`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 165->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lnk41AsfxS1Fqy2RoqKoK0spEvItaXF5S5SQvRK6pMVWKUuhIlQ3cduE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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.4185665791435553`, 0.9212279079520421}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.516316010133085, 0.33529953746986824`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -0.9803502630270488, 
                    1.5096070223017632`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 166->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIweQEXSrRQlVJYkUmhRtlJ/kqWS0GZLXGuKVkXLZ8sSkqUvKgol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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.4022728807116227`, 0.9458450009771537}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5103855888977518, 0.34425942658517106`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.0065472262473445`, 
                    1.4922676305990752`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 167->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAofQFGIqJTQciuRdElSluj6i8qSohISobQpJBEVZVT2XYuabEkk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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.3855520363761031`, 0.9701739804523613}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.5042996992678239, 0.35311445094421995`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.032437585431883, 
                    1.4744736797201852`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 168->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwbhpEolc+WpQ1Ji9CfbEW9opCUpbJHEvkU7WVJlhERQkoqKoSy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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.3684091394681595`, 0.9942074355348369}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.49806019506423826`, 0.3618619132208148}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.0580134541264516`, 
                    1.4562305898749055`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 169->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FAoXxi2FunQpSRJRJKSVVOqECpcWyq6iBbeiUKpbkiUkWcvSXipb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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.3508494118802563`, 1.0179380454013447`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.49166897690041855`, 0.3704991488532075}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.083267041673687, 
                    1.437543918085127}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 170->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAoXx2W9bVIpirKEFtubsoTboVWWLJVs6apkUrRL3WQZVypEJSlZ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.3328782024755228`, 1.0413585814782362`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.48512799160333064`, 0.37902352685575375`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.108190655586185, 
                    1.4184193564920995`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 171->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwfxW3xEKHFUkqWdm1kKb7+KUp4JW2IalKI0ob0vWQNFWXpTUIi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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.3145009854584342`, 1.0644619096433419`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.4784392316204601, 0.38743245062033627`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.1327767038897074`, 
                    1.3988627306225476`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 172->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FIoXxpGyXCktSBS3qCyJkK1Oss0tbYqQirJVl7RYrq59rahIqQgt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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.2957233587073176`, 1.0872409923990967`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.47160473441289286`, 0.3957233587073175}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.1570176974357707`, 
                    1.3788799976141604`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 173->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxpn2opIipS6lUlq5ZMtLkiW6kWTrRogS6ipbUciSLVSoK0tk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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.276551042069185,
                     1.1096888910162264`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.4646265818346859, 0.40389372562577824`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.1809062521829132`, 
                    1.3584772444009896`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 174->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIoXx5mKSxIlpBLKGm23pM1JEqlbpMUuZYtS91ZarrUp0bWrUCrK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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.2569898756174105`, 1.1317987676473553`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.4575068994987134, 0.41194106260280694`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.204435091445945, 
                    1.3376606858593096`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 175->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lnk0FAobxqWiVJZSSpEpUkx1KVtcr6ioq0IIUSlLFG1SSiJ9qKypcFFU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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.2370458178727886`, 1.1535638874098775`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.45024785612918466`, 0.41986291834160416`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.2275970481124974`, 
                    1.3164366629145068`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 176->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FIobxlFyOLKWsoROEpGkLFn6QtI56SQnQpstSrZS4qSSKVt2QidE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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.2167249439885106`, 1.1749776204374704`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.4428516629010301, 0.42765687976817107`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.250385066826195, 
                    1.2948116406095722`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 177->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11ms0FPgbB/Bi0AVLikiLolq3SrmGX0hU8i8i17AUqagWsW0KRSspl+Oy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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.1960334438996145`, 1.1960334438996145`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.4353205727663554, 0.4353205727663554}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.2727922061357855`, 
                    1.2727922061357855`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 178->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FIgfxlGyrHIVKUUbIkdSjoRfSNpNm2yEVK5UcpUSm0qmXLkp2hA5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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.1749776204374704`, 1.2167249439885106`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.42765687976817107`, 0.4428516629010301}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.2948116406095722`, 
                    1.250385066826195}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 179->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAwXx6WitFFKlDJFikkPZYvHFRX1qBBCWshetEkpifQiWVPhsURl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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.1535638874098775`, 1.2370458178727886`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.41986291834160416`, 0.45024785612918466`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.3164366629145068`, 
                    1.2275970481124974`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 180->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIofxZmKSxISUoQiRNuNpPLLVpJbpMUuZYuoeyst19qU6NollErl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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.1317987676473553`, 1.2569898756174105`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.41194106260280694`, 0.4575068994987134}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.3376606858593096`, 
                    1.204435091445945}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 181->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FIoXxhmVUiop0nYplZIWLtlySCLRjSTrjRClqKtsoZAlW6ioblki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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.1096888910162264`, 1.276551042069185}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.40389372562577824`, 0.4646265818346859}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.3584772444009896`, 
                    1.1809062521829132`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 182->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FIoXxiVluSItSIRbVJYsUUKdyja3tClCKpJSXdJiubr2taIipSK0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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.0872409923990967`, 1.2957233587073176`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.3957233587073175, 0.47160473441289286`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.3788799976141604`, 
                    1.1570176974357707`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 183->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk0FAwfxm1xiNBiKSVbqbQRKT7/FCW8kjaKalKI0ob4XmUNFWXpJSGR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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.0644619096433419`, 1.3145009854584342`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.38743245062033627`, 0.4784392316204601}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.3988627306225476`, 
                    1.1327767038897074`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 184->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobxoU4bVIURVlCi+2kLOF4qciapRKSjkomRbvUSZZxpEJUkpIl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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.0413585814782362`, 1.3328782024755228`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.37902352685575375`, 0.48512799160333064`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.4184193564920995`, 
                    1.108190655586185}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 185->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxm2hLl1KkoooUqRSlqLeUOHSQguiorJcoVCqWypLSLKWpV2K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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    1.0179380454013447`, 1.3508494118802563`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.3704991488532075, 0.49166897690041855`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.437543918085127, 
                    1.083267041673687}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 186->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk41A0bh5EoLa8ttCJpEfUlW1GPqEjKUtkjWepVtJclWUZECFnSHkLZ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.9942074355348369, 1.3684091394681595`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.3618619132208148, 0.49806019506423826`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.4562305898749055`, 
                    1.0580134541264516`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 187->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAofQFGIqJTQciuRdElSluj6i8qSohISobQpJBEVZVT2XYuabEkk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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.9701739804523613, 1.3855520363761031`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.35311445094421995`, 0.5042996992678239}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.4744736797201852`, 
                    1.032437585431883}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 188->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobh2VJX6UoWcqSRAotylbqVbJUEtpsic+a0KpoObYsSbJ0oqKQ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.9458450009771537, 1.4022728807116227`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.34425942658517106`, 0.5103855888977518}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.4922676305990752`, 
                    1.0065472262473445`}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 189->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIofxS1Fqy3Z4hah/rJEEZJfScXlX6KEEMp+SZslKUuWCqFu4koJ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.9212279079520421, 1.4185665791435553`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.33529953746986824`, 0.516316010133085}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5096070223017632`, 
                    0.9803502630270488}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 190->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobh1GhXVKEbIVKqRxJKW/WNm3KmiVli1JaiKIsIVvSOTkiqcia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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8963301999820331, 1.4344281684535176`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.32623751286733255`, 0.5220891565100664}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5264865730815667`, 
                    0.9538546756197689}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 191->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIofxSURLSSJyFKUK4QiIT9LthuFouzcCim0IF2SJcstJHWvW6iE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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8711594611501641, 1.4498528170477514`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.3170761131580438, 0.5277032694723834}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5429011412638023`, 
                    0.9270685348380975}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 192->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
                   0.19753766811902757`, -0.03128689300804618}, {1.8, 
                   0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 
                   0.}}]]}, Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 193->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 194->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 195->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 196->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 197->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 198->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r
31PcsSX8GRKiGetgRsZsqEyDaKG8zrm9H98Pz7ffOc+X33nOo/4fbxvXxSIi
IkELEV3I9PI7vnmcV7BG14Y4I/MWlB+f8U5fNgD28vz97pUUeHTutmh6ylsI
1Vs085A0APc2Sfm3/YZgrbidsFOFCi3f87faCgfAkGhSui2yEkRJHQlpd6jQ
I/tUtseKAVbOlFn2RAmU3S0cb/uwwHt2pc1lMWDXU4M0v/gcsDlRknpYlQb+
vssrij4yQCQhxWeXVgLc80q0dzWlwVzuyybUZEJdV155mkU4qplopSk50mCt
5V+xIrZMMJTTf7bLJQPn6y/lmHnTIE2T1rgjgAnsFdcPfd1SjD7liZk112jg
3uPWLBvNhFsV524omFVgWk/ik5MhNGj5oWlwJJ4JJyxj5FW9atEmwGEDPYgG
0X2EaNJtJlQ96qpcTadgvqquurgnDbiU6EIrHyaI6d9gbQxvQvL+9Nupp2jw
cMgrEI4x4clJe1EwbEULjSwleyMauBHyralKCzzWnzr5rR2f6z6WGpahQeBt
u7+u9jDAa5n2aC6bhpkJpi9f1lMh2GzUOC6MAV/D1xQsftuJabtX0BmWVODW
7iEEKTOA6SNGTa7txqzMa3HH6t9CUr4l/c+MAVBUZwwcKe3FjKWpnXrqbyHG
5vA0VWEA7igfnGM860OLcwkzER7tcFWuYDA1qB+MePM00WcDKP3Ps5OWyW0g
JnrmnPjrPlCPseNcLGGiVKmv8vmyNxCieiFGap4O23XI/TmV7xBtHbdllrbC
5fXns8hqdDCQVc975MzCNgWiX0tSC8jLrDYf1uoF90UCre3uw+gmM7Ex8lwz
dP/z7Y3Pmh54rxZJoXizsckisjpg2WvYG2K+0uhzF0TearKnB3DQ3UNRX/fh
K2gUc/xzorgTvtR9fTwWysVG9a1jmvMNoC9fWWRt3QF5dMbvjlE8PH5ZU+Wd
BQVkvFfYLM1b8C69piQwlo9fb7mdqvWog0VFkzedvNvAt/Cj/sX4ESSeXFPo
1lkN5COe/ezpZqgylYzZlzCKGVXyMnY3KqEp2F6WZbjQny5vyI4bwwkuff3u
ITJskFToL9Svhy8VR3asinyPgrwV2/Z3FoHkuRKlgK4XsLiIEHfJ/wPK7tnd
kGeYCYcfbgj0yC6G4Om/dzmc+Yhhi7tELpHvQvMrPfvNvk/AuclBUnHPOG4N
sa87cSIMwwitldEHY/CjycGA5ysEuLP6xp1pahqqsROXFK0rwnVD1ZRpmgCt
guo6Npg/Q7kKucqpXVWosOZGTDTpE8b4LA9RNi5HCzXBliZoQMm2Z51eMkIU
RsTbHSqqwSonsctXyC0oQ6jhr7IVYvGLLQqN1RTU/hktrmpMQ4mdZ1l74oSo
VH8h4kx7E6akFZ05jl242HM64mylEDnn9bff+u0NJkWZaVEu0LFVvXwlr1OI
jV4hag7OVKwLFt0vr8vA+Kia8G1MISpna/A/jHfgukoTre8rhnCTi/miogVe
JCki+JJBN+pp6LhLhg+j41oFFWqpEE/RyN+Db/dioOTm7xE3OThWRxHXuSHE
48sPBLUO9aGAUrql8A4P2eMpoaRdQrzuWnHfRZ+Bb/PldHbeG8G63VdS03M/
4ab3odqUm4MYEEcyt7s3hl/slHLLiwW4ZiPJe/D1EEZ07M0YjPiAM6NWyrFR
47jo99Y/1s+x0GKIcH/rxXF0XDx62lTnIw67N4pnSLAxTDKkNtz4E8YtO9fI
TH2PH548LpcQ5aDObFTDV38h2nC/WLtyR3FP886I2fccvJLjtqUfJtAsYd6S
M8fHF6qUHcerufj+4d/X1KcnkNQht//0OBeTR46SlX15eMbinvnRB5PYWTxS
+LKKjcdfHvWnr+RjSQo9XUdl6pfHLPyf192Tkau+RU0hT7zMPESCiSd9uE0h
H/gYy1JyvtA/hXdy9K7LKdGxaunsebHNI7hOt3qySOozVhyw8zis2Iku3ip+
jeYjeMlQbeq+5mdcv/s70V6jFcM5huGKxBHc7KMucCV8xpvUbxsr9eqQ+iP1
86d1I8g2/GY49dtnZG3Q/+IYm4+bTVWl6gf52BvpPBHaPoVpRk2/b9zwGMhe
T8X9wvi4WfRUIzl4CgMds0ULcyvh3SmbcaulfDyvtmQ0YvUUSj/K9HdTegXE
EkXRwWs8vLZ6vkHzr0ks/TRQQrnQDl8MpbTa6FxkJr8s+CQ5iVn7XF3ckjoh
20C7kbuei64cZofZ5Ql87vyD0mrQCwnZgqUfz3AwydnFM7ZJiONHM2XE7/YD
MKQjHsSxMVT3GElVVogRXk6LeclM4E0tEbtcOozZuuM3/igQ/PJ4CP71moUh
1wJKKRvGMarMf1G+gAWO91+5HO8bQo2p5LsqDz7g/RKG6f6lbLgp1uLqIfYO
k3626fJ/jqFdvPK3/EUciLzvXJWly0QbmQbadrdRPNClQDvYz4HRSfvHCqcG
kKvB9yim8nGt/B6binguGFlRM7xJfbhExoXz3JiHXhqCv/N1eJB7vnJ8cmHX
d1l/PbG5gIO9ftv9OIU8aLZKTbk13o3iKdGpFFU2ejIaSLoyfPAtiHeq1+tC
/2376nqTWThaTus8coYP4iEJJqygDqwK8p3/bvYOjUckpOce8ME2QVfndSoV
Tcp792m4MNDp67tQfjkfeslkTRWXNkx8y3sS+rAPjY9o2Wa94kPkzOyLPpMW
fDbpZ/aD2YM2emTjSgofVOJeKDXsaELb3ZxDB427UJGq3RD7nA/eY/VyNsQG
fJiwxLO5iPY/j+HXPuOvfUZxmdr2Uic+yPwcy1V0eIkX184f+Pn8NepXOWy/
oM6HpwFhJdqy5Tin2T67dW0Dund+/fy4nwc3jfq7CT+KsYIvrS28VIPEPeeX
HYjiQYaqnTBoZx7evapudWymFDtnCm2Pa/PAPdppyYqMFHzavelaeX4+Lv0z
mx7WxAXpajvTvQZRqJZcLD6v/AAVPsYMJtpzgRVbJE156Q9bCWUCqWIS6L9W
O7ibx4E9bAHJl5gIdk6zjYsOZMIt0lydhAcHjBNnMyZkMkGwjazHIRUDU3pk
PHKUDUSCb6vq0wKo1rhpdEKpAhom7B7pO7PBM4nwRf1bMYjLRz784VoDwtMv
6kjdwxBkZi3i4VMKq4tz3UTK68Hcq7m4hzgMIuvj/VSaKmDbc3ODF4mNwL/n
MXbzKQvEc1ZNnp2sgiv1OdNatq/h35/B+vU7aoB7Msfg6HQLsD2tgpz57+Dq
mwebxL3q4OqzFWqSfm3QKlGdfD59EJYQ2+Mb2uuh9r26w4Het1DjRtA0OskE
PEx0dlzTAF5Zp3NGY2hw9uLpSZPFDHCXLFhOdGgEzkbHvQZpHdDPn7VoyeuH
SGnvF4NRr+Coei/JI7sTdGrLvqge6oPvplEr72U3ASFEXqc3uQvud1u6hnF6
IfyWr1gJ+TUQy8pdmiK7QXfG2nNdYA9kvZOqvftPMzjtnSsLdemBCz1k840S
3XDa3NDvakYLXBI9NWWyoxdeNYodqLzXCaXfJJwSSa2wz4KlYjTTC9fXx+RO
yXXA/WDb6C22b8Bzfpnlk6d0SD7y0XpAkwqh9cMsd+U2+OT4PeOObR8Ehi/z
+0OlDURdwz+50NogJUF7F+FzH3zQ0N1QINYCovLrBw0D22FWx0oQHNEP/+8/
/xd+YAFw
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 199->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 200->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 201->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 202->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 203->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6156362579862037, 
                    0.8457233587073176, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 
                    0.30781812899310185`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 204->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAobhhVJHSkiyRKlNJEcKkvxdk5UliJlK5wkkchaIVu2FpxWkmxJ
TraMSA7xjn0sjZFmLDPWMUPJGMZSKJ8f5+/34/l/P+/1Xvf1KF3wsnRZKSAg
ELgcweXsM59m+dvXw16tUL1EXwpseebo9WJtD7htkD09rF4D5+yqhDbyKBCm
vmI2IbIHhgcN4jO5lSA/cnLE5K82aJrP0bDm9YAVNgm5XHkPdU97stVJbUCT
yJegWTAgbL96Lr+DCK66aRaWa6jQ5NmRsZjFADMh19tnLLKgRuz8MUNVKlz3
/+19wTcG8LyF18wZxILt+XupNCMqLP5T0YAqTCB9I3n3u8Xi5ezeLV9sqSBv
mhwvYM2ED/MGcV8KsnBfzbcP5y5SIUOFWqd1gwl935snu6yK0O4KKUbIjQpu
NFeyRCwTFLiSFZOXy/CzlaVZifMyz08VbbOHTHATfxHi9BjRpnpz0H4bKsR2
KcdG3mUCpvhrK16uRdvehS7TP6kwXBObZ+HHhFlH/dtmGxsxMfiAeYkyFRL6
rwbASSY82p4nrUluRpJ9jr7xYhu4KuecapNhgrbMKqOa2xQMngkxSkxpg4C7
tsm+NAZ0mjj58Ha1o4mQlHQqoQ2CDUf1/g5nAGtleZnGxg7ckAoHn2dSYLjq
kHLgFgaItZb8vLWShs5PPdmVwhRIyjHtvJnZAyq/HWgom6Wj/4HTEUpWHyHO
0mSmTboHBtIXZFMmujDc/aZte1wr+Erm9qYHdoOe7XEL1rcetE4L/bMxvwWE
BB3PCzd2gcKCeKAWl4lbJq3ixoqbIXTrpTixpU4ICricIcfvQ7rm6SXJF03g
ve1iVrFiJzSznMxjQwZwKpW4e40fGTaJSxkN7qZDiW1wa1XEIMJiwI/gXY3w
+e2PFj85GpQG5a5rvDOEBmRSjhSpHvRDjdbrTneAVuP6Sxr3WWhZRjnkrlMH
dUL2NyeJn2DFo5Yu34Rh5NoP31z1oAb2byorOHWqHTTD+VETyWwsJrQWudWT
QNxrneWa122wT+c+YzyNgyTizmCFN5WwomAqysGrFRoSRV8mZYzgH9MBNpyY
f6HYzLN7aIYMewhfKfNpo6jftGZ6h8Q7aAi2kxjQqYdvxqkHFpO+YB/Z/smk
GRG2i0p35+2vBo1nGocc47+i5SHPTNHL2SB6vkjmRse/kBkyFlgWNIbEYyTj
EJmnYJKwPcD9FRHipXMSr/31DQUEghLlGzsMyPXqdgT/5/DGwsedqjuOZG7/
y3shSRiu3FwWezwOI847vW5fzUW1tHTDAq0cVBxKFClQKMDo4Trzk41c/H4m
UvuqVzFKvpcs4x8oR0LErNbItQkkXXbYnJ5ejkcVuXsboBbvK2ktRonw0LLa
SsxJshrLHYS8fYqbMDLGfuaHCQ+tSA2bJwTrUfVXrPBWPSoGxhk9ZYTzkCNV
8oeOXBOmZhQ4mmMHPlEwsXvxmoeTSny6zNmPmHTbcHfNpU4ctbtUVEriIXaG
ypYzqUgKFjyyaQ8DDVXfhEQ08nBrnnb9nS0dqFBmsHt+XT+y1OLPe1fw0EHi
p9dxZxqq71RzE13+j/6LD2UWk3n4UDdnpVpxJwaIEuajo1jYdo5eXXVxmTPp
1bnGVT3IrSnZm3ePjSFyD7NDpHlo/Urlm4Q1Eyk5kmr7Hoyg98T83/4XJ3BT
wqNn19P68MbfkUa2D75g/vrY2Gg3Lk4Lv7p21WMAo9v1M3ujx/BIZzcxUm8c
V/fqPXANG8Sj/cqPNa6Mo8iTrLPJPWPobl4p/TFqCMNFQ6si9CawtNVp1ZDx
VyRER83pB7JQbeF27ffrPFQm2Md63RvFIEsV1yt2w+iT7bq3Gyax1iHa1C6d
g/bW9I5929j4NSEtSGlmEhVvFeUS44bxCH8D1FHZ6Hj0gdGJJ1PY4L5qv5fN
EBaNjh/KucDBotTOF2qyfHQ9OJdrs2oAnbP78ng0Dn6eitn44zYftwfFlSXp
MnBjqYKLNmEE4wdknC5189HvLP+KnjEdz7UUhpWeG0GFPR+mCsSm0fDL1Qsv
jrVj16Tv0eOeI+iho8h/rDKNzb4DqwuiyUhcbfrSxXEECX5KXBfladR5p3m9
UakSGStUXOU0RnBI54cOf9U08sjt3+sJLzFrYtB9icVBeozTZNhHPmp01VLT
uzOh2v7xtHgwBwmCNnXFwXwkjnZ/simvADW7L6LEeTZeVBQZjZbi4zzTL9w/
qQF2mH4IuXaBjUFSS7UqyVOY63s6f0sPBSLf+2zcUTqMzJSK3AnRKVzjfVQw
xbQDbrC4AQ+/s9CFxWw39J7Ezq2czULDdCgfTy68o8bCJCdnz/gGHoqMRV3s
0uqBtBghcs2ZIQzbczJyqwQPU0Hm+YJuL3wXK1H57DeIr/aM37qcy0XLmMqK
a7P9INf3wmF73ACGBt0oqdk+jrKPJCO27x+EaQnV5Drox538lPuyT8Zwtvf7
rVTTITAmz6RJXujFpF+tezi/vmBMgsdAH7DgQsWJwncRDLQUr6Vquo5isaai
8tmNw8B4dEezJKsbh3dy3IltHLx/drE6v3EYsOuS/5vmThQRd2YV6rGx2+sD
874jG+bEdxxizNLwwKnvZwi5y/0WBC60dLOhoT2PJq76GYVTY9Nrtg7h64Y6
T9WDHFhLyB375PYJr/9+mERPGcA1uUC+EcWBhIXLb08VUbE80H9p3rAPe24K
H/V8z4E30m8F59dS0KCUfninMwN3BhS1ltE4IFLio7GhtRkTKeznYQld6Hu7
pJI/wAH7IkIeO7sR30xdM/zJpOFjofbYFz0c2Hx2LGtbSh1aH2QZH9frQArV
3lC9jgM8zV3RO/KrMeGRiCe5gIr/+Rn+8zP+52f8sM1FXM6DA45khkeKbhle
kV869quwEautlpqZahxIkg8sNp9/i4sqHxc05GsRi8xrDg2xIdn6YrJgfx6+
52xQ5XlUYlKuuZ9mPBsusazOPtLIxPu+ShYnZ0sw36xSM12dDaMX+GwrykPM
/7wrqDQnB+8YBThaLN9fIHzOmDbXWqWYQhRe2vIE/Uo3PhewHYZWcRMHFdGH
oKH8jitGjIS5Z5ul7AZZkKypKb+qMANsHRbqVhx7CYT1nVVTziyg76fuFQ55
Ddzfi9VZkUQoHnkcbTMwBFvervlaNVUIH3ZG6Z6ReQ9zih5BgjZDUOgSkuF2
txiEN8Uk/HSphCO7b31zIQ/CvT3Vu79MlIIU8R9XgdJqKNs94zu0bxBgpD54
m3o5/F5opP1vYh2IWc+z21MG4CHX9pWJUSX4VGfP7LZuhIqIhqORAgOgUMo2
M5IlwbBVtvaJmSYo9DLdE0jqg9etY+6ht6rB9806RdFrrXCqw+XgjYBeYLiW
KdNpNVD1VensMToFdjWNHPEkMOF2O62maXMdXM06lz0aR4WV+n5byzt6wCB3
rRjFpB5YO+z1tTPaIWsxcBfxRjdYT3RJmHs0wAkleqT7q08Q9OuHdaJUF9Af
6E0XhjSCcugmNXpKB5w52G6YU0AH27HSJpMwMvz5rtS5IeYzhL6rkpM7TIOM
iMhob58mcNBffBfmTIPr8orXZT52gHbBUL/bmWbwELThG2jRganos7XuzCco
uvuXke+uFjh8dEBWd5a+zBHVrd1Jhc3WQ/XV4y3gubTW9Hl+J2xQaFkrmUMB
4UT2ysisVpiwn8+8Z90FrWI+8U+etYBqopVsl9lHSH2kekB5ugt8oxd1hMPJ
4ELpedzN+QgLahbc4Ohu+H/7+X8VWxgC
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.6007825858125467, 
                    0.8563388851353371, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.6965612689828187`, 
                    0.27825143122177637`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.027205609197345458`, -1.5586083070573573`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 205->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwfxUkfXqWirCW8iZClJFH598mSUJRUlEhliUiy1UvIKCMVEVJJ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.5857459094433395, 
                    0.8666935624434031, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.701159031553512, 
                    0.2485999753690186, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.05440293130258275, -1.5578961201138175`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 206->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxpWuVFKIbDHKi2owqWzFv0VSrq2EbqWEFMmSsl50bYWkZGsj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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.5705308091958676, 
                    0.8767842364964998, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.705238604603696, 
                    0.21887279355552133`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.08158368174793226, -1.5567093829204124`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 207->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobh0fkqFAUpRNxsiRL0kKkV2UrKrLEKRWRNmvKWpGlsrUo1EhC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.555141919737059, 0.88660783357756, 
                    1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.7087987454559008`, 
                    0.1890789409688388, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.10873958101350246`, -1.5550484569687877`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 208->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAobhimpHEnKXpY4dtlpwdtiS1EkUekoRKJFsn+WrIVyhFOWr0Si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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.5395839286717177, 
                    0.8961613613237498, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.7118383696567347`, 
                    0.15922749310508824`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.13586235714931197`, -1.5529138481930775`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 209->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobh0lHiqFChbJkS9Z2FG/HQR1bkUSL0yaRSilbxKFQUpEtUQhl
mRKFVF6NvTCDsc7IjFnsjBlarF8X5/a7eO7+t//n96icvuzgtkRISCjgNyK/
oVvWTNqmk8DjU83+6nUUkH/sejljRQ8QrMUUG9srIDPq5I2WbRQI0RP+nhDe
AxIKK9MjXcrguHNI2KF9FGiYyTVw4vWAb6lcfsXXN3CATz9pdogC7asLVrcf
pIFEy3xfkXMOTPJjih8e+b2/2JY+l0WDl24yxMHRWGgKOfRU25ECvtfES4mj
NPC2lQ79wzQMldgyb2f2U2DuxYda1KQDY9sbr2tGmTgT/ojWt4MCG6xTYoSc
6CA2OZtBFSnEP5khBqXyFEjXpFRv86ODqNK9Or35EoyvcyERx8lwvt29fnU0
HTyHyU5MsQo0dL+6WjGJDA3zmrtsYumQ/XHrePAjEp4tt5E+pEeG6C616PA7
dFCPWfWxUrsWyyd+fGorbgY2KTr/oA8dvPPc0rY2NWDVrshROc1mSOi75A92
dDD1M5Ks8mvCocIakbjIJnBXy7Uny9GBIMV5mpdAwSBho2cp1Ebwv+OccrWd
Bsn81upvPq04lptrdovQCEHmg8b3Q2mwXdfj8D9OVPTP0JWN3fIV2BV71ALk
aZDIt7UQMenAK9ZP86bgCyTnWnfeyOwBhx0TLgmaXXiaGMRs29UA9xyspslr
e6D1x7nNrbI9+EEigW6+rh6uyuT1PgvohgnS3/1uy+josMdE5QCjFpaKuJ4U
resCkVXVODTbiykvOtgj92vgptK5e5KLnWA5Z2HJ5Pdh5nanRFHVavDeeDar
WLkTSiD8AW2agdZOi0XBT0iwZpWsBXNzBwgXB1LofCYeCjb7qfqjEqhFv776
rG+H+3b6weK8fszbkix1y6MCTG5aSBlNtYFBS/uN0VEW3t8To7Mlpxyqlx6/
MVnYCs0+e7fyBtn4/KtuWG1GCexYU0a0t28BB+sHIt4sDh79VupU5lIEqy4T
HJa/JMPR59TUfBoX25Lc5Jck5YMwkX/rxOVGIHqskK2lDKAYcfyT81AGFNtc
7O6froe6r9KDpM+DGBUfVbAp6T7UBrmsZhjWgBCF2RVGHML6t+5t2RiAqhJr
u/N3fAbdYKfGyrhhpKysUDnonoYSJ9/I+bW9hysNzu8kvUcwuX6M4ErJQ6sE
VX/P7EKYYbYVtf41ilPZr2TW1xdjfY2ei9a1J2DppXbXXGIM95h+5coGlmOo
2pey6P330JdPLL5QN4Yk1mLMeEUlKvcnihEViWgn/WG3os84Uu/I9Gt6VKNM
qUyZYGc5pq1n1QoRJlAuWtH1qXE9WiqP69dCFUoVrV8TFTeBhReWlj7e0ojl
J5Z6XyluwJQogtFNIR5urIvdTVWnoPZCtKiSMQVZlxgluJmHgvm5eZJZK6al
E10PYBsqXp01vGvJw/RTS/xDL1IxOdJ8M+lcJy48fgRODjxMruO3XnnegZVB
In+t0aVhJ/sYptjwsKcdV3gzu1CxzHTzDKEPzS8Nv+rYxsO04IiGSlUa6mno
nJcIY6K71viNVFEeRs0mHpA+14v+Elozt2+xUCX/z4emkRMY0rIxP+x5H46T
3urn3+XgpZ4As/C2cewbajY9MMLA5lwZne0PB/C0pPU5K94YarJ/FH2aY6Lf
/XAL54dDqJGX4XedPopUlsIIZwkLb7eYZPbeHkF3X6EXmUkjePqnFDl0hoWW
fWqPDC6MIbGysn/fxmG0t/zC3s1gY6jEzYow4wn0TyXO1gUPoqNDFLWlkIM6
s5FVP315uLrCOi6kgIvbfpWGqHtw8UqOu343TKKZO6eh7g0bk/dJm7mKDuBw
wtNAlelJ1Pu+/shYbD9+m659LhIxgK6WDy1s4/nonePnouDAQKN9XslruAP4
Jq0zQ0dBgFbDL4av8WiomLrpoob6IFL5EdK/IgV48eWwV7RsJw6Ffaz5x2wQ
Yxhyp851C7CwXTtQX6UVxUz0AuJNBlFR9yOfKDmF9nexucnsC0Y9dS/ZvXYQ
vQyVBY80p7Dgz8T3+vsr8Vjoh3DP3//Q8lEZd1Obwp9/314++TYX5w4HOtR4
DmC/4S9DwR9TmL7z5gHj3MfAjLYauTDIxY6IU5MhTQLc1L3kh+iq99B/XcSZ
ac1FLZEj1cVBAhSaPKRlFlADp+tePJlM4uBZZbHB27ICXCnyaNuP703gQVIS
TiKzMVB2sUozhY8+J1z6YKYV8NXdBMY0C+mpH/ImJPi40+Lkr/niDpDUeLSS
RmChG4veYu49ieSK+lxH9R5YuLpDPFi+H5NPnbkYU8vDBa2d3g42vTCm/V04
SZGJIbp24UqredgP1+Q1ZRiw3A4t6tYzMFt37F+PvHH8NXA3svc4E4z32l5g
6X3Dm4F+b0mqYyglYyA/H9oPEihouq5CRw1B6gOF+BFUeJ1ek/gvC2IaxEMl
fvs1eaFRl7swhNwqTVfRk2zICkmbHpXoQodVVZSt7oP4wz5LpG8DB6gbQpYx
xDuQrcH1LCRzUT9AqLn7IwcsdwSdNpKhotiqM6zXxhz86aLDqTXlwiXJh5UM
zVbcaf/TUSuPhev/OLv032wujBraaB3fT0HRtOhnJKV+jPL6YMXic8HuerHR
u7FG9N2yt7IjlYHJ8g81P28agIo02TPB5xuwPODa4oz5N0R2jgZj/wBs7DJ/
bL+kFk1LOvZqnKEhed79mMBxABYT4q8LfyRhYjPnSUhCF3q5iWsn2w1AnvA9
wow24iv+dfN5ejuKswhGjrsGIGxZ/P0G5ffotJv1937jNmS9eWcav3IACsrw
tb5TMSbEiV2sJ1LwPz/Df37G//yMO71zgqmPuRAmx+kNWkzHCxsW9y28rkNf
gf4ZAxsulJXOkvbEROOcZtOswYYqDGxKWNog4MBLVbMTViK+UMpdqc3z+oTN
c4dPx8ZyYB2XbJ7fmwQPrqoctPv+Ftut1i6c0+DA++Z4ol1+FhRQNwWW5OZi
8pduDeliNiwSlq2w+lUAyqmFoovy8egzXmNrY8gGz9BEXfVLRWCg9m5csjAc
mDeLjpaWsMB+++7tQ9ol4Hxitlp433M4daz516AeC4KPVjoSS9/D+JZiPVZ4
IcT5feg9l9EP5T6T3mrSn+Cjxi0jR7lSuBTA5b+U7IcI0W2uM0qVILomImHe
7RMMcVaFyfsxAbNbH/Y8+wyyhS/chUo+g9xxwV4FGgMG466nTy+vgi2vLXa9
T6wG9ZQrB4V2MyB7KPP70n+q4crnnOnNTnXg4qltv1mvD3z5R8TKntUA+3DO
LtvpBuDYmnMM+3rBlp8+WdxYC1dfEZQlrjeCvD0hK+N375zRtNv6iFsHFcMq
R/d1NMM1vo7xV10a9Bdk3eKM1cOlrGM5g/co4OW/nCDV2A1n08Tr9VkNwFI/
brIrvQUKTP2vlJ/tgqjmgpmR2i9gq9IR7pndCgt3XOulfnbAmvZWkzuPv4La
zTU6HaltoK4RFr4voh2mHUKZF441gtm7kjO1EVSgGZFkYqWokKFx6NqYRBOc
MJl7F3KmHejCnAbp+FZI7DRvP/6qCbxEjghMt3VAK2Fd0oR0C0wtN7dYgGbY
a8lQMPreAQSbk1k3FMkgMjfrK05qhouLK6yfFHSCwN/6s6pEIwR3ejwp3k6G
ieMzmXedusCB7vdWwKuHA+cVPRWSyZAWp71TbaoLlhi4my801kAyCdROjJJh
VufgeNDtbvh//fw/HsEbgg==
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.5238615751146362, 0.90544190963797, 
                    1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.7143565513072203`, 
                    0.12932754300446658`, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.1629437482950056, -1.5503062068157933`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 210->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FIobh0VJpeyEhIjI2maJvs5JlKXspUK2OEgpWziWaCXJFkWkkK1I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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.5079796482470137, 0.914446651575302,
                     1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.7163525233448333`, 
                    0.09938819848142166, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.18997550519649706`, -1.5472263271497597`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 211->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FAobxYnmbbGH3pIiyq7UDSkeZblpUbkl3ZCiSLZK1iJLG9KqqBAp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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.4919429858576259, 
                    0.9231728442041206, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.7178256777771548`, 
                    0.06941857935032425, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.21694939371877162`, -1.5436751473561585`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 212->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11lk8FAofxnEiKUsIJcmSEiFpUaS/00lJqkmbzsGpbKVk3yXZWhBilJJU
CFkmW0L+1rGbsczYJsswMyhjlyTec3Fu34vf3XP9/TyK1x1NbVbx8PB4/xvf
v8mcfsh1GiuHpOI5J1YkFTbHWzq+WdcDg63rCtJsS2DuvXe4PZEK9zR554lB
PdC2/70ecSQfhpREMtRjqFC/mK51abIHnHxk67QLMqFL1+/FtkdUoElkStAI
vZAWeaM9YDoR8pVacv7w/Hfv0J60lNwL1BA7v+URJ+j3JZFcLajg4Sb0Ket7
LyycVHtFKYvDsEq9uiQ9Kiy9LyGjCgNuH1thRy6lYZSLgUuGOBXkTr2I4LnE
gI2TUZzjFnmoJFJV11VGgSQVavVeTwa4XFBqIpsUI0kwb8TrJAVu0OzqJMIY
QL/ZqXArtRyzmup+dFS2QP1vFR2TaAbkuLt/KdWsRguBTvcAtRYI61IOC3rE
AG5ktft5rMXpFjfnVQHNMFwZ9oHgyoCyKBmKolkj0mm3jGmVTUDsv+MFZxhg
z5cevf5nC1ZmxnnYTjeCnXL6OYoMA5QHdSt/EVrxt7G6ibRoI3g9MnvhQuuF
FrmXLqaq7XhljTJNR6oB/I6N6D4J6IVNO++cvLGahsydGiSxNfUwXHZY2Xtz
L+hYnZ8UZdEx7mwmfzezFp6nn+r0fdsD07pOQUJ1XUi/eTGq5D0Zwk2N5ygb
e0BB9etTyeweXNx/jk67UAMukhlfX3t3g3b/Gg4ljoFz4OR9cLQK+PksrwrU
doHg1s+81Pt9mE6qaOJYVYK/vG246EonmJEyMox0BlAtgCeNUVUOTkrWyXkK
naDVxR+npzmISVwbeSGxMpAWlzIcVKNDqaTvFuvtTLxjrPwgyrIYOnJ/Nrpu
oYHo/Aa7i1uGMLv6Y/Qa50LQ9zdcf2i2HX4HFF+JkhjGsI9fJXYY5kI1v7nv
FKkNQvVkz9xfw8JEt95og48fYL90Uda5c63A1SIk3l1k4dksvqPXTd+CuKOI
6do0Cry7/563YoyNiZ01L6LbooA3azrYwrEJfvjZldt3cpB/s9C2ZmcnzDNx
6GbO1cFTAoPsgyNoTQ1pn939Asl+VyQGDtYAzlsmt7wZRae25jjTT2m4TXhj
94f9FeBRGv5w690xXPs51MLHMxeFr36U8Wz/DEnEosuLZ7+hk/b6YouBIjQm
bvOyTyHBKH/XD/Km7xi/naRQFIdYV6N5RdXtJdg/oPOU0r5j1trwMKXTVRig
3FAUZhSOSrogwAwex7qxS+t+zpJRgRknmLU1C/PLjErFlbkYmC1L7aloQMlP
kkUzB4rR13Xp+CyJi4OsZMs9uS14XIG7mwxVeJgTKbpadQKp4ozLfddasdiC
38k5rx5JKmR/4qMJtHNQOfrFux13LYcJyOtScdTCd2s7ZQKf3FxNJSfS8FVS
luVZbEd98UUH6sIEStFWC8W0dOLzB8fUKm07seRQtXcdzyQKb9AWPyDQg+V+
fH9Ka/Ri6ZXHDZs4E7j2z7iPOkcZuLXoiNqiSD96BDpx7qVO4PphXeMn/n2o
uUP9hnDgIE4eaxddqz+Bj9LfC539ewC9hFUXQ4KHMD95j87hNC7qB1ZufO0y
iNzK/N0fHrPQ9G5tHh97HL8XxGpcD2RiS7qk+r4oDhLODsk3zn7HGO3Bq+EP
htDzSZChWdQoshfUiInt33BCTWDNqP8whrTqv/0a8g2vzb4lGAWOofGz6vUa
Niw83q8co3VrHH1C5uLteUeRz83/sogOGwOE/csCdSfQXHnX8xhTDqodXXvE
bIqN6r8eVC14TGKbuSfFyIuF3z+duCYezUHnVLvd3TCFXNEaM0GPITQihi5E
bBjBMWKij+LcFO4z+yvgCGEQUxgyq6M8RtDyeJTh6dhptGfLp1tu6sOeU1sc
LItG8OOrzjfqsjOY6tpkk/5PN04+c1Lt6hzBjunQDT8fzKBBdPmgdVAHejiy
fwV0jGDEgMw12+4ZtJQ/Tw5XomCEhXZSaPYIbtUonc4SnUXh8fq8YM0aLH5W
JFRmO4K3DyrMxKjMYuzDAV238ELsKi1Yeb7MQVVXRa6N8iwqMO42axs8RKWb
6zslvTjIPPjz4MzqWXzIUH5CW86BCQ7/yjsaG+mh16buNc8gVdL2ncDuCmBL
Gg5s2MxGVb7L1Xl+M5i7dFvjx3w9vE+NkHM2YqG1guBIiNQMVoXUbhnY1go1
LJGFb1bD6CO1UqXyYhpjH+UUu66jwVi1mH2Z4xAyEkoyJoSnsW6AZyE+owsi
Cs3VpRyZaDPEaD3mNIX5ivEaR3kZ4F4o5LJkPYjPr1k5RJAn8eIXygxZuB80
r75GwoUBvKdxJkheYhJvf+Ztus4egKAj6hS7e32YojF+/2YGF4/P/PN4QYEJ
A4tFfULnGejv45lfuW0cD4XU104dGALfXYa9lSo9uGMmIVI29htGB5y19lId
Boa4QeZ+3i58vtykwV4eRfW0M8m/fw5Do4WLTjCThqbiVVRtuxFMjout2JHB
gk2XvVVNWtpxeAfbnkRh44RJEaVEjw2EVfHaueRWFBS3GsrRZaFohczGeBIb
uLcIz7tfUPDAuYULqhlDyL//wODbdRw4ODzz4HVtIwq8CntdKc9ErTn92JJT
HDgZKjuaI1WHHnsMyukJA/jG2Wu0xJ0D2u+S7ziEVmOxt9vK4rE+5HYK8jg8
5kA7cWPA580VeKSQbrDDqhd7HEXWBYdx4Ip4Ya5YagnGtbBe3iN2oUOQ0PnX
PhwgXDXPZlsWYPa0+7HfDBreqSJeP3aFA+Z5lubbMRsv6Q2dNNJtxzXjg3z9
OzngUWOe6XbmHRKfCjrUZVHxP5/hP5/xP58xU9rvtlISG8rFBAT2HHCEW3Ir
J5ZzajHq4n0jJWM28Bc4snjjnsGSSvMvLbkqPNVxOaR2lAXlOZsKCYop8Ikt
tmvy9hdMuli1c1UAC4KlX9UYLmZBpIsi4cx8PqpZacdnirAg+6VpyoJ6HmR2
7PQpTE/HUl+Hn+Exw6AbWrL1oNInUEggCaxsjsXlHNnHlySGgXh1yYbbVwxa
ygVcUVIQPD3xUvDD4yHQO2dlomhTBmYWv6p5T7wDka0/+Lf8ZsJqnQQzm95y
4O7J0xwKIoG/1zM1dXsmcB8t3Rqzr4TSHcGHLsh8ghj+Ci9C2yAoqPE0CjGr
QEA6lPjb5gskjErfnNo/CNUicjIf/qgBKdJ7O57CCvjJ3st3mzgAw5pXvyU+
JsOeHEOdz3HVQN+lWbyd2Q+/fb0P536pBeeK1Dm1S7Xg8lpP3PJpH6wQ/hFL
7q2D4YupOqfn6kForf5X3sNfwckqV1+FVQ8u2SIKwu5N8GmeqxXY3wv7KC8v
MHsaoGxM8a8T9Bb4RZBr++NuD9hH6iQ4fmmEO8l/p46EU6F8VX54nFQ3nNCu
VrCIaIKh7eb6OkmtQJjfdbMhrROyxhua1U81w2lFepB9Shs0NGbUbdGhQyHv
iagLP5pB2V9anZ7QDsIEtZtV5R2wuTLk7pGnLXC0oNCKHNoBPbPT578ZtkOI
teiS0RYKWOgvFdyzosHhoJSiz+RWYItaficTKXCb7/LMkb10qLRdLjT5kwrf
LmZRVpYpYHB8QPbQPB1ar3Roe3k2A39fytxGdSo4rKw79TKzEwQNBvn3XW0A
S4u8vdUEKkyYL759fKkL/qbS5TgGteB6XyX/mQMVXj3ddUB5tgvcvPu+vpWp
hlbZCrGkQCr8Uidw/UK64f/95/8BT0USGQ==
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.4757564728691872, 
                    0.9316178294416183, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.7187755658670747`, 
                    0.03942781464748382, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.24385719735408345`, -1.5396537491587554`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 213->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FAoXxkfiSqQUpcWSyRbSSt04KlRkabF0QyjrJbShXCohkSR6JSSv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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.45942503985035593`, 
                    0.9397790348634836, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-1.7192018982694783`, 
                    0.00942503985035596, 0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.2706907197247835, -1.5351633575143977`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 214->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FIgfh+mwERWVskWjLEuukiPKT62jHIVto4PKGVKukqMQasuRDrZC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.44295366151383614`, 
                    0.9476539744874856, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.7191045451193865`, -0.020580605905212736`, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.2974417870800155, -1.5302053402398799`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 215->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAoXx22pa+lGRSmyRXYqiXAkS+pacqVSabEUJSrC5VIo1xYVbqtU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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.4263473552010306, 
                    0.9552402495307283, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.7184835360715118`, -0.0505799826088539, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.32410225078551974`, -1.5247812075952931`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 216->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwfxXmViCSJNkL2tXptqfxLUSmSVNq0EFKUXeXDSyhUElGRJS1k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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.4096111793537112, 0.962535549140344,
                     1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.7173390602912257`, -0.08056395215981316, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.3506639898057856, -1.5188926118239854`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 217->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobh20JqRBKVGNfonIqe72dDoUitFEhZSlJSUc4hRBHWpwiU0Qc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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.39275023197316816`, 
                    0.9695376510974003, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.715671466396938, -0.11052338115050395`, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.3771189131777983, -1.512541346649273, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 218->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1luc/FQwfh5NIiLg1UJzq2CsZofRTGamQyB2h204qiYwI2SPSIImGG0WU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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.3757696490673092, 0.97624442249381, 
                    1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.7134812623539029`, -0.1404491436486322, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.403458962475624, -1.5057293467280541`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 219->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lvk/FIgfhx0dKrS5SjkjIqTcOj46yFZIB7KyRRo5IpUrkYSieyNXhZCz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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.3586746030861821, 
                    0.9826538203820364, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.7107691153194893`, -0.17033212397704375`, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.429676114265085, -1.4984586870614942`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 220->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FIobxoUkR0iSfSkSIUvZzuHrZM0WZalT2iQlWyUkobQjJB2JilAm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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.3414703013463958, 
                    0.9887638923973929, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.7075358514399566`, -0.20016321949044769`, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.45576238254777496`, -1.49073158236296, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 221->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAwfxSl5ZCl7UVkyUVGotHjTX2VJZKkeqRBJeSqRJFGWJlJSKGV9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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.3241619844449225, 
                    0.9945727773527544, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.7037824555988041`, -0.22993334334817, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.48170982119367145`, -1.4825503863833975`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 222->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FIoXxutaUkklCpVMxKWxpWxdjspSSSlLSupGlkQkFRJlKdmKkCRU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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.30675492466275955`, 
                    1.0000787058054914`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6995100711167652`, -0.2596334272820942, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.5075105263616044, -1.473917591194354, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 223->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIwXxom8KireolKWzJsloo1IXclSkmyVFkqSsldkyRvZKmQLeZFU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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.2892544243589427, 1.00528000059646, 
                    1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6947199994035402`, -0.2892544243589427, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.5331566389068428, -1.4648358264288728`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 224->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAofxpUWWSPEUfZjC2UJSf49hdMi2SoKLVIKWaIkxzaokFaS6qAs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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.27166581435539555`, 
                    1.0101750773608809`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6894136995613758`, -0.318787311736061, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.558640346775066, -1.4553078584804775`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 225->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAofxStyhRYSWSq7SxRtopt/i+WWEirJMsqSCkluWbKVcK1JSJZI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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.25399445231310985`, 
                    1.014762445010952, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6835927879406067`, -0.3482230934098625, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.5839538873819908, -1.4453365896605057`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 226->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk01Isfh1VSSov9RraSsaY9Ed+SVJIoVyW0imQLIQklWlTIklAKuQiN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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.23624572110015007`, 
                    1.0190407061900482`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6772590376473018`, -0.3775528029560986, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.6090895499779309, -1.4349250573140333`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 227->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk4FAwbhpUvSagkKntN9rXNUrwqqj8qfNJi+ahQSqREsoWUKCWk0m9L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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.21842502715197956`, 
                    1.0230085576983698`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.670414378003156, -0.406767506261118, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.6340396779965646, -1.4240764328946718`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 228->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FAobxYnrSlrsFFkSWaNF5NajrEWKV6hkeSWSrVGWKNmqG8pasiT7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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.20053779882460782`, 
                    1.02666479088991, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6630608939578029`, -0.435858304243285, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.6587966713872002, -1.4127940209985124`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 229->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FIofxYUsJV2SLCXiJlmyk6Wfmyxpw5WiTShCFEKSRKhQSrRRpJQQ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.1825894847410608, 
                    1.0300082920406204`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.655200825453718, -0.46481633556372537`, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.6833529889298248, -1.4010812583575138`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 230->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11lk8FAofxnFFUrSIqFTWSCGlkoq/akSbpNVSJwl1REi2HKNsWdsoKiVH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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.16458555213167764`, 
                    1.0330380426876604`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6468365667439093`, -0.49363277932557587`, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.7077011505322321, -1.388941712792641, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 231->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobxpVSMUmbUtnFEUW0Kr2pqCRbtgpHyZItIVu2LBVFHSLZKtlD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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.14653148516873907`, 
                    1.035753119939634, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6379706656626063`, -0.5222988577609158, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.7318337395085326, -1.3763790821270707`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 232->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk8FAoXxklXZInK2MqSXYQrS1McFXErkotboqvslZRsWUoRFUULIYSs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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.12843278329593563`, 
                    1.0381526967577077`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6286058228491642`, -0.5508058389045591, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.7557434048383459, -1.3633971930598008`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 233->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11lk41QsbBXAdkcyEIpkzlDSKSK+KdEjRIBpkqFRSUpmSMXRCUZHMSSGU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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.11029495955318405`, 
                    1.040236042207538, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6187448909254236`, -0.5791450392538962, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.7794228634059948, -1.35, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 234->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1luk71IsfhitFSUSWNuEQZYlKJXI+LSinFJLKdhLiFGWNpCiFQkmUGCVZ
EmLIksoHY5uEscyXYbLMagph1MkSv16ct78X9z/wXM9zX4/K2UvWbosWLFhw
5Tciv3njJjQy0k+Gs+e7R0wi2mHtE6dLz8V7IEy4x/xrszNAbZvhrvE2CN2y
8EdieA+8OPlzq2hzIm659FHj6vE2oE7n6NmO9UDynQdWy8ayUOy4abNYPg3o
MnkydMteOBQWO9IdSkYvXp946kwrUL060mYzesET/vZ9e7cMaQpV6pejW+Cy
//Ky/OFe0A+qtUlJ+oCfJz/FuS9rhtnsd/WowYRSV00s6axGnm+p5faAJlA8
nBy7wJYJD+4Mqkb01WI9Ib3+QQsV0jRotdsDmVBwzCwoR9CAEatoz7fINYIH
3b1RJpoJT0v2+Sz68RElmzf1FhyqB+ovjV1HHjBBNk1gf16kBbs79NwKPGoh
ulstOvwOE8rWOlV2RdFwzITGq/SvAU5NdK6lHxNMzzHSzVe2474gp0h3zypI
7L8YBEeZMDxXvIXzuAMv6eV8t3n6HtzVcqxa1zAh+lq8QZASHU+VkaxFdpdD
0J1Tyb70Xngv/pz7KYvAtLThsarsYggxGTK8F9YLpHnv4091utEkVmq6vT0f
OJV71K6s7YXdmT3rScUMJIncePps6gUk5RzuupreA3oH5UvdDXpx9f7pykXh
DyHG+q/vrQo9UB+gRYp/x8SwXP19AXN26Cv76vOzKwyIyu06TtrTh3oK9LdW
rx7jYhGnM6IN3RBjqqc/VtGPUSWkkKsG2Xhd6VyM5HwXLHlKDRlPHsCi2cL0
1TfJ6P2Ha0axchfITy+SOmU7iFarxLx2pJahvLSc6aAmAbPk68FGUiwUvLTv
uTP6ATuLppr81tNBeIJfu66OhRdTMlv8jGrQ+Lqp1O7JDrhqPJTmHsjGWwHk
9KCUOqxd7HB1vLAd5EI60oM3clD97sKsCAUq7pAvz7eyaoPw7UYOKS0clB0Q
j8gt+ITSl1ZYL3vZCm3XfrlM+XCR7rHVjr2VhgvzJ245XvoED37OWudK8tBJ
XKsC17Rj8REvBut7I4TX6FbnveChddgIZb1UJ9aHnJYZMKiDo0Gj1kxdPhY2
c7fdkiZQVUKBkbujGpL0E75OkfkYkpUXYKncjRJnyGsCO97CytlnypmbhtAS
vCkZhj34V6Jq0PnMQkhOey7lED+E8eT+ANe/mdhYt+X0Zv8UeMkyqg4eGcLg
JW7vNsf2YZjax/LoQzH4oWTHESMDAdrFZLEUnQdQmfVoaf6GfBSXjpss9Rag
5DRhs//6IMqWyZYLd1agFsUgeihBgGbynAwKiYVmyqO69UDBVY5/2RWmC1C+
M4uu+Y6NFY6LvX2KqbjR/PYo47EAhVv9NGu7OKg1Fy2qZEjD95fXSKn5ClBH
4gk5ZYyLqWn5TsewA9VKP285rCvAXIPI1VdF+JgUaaJZc64LhRTbh/LNQ3jW
wOCQYMUQVoWIHJDX6cU7CuI2HuZD2FdVfUJ7hQA3lP+pOb2iH6lWnjqW6XwM
45FPHZ0T4BZ1bQ+Jm4O4aqXIiDLBwyqfi8Ub+75gkMTm6du32NgqdvhnJJuL
V8oEJs45X3G05o1u7l0ukrUUlbOoHBR/NNme5DCMLTmy2vpxfIxPVCBtimIj
ubG+0nlyGAPvhZueihPgJot3JWeUWKjj96Xa3WsEb7cZp3++/RXFNN3dTsUN
IJcsWH6ndgTN+tUe6l0YwSj28UnK289Yzkx4OfljBMMkrlfeNPyGnpE5zfuk
etAj4Em2+aJR1J6JpPy8PIbmRfUSspsIdGcaKZdwRtAny12XAeNoJ8EyfCPR
jooytDGJ1BH8kvg0WOX7OPr6XtFaeq8JaQVi0lzNEXQyizO1SJhAu8wNdaq1
Nbj8gFp46r1hJKd2PddeJ8SDMT88tbOL8eGzWld36lfsnIhYNRUpRO+k1Yru
L4OxSab98N7PXzB2YI3zOYYQj/ifuOZgVAgbosa+sj/9zl/n/US+5CSKXhvN
Jw1XwelBBuNNyhB6GigLH2pM4loXVZpmGBUe+rqKPrXg42Y/lVE3tUnMo0Ud
9x+kwUc6Kn3jcZFlMGUgXDKJO9cmvRildcKjRQp2Oz05SEQ4j4c2CzHOemlC
QEQ3HAMjzbUsFm4WOVlbHCLEyaLtmyJmeuGGmO3+HRaD6Kq8dOi2nBDLHQce
btfqh8r7NOcRl34MlpunaCRPYOqNQb7UskHwtpLnSm5mIpP07tU3iQnUSih8
tu0kC4K3R9p5jnejG5vZZuI9jlMWZX4VoWywyCcHtVPomOTs4hVbP4abG95f
+nGTA6RG90CdrHYM1TkariQzhokDF4xLnLmQVFGYJWbUipk6Izf+eTWK4eV5
yTqKPDjDjpoT2lPxenDgmxrVEXwv3ejFL+WBv6vjpooSCqoLSffXJXzFRcTp
s1l6fDh0k279Mfk9Js190uH97nWrvXSebQwfPOSfzOhYFKG1NIW2zX0IdVVt
D8428SHoqow2VfI5ctR55wtbedgac6UrY5wPCzi5y8uun4Ol0i7sAkMunivV
VnCY58PPkIbt+o3psNPqp83mV2ykDHaR//iXD1XnH2Y13CGDaGr0s5rf/Xaq
jzLn9/CBRxM7NK3+Fi5v3VtFkAbwnrWdy408PpTRXwbaKFVBxRX/+WmTPnT9
4/B4vhcfvi+Zqzc9T4E/S4m96i692KfrtW2FMh9M7Abc/S/Xw6MWbkpoYjcu
briarVLHg7abb9N2mFHh9USAyS8mHTUWMwaOOfFgIDrq9VxvE9gasc0PGXZg
dF7JRN8wFx7ctPtywrAFEuOXejXm0/A/P8N/fob//Iz9+fL+r0c5EF+rwr2g
0wYXFOcPzhU04JM6i2ShCwese6jdC6XbYVajeUZPkYJddRSNrHY2eAnYvozP
7VDGW6k15vkBA3czpmKM2FB+SrZqXWIH3PdVsTz64w0G3XDRtXvGgsd6JyS4
uzohr3NTcGlODhbp3yXy5gZBj2XVcaChE5RJhaLzaxNw49iKGBm7QfBcp7Ta
wIQOemolo5KF4cD0EhNbVjQAZH8HqeICOpxynKldePAFSApnYudFByCuRF78
sTgBo1uLt7DDC0H/y8rswqI+GLXIjS87QcB79Vu7bdaUwZ4Gjl+H9WcIFrtS
wHhAgKh8ROIvtw9wW/WfmbnRXkhItt/3BgmQK8x2X1BaDTZyjvfLInugvL8l
YKyfgK0FprvePqoFPaeFlt6KDGApa5lpCgnwqc76rmnbAK32lO8xhV3gehDn
xqYI4JzI2mXxnQpHH9X6uOwjgGjOpjZMEuD7eoWyRMAnMB6y9jD+veuKEE1D
dQ4BlV9U7A4SLSA36Rt12rEDfpzeQAQ1EnAxwz5rKIYG6rJJlOGhNqg4G56i
kk4Ae6OD8a60Nqi+Feeh6keD2HPDYUE+BFioEOHnM9thfMcGc5OfzWCcS/nW
tJMAtevy2gSpA9xObOtZsbQJlHbU7XKeoMP+klKX+ohOuHlg8lXH799Gtjk8
459BB0fj2ZJQFzrs4fpkvFOpg38f/ZlgZEEHT5GTwj+3E7AktIXB0qqB9pUZ
PoPDnbDXbGDd7h8E3G1a+OqDRyVkBvK8osM7wWte/HBKXheMkKqfXLtcDpkh
0htOSnfCN4fp9Lu23XBQfDpuzY0iKBS3WGv/qANS47V2qk12w+J1ii2G0jkQ
WPkTsmU6YEbbcjTkNgP+33/+H2VwHn0=
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.09212353889730143, 
                    1.0420025216819195`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.6083908736267734`, -0.6073078264139723, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.8028649022190113, -1.3361915838624554`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 235->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAoXx0NJXabLRVFdY8mWrZJCHK+I0kYUhVeEKFkqSaVlUNm7IaSo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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.07392405651904982, 
                    1.0434515970940914`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.5975469248871839`, -0.6352856217269999, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.826062380605285, -1.3219761508244878`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 236->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAwbxfWSyidFSEnI1jIhilI88k14VdImhBZroigl9FJIRJIo1ShE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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.05570205615706401, 
                    1.044582827041646, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.5862163478784894`, -0.6630699028854996, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.8490082323881805, -1.3073580310447086`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 237->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAoXx8nNLaEIpcWSQURoVV1Ot9BCQllSSYkp0SI7pbK0aJEiV/ZL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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.03746308840917491, 
                    1.0453958669409824`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.5744025940042083`, -0.690652206528278, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.8716954680389631, -1.2923416773440115`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 238->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobxvmotDmRSIuIshclInolVFLhI1TarEVRSiXHVnSQkLUsqewM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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.019212709041643263`, 
                    1.0458904691322717`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.562109261848213, -0.7180241308184493, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.8941171768058772, -1.2769316638492003`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 239->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxokkyZUQura3QbJUWmzx7xYicrW80kKLbOGitJAlTWRtUSZC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {0.0009564772968198354, 
                    1.0460664829548947`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.5493400960785666`, -0.7451773380027178, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.9162665288192289, -1.2611326845996662`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 240->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk4FAobhjl8kiiKTilbZAvRcoT01gkJFSVpUflsrZR9K7KWnaKylIQQ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.017300045800253818`, 
                    1.0459238547933356`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.53609898630686, -0.7721035569511355, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.938136777171829, -1.2449495521175362`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 241->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1llk8FAobh4kkySlZSguiZK0OEaW3U6SIkChbhZAQSWihrNlKWZKlJMke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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.03555129913578743, 
                    1.045462628093515, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.5223899659033995`, -0.7987945856765709, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.9597212599741676, -1.2283871959417338`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 242->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1luk/FAobhpM4KgqhVMKxpQinUogH0aY6qEihbC1KiKJIMqFSodKxniTJ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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.053791723201210895`, 
                    1.0446829433495533`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.5082172107686023`, -0.8252422938331119, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    0.9810134023836892, -1.2114506611263942`, 0.9}}, 
                   0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 243->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC
Ubayi9fekGUYM2bG2MbMkOxbWdLfh/v1/+H59J7znPOe8zu/8yhcumZuv4KH
h8dvOXzL2SDVuVEw4Dm2vy7L9X3YBjIvba+9FmLAFh1+1zGrVMzmzrjplrdC
kBrvbHQIA87WHW8K187BRB+OuwmXBPXz6XvOjDNge663tkp1PobK3GSnriQB
ReKjBMW0E57OD9SdNSzFpimlYketZqh3JScvpnRChO6luUCHChwXdpBpPNUI
3teFCzOHO+G+5dWZ4B3VOB2mLHzEpgEW35XWoRITPkoWF20ZrEWRqpT25xZE
2GwU95DnDBOqTpuf1Esj4q+7wpf8tOsgWYlUs8+HCV4pxNKyS9/wi0pT2Vvh
GnCkOBAlIpjQnzOe7rG5Gc30jGLLGiqh/reS5oknTHi633iFhAsJrRK7C1uH
yyGCRogIuc+EY3Hj6sfrWnFSmpAWvKkE2FURH0y9mHBUsEhXQ56Mwxvu1eds
y4foHjdfMGGCbw534b1vO9oxg5lBvDngQEg3a9nIhMFrZRccWyg4ePvFEr9z
KvjePxfnSekE+iPtI3sJHVjkvXeTzMxzCDgyqPMouBOczFR25nvTkOfmIcFn
GZbILtcl+Ml0wqJzDje2jo6m5Vv9NvXEYmy6UcfNNwxwN/1L3GtdJ+aJxbms
cnuPkeaGMy3rGWD4kmHXYM1EDaPHj0zsP6GnZEbXKz865NbTB9e96UJWU3Vq
eHUR8vPZXhD4SgONwOHJHFY36hll2PibIwbKXYkU+9MB93gf35oV60Uh4TtD
bqur0X2rXcpn+Q7Id9BJvpXei6ItQmGv79ShtLiUfp8KFS7AFjn/g33I5/JY
bJVUA7Z/mvvmtYkCPxfC/ZzIfahKMOAtqWjCA4H6a7SnyfDyrvlS0UUW5tkG
W1OrSFjDb31zIqcN7AniR2uGWEjyNPpJyW3D/dJFmWZmrWD6ipJCdu1Ho507
H+3IbEfxa6Lmq9+3wAVtkzCZoX70q86iBeRRkTdzMtTmWiOscXKh59uy8bTW
miWbrzT8fMKVzpohAt8LxQcZDWxUEbe33sVhYF2ApUSvVi2o/vNbmK3KwaEN
3HhZ0S7cJrKe/mF/JXxk3FTcF8pB0tVWUQW9HhS5kLvRh1wMp9JqhYxbOEhs
Mc32L+1Fw+htvs6pOfBp2orRIMLF/u2LZ/g6+5BYq2apfD0etL6erlP+m4vX
7cOlixZZGExoKIo4Fonnv32c/XaOi9Tpf//2lWOjPCtmVeaWTPwWdNZ9/jIX
NZvjZ8b+4aBkoWTRlEYJVmyr1hy04qJKgGzJs0tcNJAf3V0H1ah0eHaiYLk/
9dZt2YSgASyx4Xf3+FyP363rjt3i52JUbKvriheDuHMpQkBOh4TJ+kIWJz9z
0NlhPC4w7TsmJmfankQySvQyDx434CCPSdOr8A9DGHv3iErVlQ5ULq22TShl
45pNlVqmb39gRQDfYeldnfjbZTApSZyN/t1pJygPhnFLkZ7KvGgPbiucc2Ia
9GNXY1tqp+0IqimqOorc6UOex1K3VK1YSBvW8+fZNIq+IsrzYaH96PR6j16t
YR/WnuXdTiwfxdGqvN0fHnDwsR0923xDL3qeloJPh8ewOV1SVT1qABX6HCvX
h3fhg6n1C2bvxtDnUYj+uajv6Fj1hhH5goF7LKWPOXPHMKz1wJuusB94INZ1
WMSxA+XVt5BElsbQoIfwbI/LCA7sY6dLLJLReGWGR8mPMQwWCSy/ozOGPWvv
dz61JOHWpZv2IZljqLpwt/qX9ziWEFv4B9bUo/1Xj1HCoTH0SHPYTYcJbLj7
y71PrhIzeX2ObU0fxaHoJH+FmQlMSrsTWTqSiwxdwyQqawRtDaL0jZ9P4vsS
5XN0kxu4ur5lW+D4MOYmdrxWlZ3ClFfENKGSLCj3TBDa3/4D2yfD183dnUL1
a7zW7nMI531n2n5EDeHD3o0Xr9CnUPQ2a0BQmQjm6rV2ZirfccuuL5OZYtOY
nPxWNkmMBEoUgcN5KQN4VUt+6pnSNGYqPLhrxSKDcVDLOHOZC2UvhVF7wjQa
meSeDAjvgA2rfRTZJ9nI0prTmlo5jT/uV1WJTzGgZeu6bMEIFlLDL04ENU3h
gg9z9qVCN8jPu2YHL/OvzHe25nPAFGb6qCRFhPeCk0uMV2ljF9rJrxoMk5rC
1mytAkF6H3zt7OOtlWegv9SfaqW4SeQrVt2hJ9gPtcVP3jJvUpGZUJoxJjKJ
ZDmB+I61bCjpNE4gc9rQvp/ZesR9Yvne/FJqlg20gETCWEMzxl687Pqwbhz3
lp5q+VLIAUne4SwJXiIG7TIJkZMYR5+5FfO/z3DBu9qq7ZZPJabuGrntlDGK
xscvztpSuHAMaY3aLgUY6O+TV7VtBB/weUykqA9A8rqDpjz8qag4lfBY9vkP
PPM9K7TCewCCrQ31Vyc5QuxS4y7u0nf0iDLe9yVxAHioOzkp9WlgLl5N+sth
EEcOytzO/DAAa5+0NN04nw9sRa5zTgsXJSgX0t+/GYCcttFDtPflsEr8cn+2
Dgdd+wI6CkIHoOaUxLVL76pBw+yXhXJGP4oXO2c0nxoA3bioed33X0EgMeJV
lRwLLTyyypvFByCmXURW1fIbeO89WEFN6MWsd+LTfhVcKHpokt70pRlK/K7/
mT/SjU4Puwg3LnLh35QkacEfJNAroB5UvNyJRAHHVQazHNBZoFgJWrRBTDMn
PiiahocSPXlPBXOgiPknRDCeDFmTN478ZlLwRjwm9/NwQH64oSezsh3O/N1/
/JgOGd/O3/6o4MeGoN82M6/qKRD9dJUrMZOE//kZ/vMz/Odn7I6MJlZY9INU
T0MDLaQDXDb/ObqU/RWbJgzWjxazQD6Uf0pbmwaLSk0LezZX44G47mE7GRaU
tLXzSlNpUMhdu3P8ahm+MJzxafPuA539cc9I5+nw2FPB1GQ2D1d8tnAitfTC
7J5itZJvdPjYvsO/ID0dd2vU53K390LUpuayNUoMkE/IEfgj8xx7J4fMZaa6
QTbXzmXejQF7CPmjYjkhkEUg61jFdAGP1xzxcQoDztks1PAefQuabZEh+hpM
UN1GU2sjMmB072e1/pAcyPtZsOYWmQE80SX6uUwGfFEM1bbYWAhqE6tyI93o
ULXIyhTqY4CAdHj0b/sySIg1dBgRpEHJDKU4g8oAqZx3DjwFlXD68/qrgslU
KE3rVjcuZ8DebH3N4pgauOEWIqauSQG1+xq7k2IZ4FGZNqNyZpmLf5cuYhMZ
CBvFvulcYQD7dJqm8Uw96G1aWfP9chscWt0h8Gn5X88sUXmRG42Q/2ar7vc5
ElQ4b74T1kWH8iEFq6PUZpCPueNFkWsBO/tFHZV7dHBLOZ82GEmCvTdPXFE8
0QgSlu2HVu+gQ/926wOaya3w8kWMGa9fPbgfvOQUXEYDYwVqiHNqG2wU1ZWP
SasD6quiLtYxGhACpVWpCWRofPrTVIhSDVFruDV+DR1wKL/gcl14OzBXKPn7
81fCuVjTutBDHWBzYDE/6DIFhFXfnvvp9AWspRYe6uRS4Srf2Sm9fVQQ/qno
rt1UAL23RPXrpalw0KBXVnuWCsHJ9wqb/8qFkQpJ3rNeFHD9I2QU/7EDBEpS
vML2vwP1mlCVFV/bYcx6/s2DMzSYdtd5cFUyFoSbNnT2ibdD4tOdGoRpGrjP
Dya4eluD2ZMydQELMiyomo4GhNHh/+3n/wGwzxVc
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {
                   1.6, -1.6, -0.001}}]}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005],
                     Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
                 {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
                  Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
                   0.1618033988749895, 1.8}, {-0.09079809994790937, 
                   0.1782013048376736, 1.8}, {-0.1414213562373095, 
                   0.1414213562373095, 1.8}}]]}, 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 244->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC
Ubayi9fekGUYM2bG2MbMkOxbWdLfh/v1/+H59J7znPOe8zu/8yhcumZuv4KH
h8dvOXzL2SDVuVEw4Dm2vy7L9X3YBjIvba+9FmLAFh1+1zGrVMzmzrjplrdC
kBrvbHQIA87WHW8K187BRB+OuwmXBPXz6XvOjDNge663tkp1PobK3GSnriQB
ReKjBMW0E57OD9SdNSzFpimlYketZqh3JScvpnRChO6luUCHChwXdpBpPNUI
3teFCzOHO+G+5dWZ4B3VOB2mLHzEpgEW35XWoRITPkoWF20ZrEWRqpT25xZE
2GwU95DnDBOqTpuf1Esj4q+7wpf8tOsgWYlUs8+HCV4pxNKyS9/wi0pT2Vvh
GnCkOBAlIpjQnzOe7rG5Gc30jGLLGiqh/reS5oknTHi633iFhAsJrRK7C1uH
yyGCRogIuc+EY3Hj6sfrWnFSmpAWvKkE2FURH0y9mHBUsEhXQ56Mwxvu1eds
y4foHjdfMGGCbw534b1vO9oxg5lBvDngQEg3a9nIhMFrZRccWyg4ePvFEr9z
KvjePxfnSekE+iPtI3sJHVjkvXeTzMxzCDgyqPMouBOczFR25nvTkOfmIcFn
GZbILtcl+Ml0wqJzDje2jo6m5Vv9NvXEYmy6UcfNNwxwN/1L3GtdJ+aJxbms
cnuPkeaGMy3rGWD4kmHXYM1EDaPHj0zsP6GnZEbXKz865NbTB9e96UJWU3Vq
eHUR8vPZXhD4SgONwOHJHFY36hll2PibIwbKXYkU+9MB93gf35oV60Uh4TtD
bqur0X2rXcpn+Q7Id9BJvpXei6ItQmGv79ShtLiUfp8KFS7AFjn/g33I5/JY
bJVUA7Z/mvvmtYkCPxfC/ZzIfahKMOAtqWjCA4H6a7SnyfDyrvlS0UUW5tkG
W1OrSFjDb31zIqcN7AniR2uGWEjyNPpJyW3D/dJFmWZmrWD6ipJCdu1Ho507
H+3IbEfxa6Lmq9+3wAVtkzCZoX70q86iBeRRkTdzMtTmWiOscXKh59uy8bTW
miWbrzT8fMKVzpohAt8LxQcZDWxUEbe33sVhYF2ApUSvVi2o/vNbmK3KwaEN
3HhZ0S7cJrKe/mF/JXxk3FTcF8pB0tVWUQW9HhS5kLvRh1wMp9JqhYxbOEhs
Mc32L+1Fw+htvs6pOfBp2orRIMLF/u2LZ/g6+5BYq2apfD0etL6erlP+m4vX
7cOlixZZGExoKIo4Fonnv32c/XaOi9Tpf//2lWOjPCtmVeaWTPwWdNZ9/jIX
NZvjZ8b+4aBkoWTRlEYJVmyr1hy04qJKgGzJs0tcNJAf3V0H1ah0eHaiYLk/
9dZt2YSgASyx4Xf3+FyP363rjt3i52JUbKvriheDuHMpQkBOh4TJ+kIWJz9z
0NlhPC4w7TsmJmfankQySvQyDx434CCPSdOr8A9DGHv3iErVlQ5ULq22TShl
45pNlVqmb39gRQDfYeldnfjbZTApSZyN/t1pJygPhnFLkZ7KvGgPbiucc2Ia
9GNXY1tqp+0IqimqOorc6UOex1K3VK1YSBvW8+fZNIq+IsrzYaH96PR6j16t
YR/WnuXdTiwfxdGqvN0fHnDwsR0923xDL3qeloJPh8ewOV1SVT1qABX6HCvX
h3fhg6n1C2bvxtDnUYj+uajv6Fj1hhH5goF7LKWPOXPHMKz1wJuusB94INZ1
WMSxA+XVt5BElsbQoIfwbI/LCA7sY6dLLJLReGWGR8mPMQwWCSy/ozOGPWvv
dz61JOHWpZv2IZljqLpwt/qX9ziWEFv4B9bUo/1Xj1HCoTH0SHPYTYcJbLj7
y71PrhIzeX2ObU0fxaHoJH+FmQlMSrsTWTqSiwxdwyQqawRtDaL0jZ9P4vsS
5XN0kxu4ur5lW+D4MOYmdrxWlZ3ClFfENKGSLCj3TBDa3/4D2yfD183dnUL1
a7zW7nMI531n2n5EDeHD3o0Xr9CnUPQ2a0BQmQjm6rV2ZirfccuuL5OZYtOY
nPxWNkmMBEoUgcN5KQN4VUt+6pnSNGYqPLhrxSKDcVDLOHOZC2UvhVF7wjQa
meSeDAjvgA2rfRTZJ9nI0prTmlo5jT/uV1WJTzGgZeu6bMEIFlLDL04ENU3h
gg9z9qVCN8jPu2YHL/OvzHe25nPAFGb6qCRFhPeCk0uMV2ljF9rJrxoMk5rC
1mytAkF6H3zt7OOtlWegv9SfaqW4SeQrVt2hJ9gPtcVP3jJvUpGZUJoxJjKJ
ZDmB+I61bCjpNE4gc9rQvp/ZesR9Yvne/FJqlg20gETCWEMzxl687Pqwbhz3
lp5q+VLIAUne4SwJXiIG7TIJkZMYR5+5FfO/z3DBu9qq7ZZPJabuGrntlDGK
xscvztpSuHAMaY3aLgUY6O+TV7VtBB/weUykqA9A8rqDpjz8qag4lfBY9vkP
PPM9K7TCewCCrQ31Vyc5QuxS4y7u0nf0iDLe9yVxAHioOzkp9WlgLl5N+sth
EEcOytzO/DAAa5+0NN04nw9sRa5zTgsXJSgX0t+/GYCcttFDtPflsEr8cn+2
Dgdd+wI6CkIHoOaUxLVL76pBw+yXhXJGP4oXO2c0nxoA3bioed33X0EgMeJV
lRwLLTyyypvFByCmXURW1fIbeO89WEFN6MWsd+LTfhVcKHpokt70pRlK/K7/
mT/SjU4Puwg3LnLh35QkacEfJNAroB5UvNyJRAHHVQazHNBZoFgJWrRBTDMn
PiiahocSPXlPBXOgiPknRDCeDFmTN478ZlLwRjwm9/NwQH64oSezsh3O/N1/
/JgOGd/O3/6o4MeGoN82M6/qKRD9dJUrMZOE//kZ/vMz/Odn7I6MJlZY9INU
T0MDLaQDXDb/ObqU/RWbJgzWjxazQD6Uf0pbmwaLSk0LezZX44G47mE7GRaU
tLXzSlNpUMhdu3P8ahm+MJzxafPuA539cc9I5+nw2FPB1GQ2D1d8tnAitfTC
7J5itZJvdPjYvsO/ID0dd2vU53K390LUpuayNUoMkE/IEfgj8xx7J4fMZaa6
QTbXzmXejQF7CPmjYjkhkEUg61jFdAGP1xzxcQoDztks1PAefQuabZEh+hpM
UN1GU2sjMmB072e1/pAcyPtZsOYWmQE80SX6uUwGfFEM1bbYWAhqE6tyI93o
ULXIyhTqY4CAdHj0b/sySIg1dBgRpEHJDKU4g8oAqZx3DjwFlXD68/qrgslU
KE3rVjcuZ8DebH3N4pgauOEWIqauSQG1+xq7k2IZ4FGZNqNyZpmLf5cuYhMZ
CBvFvulcYQD7dJqm8Uw96G1aWfP9chscWt0h8Gn5X88sUXmRG42Q/2ar7vc5
ElQ4b74T1kWH8iEFq6PUZpCPueNFkWsBO/tFHZV7dHBLOZ82GEmCvTdPXFE8
0QgSlu2HVu+gQ/926wOaya3w8kWMGa9fPbgfvOQUXEYDYwVqiHNqG2wU1ZWP
SasD6quiLtYxGhACpVWpCWRofPrTVIhSDVFruDV+DR1wKL/gcl14OzBXKPn7
81fCuVjTutBDHWBzYDE/6DIFhFXfnvvp9AWspRYe6uRS4Srf2Sm9fVQQ/qno
rt1UAL23RPXrpalw0KBXVnuWCsHJ9wqb/8qFkQpJ3rNeFHD9I2QU/7EDBEpS
vML2vwP1mlCVFV/bYcx6/s2DMzSYdtd5cFUyFoSbNnT2ibdD4tOdGoRpGrjP
Dya4eluD2ZMydQELMiyomo4GhNHh/+3n/wGwzxVc
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 245->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 246->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 247->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 248->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC
Ubayi9fekGUYM2bG2MbMkOxbWdLfh/v1/+H59J7znPOe8zu/8yhcumZuv4KH
h8dvOXzL2SDVuVEw4Dm2vy7L9X3YBjIvba+9FmLAFh1+1zGrVMzmzrjplrdC
kBrvbHQIA87WHW8K187BRB+OuwmXBPXz6XvOjDNge663tkp1PobK3GSnriQB
ReKjBMW0E57OD9SdNSzFpimlYketZqh3JScvpnRChO6luUCHChwXdpBpPNUI
3teFCzOHO+G+5dWZ4B3VOB2mLHzEpgEW35XWoRITPkoWF20ZrEWRqpT25xZE
2GwU95DnDBOqTpuf1Esj4q+7wpf8tOsgWYlUs8+HCV4pxNKyS9/wi0pT2Vvh
GnCkOBAlIpjQnzOe7rG5Gc30jGLLGiqh/reS5oknTHi633iFhAsJrRK7C1uH
yyGCRogIuc+EY3Hj6sfrWnFSmpAWvKkE2FURH0y9mHBUsEhXQ56Mwxvu1eds
y4foHjdfMGGCbw534b1vO9oxg5lBvDngQEg3a9nIhMFrZRccWyg4ePvFEr9z
KvjePxfnSekE+iPtI3sJHVjkvXeTzMxzCDgyqPMouBOczFR25nvTkOfmIcFn
GZbILtcl+Ml0wqJzDje2jo6m5Vv9NvXEYmy6UcfNNwxwN/1L3GtdJ+aJxbms
cnuPkeaGMy3rGWD4kmHXYM1EDaPHj0zsP6GnZEbXKz865NbTB9e96UJWU3Vq
eHUR8vPZXhD4SgONwOHJHFY36hll2PibIwbKXYkU+9MB93gf35oV60Uh4TtD
bqur0X2rXcpn+Q7Id9BJvpXei6ItQmGv79ShtLiUfp8KFS7AFjn/g33I5/JY
bJVUA7Z/mvvmtYkCPxfC/ZzIfahKMOAtqWjCA4H6a7SnyfDyrvlS0UUW5tkG
W1OrSFjDb31zIqcN7AniR2uGWEjyNPpJyW3D/dJFmWZmrWD6ipJCdu1Ho507
H+3IbEfxa6Lmq9+3wAVtkzCZoX70q86iBeRRkTdzMtTmWiOscXKh59uy8bTW
miWbrzT8fMKVzpohAt8LxQcZDWxUEbe33sVhYF2ApUSvVi2o/vNbmK3KwaEN
3HhZ0S7cJrKe/mF/JXxk3FTcF8pB0tVWUQW9HhS5kLvRh1wMp9JqhYxbOEhs
Mc32L+1Fw+htvs6pOfBp2orRIMLF/u2LZ/g6+5BYq2apfD0etL6erlP+m4vX
7cOlixZZGExoKIo4Fonnv32c/XaOi9Tpf//2lWOjPCtmVeaWTPwWdNZ9/jIX
NZvjZ8b+4aBkoWTRlEYJVmyr1hy04qJKgGzJs0tcNJAf3V0H1ah0eHaiYLk/
9dZt2YSgASyx4Xf3+FyP363rjt3i52JUbKvriheDuHMpQkBOh4TJ+kIWJz9z
0NlhPC4w7TsmJmfankQySvQyDx434CCPSdOr8A9DGHv3iErVlQ5ULq22TShl
45pNlVqmb39gRQDfYeldnfjbZTApSZyN/t1pJygPhnFLkZ7KvGgPbiucc2Ia
9GNXY1tqp+0IqimqOorc6UOex1K3VK1YSBvW8+fZNIq+IsrzYaH96PR6j16t
YR/WnuXdTiwfxdGqvN0fHnDwsR0923xDL3qeloJPh8ewOV1SVT1qABX6HCvX
h3fhg6n1C2bvxtDnUYj+uajv6Fj1hhH5goF7LKWPOXPHMKz1wJuusB94INZ1
WMSxA+XVt5BElsbQoIfwbI/LCA7sY6dLLJLReGWGR8mPMQwWCSy/ozOGPWvv
dz61JOHWpZv2IZljqLpwt/qX9ziWEFv4B9bUo/1Xj1HCoTH0SHPYTYcJbLj7
y71PrhIzeX2ObU0fxaHoJH+FmQlMSrsTWTqSiwxdwyQqawRtDaL0jZ9P4vsS
5XN0kxu4ur5lW+D4MOYmdrxWlZ3ClFfENKGSLCj3TBDa3/4D2yfD183dnUL1
a7zW7nMI531n2n5EDeHD3o0Xr9CnUPQ2a0BQmQjm6rV2ZirfccuuL5OZYtOY
nPxWNkmMBEoUgcN5KQN4VUt+6pnSNGYqPLhrxSKDcVDLOHOZC2UvhVF7wjQa
meSeDAjvgA2rfRTZJ9nI0prTmlo5jT/uV1WJTzGgZeu6bMEIFlLDL04ENU3h
gg9z9qVCN8jPu2YHL/OvzHe25nPAFGb6qCRFhPeCk0uMV2ljF9rJrxoMk5rC
1mytAkF6H3zt7OOtlWegv9SfaqW4SeQrVt2hJ9gPtcVP3jJvUpGZUJoxJjKJ
ZDmB+I61bCjpNE4gc9rQvp/ZesR9Yvne/FJqlg20gETCWEMzxl687Pqwbhz3
lp5q+VLIAUne4SwJXiIG7TIJkZMYR5+5FfO/z3DBu9qq7ZZPJabuGrntlDGK
xscvztpSuHAMaY3aLgUY6O+TV7VtBB/weUykqA9A8rqDpjz8qag4lfBY9vkP
PPM9K7TCewCCrQ31Vyc5QuxS4y7u0nf0iDLe9yVxAHioOzkp9WlgLl5N+sth
EEcOytzO/DAAa5+0NN04nw9sRa5zTgsXJSgX0t+/GYCcttFDtPflsEr8cn+2
Dgdd+wI6CkIHoOaUxLVL76pBw+yXhXJGP4oXO2c0nxoA3bioed33X0EgMeJV
lRwLLTyyypvFByCmXURW1fIbeO89WEFN6MWsd+LTfhVcKHpokt70pRlK/K7/
mT/SjU4Puwg3LnLh35QkacEfJNAroB5UvNyJRAHHVQazHNBZoFgJWrRBTDMn
PiiahocSPXlPBXOgiPknRDCeDFmTN478ZlLwRjwm9/NwQH64oSezsh3O/N1/
/JgOGd/O3/6o4MeGoN82M6/qKRD9dJUrMZOE//kZ/vMz/Odn7I6MJlZY9INU
T0MDLaQDXDb/ObqU/RWbJgzWjxazQD6Uf0pbmwaLSk0LezZX44G47mE7GRaU
tLXzSlNpUMhdu3P8ahm+MJzxafPuA539cc9I5+nw2FPB1GQ2D1d8tnAitfTC
7J5itZJvdPjYvsO/ID0dd2vU53K390LUpuayNUoMkE/IEfgj8xx7J4fMZaa6
QTbXzmXejQF7CPmjYjkhkEUg61jFdAGP1xzxcQoDztks1PAefQuabZEh+hpM
UN1GU2sjMmB072e1/pAcyPtZsOYWmQE80SX6uUwGfFEM1bbYWAhqE6tyI93o
ULXIyhTqY4CAdHj0b/sySIg1dBgRpEHJDKU4g8oAqZx3DjwFlXD68/qrgslU
KE3rVjcuZ8DebH3N4pgauOEWIqauSQG1+xq7k2IZ4FGZNqNyZpmLf5cuYhMZ
CBvFvulcYQD7dJqm8Uw96G1aWfP9chscWt0h8Gn5X88sUXmRG42Q/2ar7vc5
ElQ4b74T1kWH8iEFq6PUZpCPueNFkWsBO/tFHZV7dHBLOZ82GEmCvTdPXFE8
0QgSlu2HVu+gQ/926wOaya3w8kWMGa9fPbgfvOQUXEYDYwVqiHNqG2wU1ZWP
SasD6quiLtYxGhACpVWpCWRofPrTVIhSDVFruDV+DR1wKL/gcl14OzBXKPn7
81fCuVjTutBDHWBzYDE/6DIFhFXfnvvp9AWspRYe6uRS4Srf2Sm9fVQQ/qno
rt1UAL23RPXrpalw0KBXVnuWCsHJ9wqb/8qFkQpJ3rNeFHD9I2QU/7EDBEpS
vML2vwP1mlCVFV/bYcx6/s2DMzSYdtd5cFUyFoSbNnT2ibdD4tOdGoRpGrjP
Dya4eluD2ZMydQELMiyomo4GhNHh/+3n/wGwzxVc
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 249->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 250->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 251->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 252->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 253->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 254->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 255->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 256->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 257->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 258->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 259->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 260->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 261->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 262->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 263->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 264->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 265->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 266->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 267->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 268->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 269->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 270->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 271->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 272->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 273->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 274->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 275->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 276->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 277->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 278->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 279->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 280->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 281->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 282->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 283->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 284->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC
Ubayi9fekGUYM2bG2MbMkOxbWdLfh/v1/+H59J7znPOe8zu/8yhcumZuv4KH
h8dvOXzL2SDVuVEw4Dm2vy7L9X3YBjIvba+9FmLAFh1+1zGrVMzmzrjplrdC
kBrvbHQIA87WHW8K187BRB+OuwmXBPXz6XvOjDNge663tkp1PobK3GSnriQB
ReKjBMW0E57OD9SdNSzFpimlYketZqh3JScvpnRChO6luUCHChwXdpBpPNUI
3teFCzOHO+G+5dWZ4B3VOB2mLHzEpgEW35XWoRITPkoWF20ZrEWRqpT25xZE
2GwU95DnDBOqTpuf1Esj4q+7wpf8tOsgWYlUs8+HCV4pxNKyS9/wi0pT2Vvh
GnCkOBAlIpjQnzOe7rG5Gc30jGLLGiqh/reS5oknTHi633iFhAsJrRK7C1uH
yyGCRogIuc+EY3Hj6sfrWnFSmpAWvKkE2FURH0y9mHBUsEhXQ56Mwxvu1eds
y4foHjdfMGGCbw534b1vO9oxg5lBvDngQEg3a9nIhMFrZRccWyg4ePvFEr9z
KvjePxfnSekE+iPtI3sJHVjkvXeTzMxzCDgyqPMouBOczFR25nvTkOfmIcFn
GZbILtcl+Ml0wqJzDje2jo6m5Vv9NvXEYmy6UcfNNwxwN/1L3GtdJ+aJxbms
cnuPkeaGMy3rGWD4kmHXYM1EDaPHj0zsP6GnZEbXKz865NbTB9e96UJWU3Vq
eHUR8vPZXhD4SgONwOHJHFY36hll2PibIwbKXYkU+9MB93gf35oV60Uh4TtD
bqur0X2rXcpn+Q7Id9BJvpXei6ItQmGv79ShtLiUfp8KFS7AFjn/g33I5/JY
bJVUA7Z/mvvmtYkCPxfC/ZzIfahKMOAtqWjCA4H6a7SnyfDyrvlS0UUW5tkG
W1OrSFjDb31zIqcN7AniR2uGWEjyNPpJyW3D/dJFmWZmrWD6ipJCdu1Ho507
H+3IbEfxa6Lmq9+3wAVtkzCZoX70q86iBeRRkTdzMtTmWiOscXKh59uy8bTW
miWbrzT8fMKVzpohAt8LxQcZDWxUEbe33sVhYF2ApUSvVi2o/vNbmK3KwaEN
3HhZ0S7cJrKe/mF/JXxk3FTcF8pB0tVWUQW9HhS5kLvRh1wMp9JqhYxbOEhs
Mc32L+1Fw+htvs6pOfBp2orRIMLF/u2LZ/g6+5BYq2apfD0etL6erlP+m4vX
7cOlixZZGExoKIo4Fonnv32c/XaOi9Tpf//2lWOjPCtmVeaWTPwWdNZ9/jIX
NZvjZ8b+4aBkoWTRlEYJVmyr1hy04qJKgGzJs0tcNJAf3V0H1ah0eHaiYLk/
9dZt2YSgASyx4Xf3+FyP363rjt3i52JUbKvriheDuHMpQkBOh4TJ+kIWJz9z
0NlhPC4w7TsmJmfankQySvQyDx434CCPSdOr8A9DGHv3iErVlQ5ULq22TShl
45pNlVqmb39gRQDfYeldnfjbZTApSZyN/t1pJygPhnFLkZ7KvGgPbiucc2Ia
9GNXY1tqp+0IqimqOorc6UOex1K3VK1YSBvW8+fZNIq+IsrzYaH96PR6j16t
YR/WnuXdTiwfxdGqvN0fHnDwsR0923xDL3qeloJPh8ewOV1SVT1qABX6HCvX
h3fhg6n1C2bvxtDnUYj+uajv6Fj1hhH5goF7LKWPOXPHMKz1wJuusB94INZ1
WMSxA+XVt5BElsbQoIfwbI/LCA7sY6dLLJLReGWGR8mPMQwWCSy/ozOGPWvv
dz61JOHWpZv2IZljqLpwt/qX9ziWEFv4B9bUo/1Xj1HCoTH0SHPYTYcJbLj7
y71PrhIzeX2ObU0fxaHoJH+FmQlMSrsTWTqSiwxdwyQqawRtDaL0jZ9P4vsS
5XN0kxu4ur5lW+D4MOYmdrxWlZ3ClFfENKGSLCj3TBDa3/4D2yfD183dnUL1
a7zW7nMI531n2n5EDeHD3o0Xr9CnUPQ2a0BQmQjm6rV2ZirfccuuL5OZYtOY
nPxWNkmMBEoUgcN5KQN4VUt+6pnSNGYqPLhrxSKDcVDLOHOZC2UvhVF7wjQa
meSeDAjvgA2rfRTZJ9nI0prTmlo5jT/uV1WJTzGgZeu6bMEIFlLDL04ENU3h
gg9z9qVCN8jPu2YHL/OvzHe25nPAFGb6qCRFhPeCk0uMV2ljF9rJrxoMk5rC
1mytAkF6H3zt7OOtlWegv9SfaqW4SeQrVt2hJ9gPtcVP3jJvUpGZUJoxJjKJ
ZDmB+I61bCjpNE4gc9rQvp/ZesR9Yvne/FJqlg20gETCWEMzxl687Pqwbhz3
lp5q+VLIAUne4SwJXiIG7TIJkZMYR5+5FfO/z3DBu9qq7ZZPJabuGrntlDGK
xscvztpSuHAMaY3aLgUY6O+TV7VtBB/weUykqA9A8rqDpjz8qag4lfBY9vkP
PPM9K7TCewCCrQ31Vyc5QuxS4y7u0nf0iDLe9yVxAHioOzkp9WlgLl5N+sth
EEcOytzO/DAAa5+0NN04nw9sRa5zTgsXJSgX0t+/GYCcttFDtPflsEr8cn+2
Dgdd+wI6CkIHoOaUxLVL76pBw+yXhXJGP4oXO2c0nxoA3bioed33X0EgMeJV
lRwLLTyyypvFByCmXURW1fIbeO89WEFN6MWsd+LTfhVcKHpokt70pRlK/K7/
mT/SjU4Puwg3LnLh35QkacEfJNAroB5UvNyJRAHHVQazHNBZoFgJWrRBTDMn
PiiahocSPXlPBXOgiPknRDCeDFmTN478ZlLwRjwm9/NwQH64oSezsh3O/N1/
/JgOGd/O3/6o4MeGoN82M6/qKRD9dJUrMZOE//kZ/vMz/Odn7I6MJlZY9INU
T0MDLaQDXDb/ObqU/RWbJgzWjxazQD6Uf0pbmwaLSk0LezZX44G47mE7GRaU
tLXzSlNpUMhdu3P8ahm+MJzxafPuA539cc9I5+nw2FPB1GQ2D1d8tnAitfTC
7J5itZJvdPjYvsO/ID0dd2vU53K390LUpuayNUoMkE/IEfgj8xx7J4fMZaa6
QTbXzmXejQF7CPmjYjkhkEUg61jFdAGP1xzxcQoDztks1PAefQuabZEh+hpM
UN1GU2sjMmB072e1/pAcyPtZsOYWmQE80SX6uUwGfFEM1bbYWAhqE6tyI93o
ULXIyhTqY4CAdHj0b/sySIg1dBgRpEHJDKU4g8oAqZx3DjwFlXD68/qrgslU
KE3rVjcuZ8DebH3N4pgauOEWIqauSQG1+xq7k2IZ4FGZNqNyZpmLf5cuYhMZ
CBvFvulcYQD7dJqm8Uw96G1aWfP9chscWt0h8Gn5X88sUXmRG42Q/2ar7vc5
ElQ4b74T1kWH8iEFq6PUZpCPueNFkWsBO/tFHZV7dHBLOZ82GEmCvTdPXFE8
0QgSlu2HVu+gQ/926wOaya3w8kWMGa9fPbgfvOQUXEYDYwVqiHNqG2wU1ZWP
SasD6quiLtYxGhACpVWpCWRofPrTVIhSDVFruDV+DR1wKL/gcl14OzBXKPn7
81fCuVjTutBDHWBzYDE/6DIFhFXfnvvp9AWspRYe6uRS4Srf2Sm9fVQQ/qno
rt1UAL23RPXrpalw0KBXVnuWCsHJ9wqb/8qFkQpJ3rNeFHD9I2QU/7EDBEpS
vML2vwP1mlCVFV/bYcx6/s2DMzSYdtd5cFUyFoSbNnT2ibdD4tOdGoRpGrjP
Dya4eluD2ZMydQELMiyomo4GhNHh/+3n/wGwzxVc
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 285->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 286->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 287->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 288->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 289->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC
Ubayi9fekGUYM2bG2MbMkOxbWdLfh/v1/+H59J7znPOe8zu/8yhcumZuv4KH
h8dvOXzL2SDVuVEw4Dm2vy7L9X3YBjIvba+9FmLAFh1+1zGrVMzmzrjplrdC
kBrvbHQIA87WHW8K187BRB+OuwmXBPXz6XvOjDNge663tkp1PobK3GSnriQB
ReKjBMW0E57OD9SdNSzFpimlYketZqh3JScvpnRChO6luUCHChwXdpBpPNUI
3teFCzOHO+G+5dWZ4B3VOB2mLHzEpgEW35XWoRITPkoWF20ZrEWRqpT25xZE
2GwU95DnDBOqTpuf1Esj4q+7wpf8tOsgWYlUs8+HCV4pxNKyS9/wi0pT2Vvh
GnCkOBAlIpjQnzOe7rG5Gc30jGLLGiqh/reS5oknTHi633iFhAsJrRK7C1uH
yyGCRogIuc+EY3Hj6sfrWnFSmpAWvKkE2FURH0y9mHBUsEhXQ56Mwxvu1eds
y4foHjdfMGGCbw534b1vO9oxg5lBvDngQEg3a9nIhMFrZRccWyg4ePvFEr9z
KvjePxfnSekE+iPtI3sJHVjkvXeTzMxzCDgyqPMouBOczFR25nvTkOfmIcFn
GZbILtcl+Ml0wqJzDje2jo6m5Vv9NvXEYmy6UcfNNwxwN/1L3GtdJ+aJxbms
cnuPkeaGMy3rGWD4kmHXYM1EDaPHj0zsP6GnZEbXKz865NbTB9e96UJWU3Vq
eHUR8vPZXhD4SgONwOHJHFY36hll2PibIwbKXYkU+9MB93gf35oV60Uh4TtD
bqur0X2rXcpn+Q7Id9BJvpXei6ItQmGv79ShtLiUfp8KFS7AFjn/g33I5/JY
bJVUA7Z/mvvmtYkCPxfC/ZzIfahKMOAtqWjCA4H6a7SnyfDyrvlS0UUW5tkG
W1OrSFjDb31zIqcN7AniR2uGWEjyNPpJyW3D/dJFmWZmrWD6ipJCdu1Ho507
H+3IbEfxa6Lmq9+3wAVtkzCZoX70q86iBeRRkTdzMtTmWiOscXKh59uy8bTW
miWbrzT8fMKVzpohAt8LxQcZDWxUEbe33sVhYF2ApUSvVi2o/vNbmK3KwaEN
3HhZ0S7cJrKe/mF/JXxk3FTcF8pB0tVWUQW9HhS5kLvRh1wMp9JqhYxbOEhs
Mc32L+1Fw+htvs6pOfBp2orRIMLF/u2LZ/g6+5BYq2apfD0etL6erlP+m4vX
7cOlixZZGExoKIo4Fonnv32c/XaOi9Tpf//2lWOjPCtmVeaWTPwWdNZ9/jIX
NZvjZ8b+4aBkoWTRlEYJVmyr1hy04qJKgGzJs0tcNJAf3V0H1ah0eHaiYLk/
9dZt2YSgASyx4Xf3+FyP363rjt3i52JUbKvriheDuHMpQkBOh4TJ+kIWJz9z
0NlhPC4w7TsmJmfankQySvQyDx434CCPSdOr8A9DGHv3iErVlQ5ULq22TShl
45pNlVqmb39gRQDfYeldnfjbZTApSZyN/t1pJygPhnFLkZ7KvGgPbiucc2Ia
9GNXY1tqp+0IqimqOorc6UOex1K3VK1YSBvW8+fZNIq+IsrzYaH96PR6j16t
YR/WnuXdTiwfxdGqvN0fHnDwsR0923xDL3qeloJPh8ewOV1SVT1qABX6HCvX
h3fhg6n1C2bvxtDnUYj+uajv6Fj1hhH5goF7LKWPOXPHMKz1wJuusB94INZ1
WMSxA+XVt5BElsbQoIfwbI/LCA7sY6dLLJLReGWGR8mPMQwWCSy/ozOGPWvv
dz61JOHWpZv2IZljqLpwt/qX9ziWEFv4B9bUo/1Xj1HCoTH0SHPYTYcJbLj7
y71PrhIzeX2ObU0fxaHoJH+FmQlMSrsTWTqSiwxdwyQqawRtDaL0jZ9P4vsS
5XN0kxu4ur5lW+D4MOYmdrxWlZ3ClFfENKGSLCj3TBDa3/4D2yfD183dnUL1
a7zW7nMI531n2n5EDeHD3o0Xr9CnUPQ2a0BQmQjm6rV2ZirfccuuL5OZYtOY
nPxWNkmMBEoUgcN5KQN4VUt+6pnSNGYqPLhrxSKDcVDLOHOZC2UvhVF7wjQa
meSeDAjvgA2rfRTZJ9nI0prTmlo5jT/uV1WJTzGgZeu6bMEIFlLDL04ENU3h
gg9z9qVCN8jPu2YHL/OvzHe25nPAFGb6qCRFhPeCk0uMV2ljF9rJrxoMk5rC
1mytAkF6H3zt7OOtlWegv9SfaqW4SeQrVt2hJ9gPtcVP3jJvUpGZUJoxJjKJ
ZDmB+I61bCjpNE4gc9rQvp/ZesR9Yvne/FJqlg20gETCWEMzxl687Pqwbhz3
lp5q+VLIAUne4SwJXiIG7TIJkZMYR5+5FfO/z3DBu9qq7ZZPJabuGrntlDGK
xscvztpSuHAMaY3aLgUY6O+TV7VtBB/weUykqA9A8rqDpjz8qag4lfBY9vkP
PPM9K7TCewCCrQ31Vyc5QuxS4y7u0nf0iDLe9yVxAHioOzkp9WlgLl5N+sth
EEcOytzO/DAAa5+0NN04nw9sRa5zTgsXJSgX0t+/GYCcttFDtPflsEr8cn+2
Dgdd+wI6CkIHoOaUxLVL76pBw+yXhXJGP4oXO2c0nxoA3bioed33X0EgMeJV
lRwLLTyyypvFByCmXURW1fIbeO89WEFN6MWsd+LTfhVcKHpokt70pRlK/K7/
mT/SjU4Puwg3LnLh35QkacEfJNAroB5UvNyJRAHHVQazHNBZoFgJWrRBTDMn
PiiahocSPXlPBXOgiPknRDCeDFmTN478ZlLwRjwm9/NwQH64oSezsh3O/N1/
/JgOGd/O3/6o4MeGoN82M6/qKRD9dJUrMZOE//kZ/vMz/Odn7I6MJlZY9INU
T0MDLaQDXDb/ObqU/RWbJgzWjxazQD6Uf0pbmwaLSk0LezZX44G47mE7GRaU
tLXzSlNpUMhdu3P8ahm+MJzxafPuA539cc9I5+nw2FPB1GQ2D1d8tnAitfTC
7J5itZJvdPjYvsO/ID0dd2vU53K390LUpuayNUoMkE/IEfgj8xx7J4fMZaa6
QTbXzmXejQF7CPmjYjkhkEUg61jFdAGP1xzxcQoDztks1PAefQuabZEh+hpM
UN1GU2sjMmB072e1/pAcyPtZsOYWmQE80SX6uUwGfFEM1bbYWAhqE6tyI93o
ULXIyhTqY4CAdHj0b/sySIg1dBgRpEHJDKU4g8oAqZx3DjwFlXD68/qrgslU
KE3rVjcuZ8DebH3N4pgauOEWIqauSQG1+xq7k2IZ4FGZNqNyZpmLf5cuYhMZ
CBvFvulcYQD7dJqm8Uw96G1aWfP9chscWt0h8Gn5X88sUXmRG42Q/2ar7vc5
ElQ4b74T1kWH8iEFq6PUZpCPueNFkWsBO/tFHZV7dHBLOZ82GEmCvTdPXFE8
0QgSlu2HVu+gQ/926wOaya3w8kWMGa9fPbgfvOQUXEYDYwVqiHNqG2wU1ZWP
SasD6quiLtYxGhACpVWpCWRofPrTVIhSDVFruDV+DR1wKL/gcl14OzBXKPn7
81fCuVjTutBDHWBzYDE/6DIFhFXfnvvp9AWspRYe6uRS4Srf2Sm9fVQQ/qno
rt1UAL23RPXrpalw0KBXVnuWCsHJ9wqb/8qFkQpJ3rNeFHD9I2QU/7EDBEpS
vML2vwP1mlCVFV/bYcx6/s2DMzSYdtd5cFUyFoSbNnT2ibdD4tOdGoRpGrjP
Dya4eluD2ZMydQELMiyomo4GhNHh/+3n/wGwzxVc
                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 290->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 291->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 292->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}], 293->
               Graphics3DBox[{
                 {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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                   "]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {-0.07201576178665542, 
                    1.0435850380609761`, 1.4648358264288728`}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 
                    0}, {-1.4935850380609763`, -0.8514386251926501, 
                    0.5331566389068428}}, 0.02]]}, 
                 {RGBColor[1, 0, 0], Arrowheads[0.04], 
                  Arrow3DBox[
                   TubeBox[{{0, 0, 0}, {
                    1.0020067186075547`, -1.1941451067040891`, 0.9}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
                 {RGBColor[0, 0, 1], Arrowheads[0.04], 
                  Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
                 {GrayLevel[1], Opacity[0.5], 
                  Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
                   1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]},
                  Point3DBox[{0, 0, 0}], 
                 Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
                 Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
                 Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
                Boxed->False,
                Lighting->False,
                PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
                SphericalRegion->True,
                ViewPoint->{1.3, -2.4, 2.}]}, Dynamic[$CellContext`i11$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.852458950432445*^9, 3.8524589663761663`*^9}, 
   3.852459015738639*^9, 3.852459069376141*^9, 3.852459150206938*^9, {
   3.852460622756536*^9, 3.85246065133743*^9}, 3.852460713290875*^9, 
   3.852460748072994*^9, 3.852460989780107*^9, 3.8524649745078077`*^9, 
   3.852465073976079*^9, 3.852465233575406*^9, 3.852465292396016*^9, 
   3.852466967679961*^9, 3.8524671431917973`*^9, 3.852529083808511*^9, 
   3.852529216965654*^9, 3.8525303150072727`*^9, 3.8525315056289988`*^9, 
   3.8525351091194897`*^9, 3.852536264002582*^9, 3.852536376627962*^9, 
   3.85253675206314*^9, 3.8525721414963617`*^9, 3.85257225885201*^9, 
   3.852572401149692*^9, {3.8525724470816517`*^9, 3.8525724770140667`*^9}, 
   3.852572608513879*^9, 3.8525726535581007`*^9, 3.88147828318233*^9, 
   3.890900582237988*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"d0b39923-53cd-4541-aff8-889ec496df53"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{"Export", "[", 
   RowBox[{"\"\<OrbitRotationMovie.mov\>\"", ",", "orbrot", ",", " ", 
    RowBox[{"\"\<ControlAppearance\>\"", "\[Rule]", "None"}]}], "]"}], 
  "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.811158316520338*^9, 3.811158343476906*^9}, {
  3.811158632154683*^9, 3.811158643834765*^9}, {3.852536339472847*^9, 
  3.8525363473912477`*^9}, {3.852536389240259*^9, 3.852536390823784*^9}, {
  3.852572241597254*^9, 3.852572248844344*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"c2e0233d-5326-4973-af65-d510af6564dc"]
},
CellGrouping->Manual,
WindowSize->{927, 645},
WindowMargins->{{223, Automatic}, {Automatic, 260}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8c5410ea-ca8d-4fcd-8cd5-bb167c5ea7f9"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"c234eda6-470d-4ce4-a2a7-7f58a6df059d"],
Cell[948, 30, 195, 3, 67, "Section",ExpressionUUID->"8d36d243-d1b2-4dc1-b6c6-24fb93c12288"],
Cell[1146, 35, 408, 14, 72, "Text",ExpressionUUID->"d5ed9320-f05a-4b94-8a25-ee3a9e0eae98"],
Cell[1557, 51, 188, 3, 30, "Input",ExpressionUUID->"672bc8cb-0992-40af-9edd-19e6c582074e"],
Cell[1748, 56, 236, 7, 53, "Text",ExpressionUUID->"a0007e51-09cc-412e-b873-7e1d980429ba"],
Cell[1987, 65, 181, 3, 30, "Input",ExpressionUUID->"9de712f4-ffc4-4c90-a61a-23de1e8c4c9d"],
Cell[2171, 70, 247, 4, 53, "Text",ExpressionUUID->"34bfc68c-99b8-4d2c-b94b-cd8ab878feb8"],
Cell[2421, 76, 754, 20, 52, "Input",ExpressionUUID->"0e376915-8fd5-499c-8b61-f5a9c5e9b62d"],
Cell[3178, 98, 248, 4, 53, "Text",ExpressionUUID->"1bc6f51f-3786-4763-aba6-8599670a2d28"],
Cell[3429, 104, 315, 7, 33, "Input",ExpressionUUID->"857e11d4-9e67-4184-abb4-7e1dd13a9671"],
Cell[3747, 113, 275, 6, 53, "Text",ExpressionUUID->"c77888b8-1de3-4b8c-90ef-f6ae58a47bc9"],
Cell[4025, 121, 3179, 71, 115, "Input",ExpressionUUID->"3652ce30-f56d-4e52-852d-b4fe08c65066"],
Cell[7207, 194, 274, 6, 53, "Text",ExpressionUUID->"9e30f975-d9be-4ece-95d5-877d0e85514d"],
Cell[7484, 202, 3609, 84, 136, "Input",ExpressionUUID->"1398d984-0426-4b5a-a072-c893e20cdcad"],
Cell[11096, 288, 268, 6, 53, "Text",ExpressionUUID->"e5a24ef9-2e36-42fa-b1ad-7178d38ca7cd"],
Cell[11367, 296, 523, 11, 30, "Input",ExpressionUUID->"252528e2-40aa-4756-b12f-b27bc2a3cac5"],
Cell[11893, 309, 272, 6, 53, "Text",ExpressionUUID->"b8a8eb27-75de-4e3c-8f55-30f58984bbe9"],
Cell[12168, 317, 643, 16, 52, "Input",ExpressionUUID->"f1e1377c-633c-4f70-854a-860223c37998"],
Cell[12814, 335, 275, 6, 53, "Text",ExpressionUUID->"06c35ab9-b0b8-40b6-b090-c02afe2d208d"],
Cell[13092, 343, 644, 16, 52, "Input",ExpressionUUID->"51024ddd-924d-498c-ad34-6d51ff7c2881"],
Cell[13739, 361, 315, 7, 53, "Text",ExpressionUUID->"67043386-4d59-4e57-a499-e40e376b532f"],
Cell[14057, 370, 3527, 101, 241, "Input",ExpressionUUID->"f877f1cb-57e9-409f-aef3-d7ceea1b068c"],
Cell[17587, 473, 1037, 32, 122, "Text",ExpressionUUID->"ef8f25f0-a856-4688-a767-eed688aacf14"],
Cell[18627, 507, 6760, 155, 346, "Input",ExpressionUUID->"833cd61d-07b2-413f-b484-11b9829ef206"],
Cell[25390, 664, 430, 9, 53, "Text",ExpressionUUID->"1466ea03-023b-4327-9ae2-52e45c36a7e4"],
Cell[CellGroupData[{
Cell[25845, 677, 680, 12, 30, "Input",ExpressionUUID->"b60ad620-4b8e-4c0b-a3d0-430ab0675dee"],
Cell[26528, 691, 6878, 119, 377, "Output",ExpressionUUID->"416d576c-bb6c-4a31-9e6e-1a4786492f85"]
}, Open  ]],
Cell[33421, 813, 373, 6, 53, "Text",ExpressionUUID->"b7a09cb3-557c-4d78-a2bf-c8fb0069582a"],
Cell[CellGroupData[{
Cell[33819, 823, 565, 11, 30, "Input",ExpressionUUID->"594a663c-15fe-40ed-8e2d-2b9900170700"],
Cell[34387, 836, 3630, 66, 377, "Output",ExpressionUUID->"a88cbfa1-8297-44e5-bcc4-e04e8975d0e4"]
}, Open  ]],
Cell[38032, 905, 506, 9, 53, "Text",ExpressionUUID->"a8640360-e1d7-44a9-9f7d-681bf0595b39"],
Cell[CellGroupData[{
Cell[38563, 918, 734, 13, 30, "Input",ExpressionUUID->"0f9b85c3-b35f-4be3-a072-a517b5fb9a1f"],
Cell[39300, 933, 6988, 125, 377, "Output",ExpressionUUID->"621736f9-05fd-41bd-a5cf-8b0cb2b3f041"]
}, Open  ]],
Cell[46303, 1061, 504, 12, 53, "Text",ExpressionUUID->"39ed6fe5-ade0-446f-b09e-9b5a1681b068"],
Cell[CellGroupData[{
Cell[46832, 1077, 856, 15, 30, "Input",ExpressionUUID->"74132f98-8cb1-45bd-8f90-c0ab6a619887"],
Cell[47691, 1094, 7930, 142, 377, "Output",ExpressionUUID->"6239c3b3-73b5-4604-84d5-f99bc78c4af6"]
}, Open  ]],
Cell[55636, 1239, 463, 8, 53, "Text",ExpressionUUID->"f196d2f0-08bc-483a-9bcc-4bf1a8e01320"],
Cell[CellGroupData[{
Cell[56124, 1251, 858, 15, 30, "Input",ExpressionUUID->"7bda418d-e005-45e6-95fd-0290eb895615"],
Cell[56985, 1268, 8082, 146, 377, "Output",ExpressionUUID->"c89a4775-3949-4a41-a098-e221182224c3"]
}, Open  ]],
Cell[65082, 1417, 438, 7, 53, "Text",ExpressionUUID->"96787028-9abc-4f81-ac55-2383ad25ed4f"],
Cell[CellGroupData[{
Cell[65545, 1428, 498, 12, 73, "Input",ExpressionUUID->"0aa0cfc5-2e05-439e-b313-c47398647101"],
Cell[66046, 1442, 25336, 455, 377, "Output",ExpressionUUID->"4527f351-5805-494c-aa6b-6acd2afe4621"]
}, Open  ]],
Cell[91397, 1900, 513, 10, 53, "Text",ExpressionUUID->"ef016f41-6678-421f-b622-b72abbe6859f"],
Cell[91913, 1912, 3217, 75, 241, "Input",ExpressionUUID->"9dc7945e-0af2-4963-b81b-a46b1e048422"],
Cell[95133, 1989, 460, 8, 53, "Text",ExpressionUUID->"241143ac-ac99-48b3-b7ee-7f7c40389e78"],
Cell[CellGroupData[{
Cell[95618, 2001, 453, 10, 30, "Input",ExpressionUUID->"a848fe40-6adb-4e9e-90d4-ad4283ef6ee3"],
Cell[96074, 2013, 1795360, 30850, 453, "Output",ExpressionUUID->"d0b39923-53cd-4541-aff8-889ec496df53"]
}, Open  ]],
Cell[1891449, 32866, 604, 10, 103, "Input",ExpressionUUID->"c2e0233d-5326-4973-af65-d510af6564dc"]
}
]
*)

